@@ -1,5 +1,5 @@
 //----------------------------------*-C++-*----------------------------------//
-// $Id: plstream.cc 9285 2009-01-08 23:46:45Z andrewross $
+// $Id: plstream.cc 10304 2009-08-20 09:05:43Z andrewross $
 // Geoffrey Furnish
 // Sep 21 1994
 //
@@ -31,7 +31,7 @@
 
 #include <iostream>
 
-#ifdef USE_NAMESPACE
+#ifdef PL_USE_NAMESPACE
 using namespace std;
 #endif
 
@@ -312,6 +312,15 @@ plstream::adv( PLINT page )
     pladv(page);
 }
 
+void
+plstream::arc( PLFLT x, PLFLT y, PLFLT a, PLFLT b, PLFLT angle1, PLFLT angle2,
+        PLBOOL fill )
+{
+    set_stream();
+
+    plarc(x, y, a, b, angle1, angle2, fill);
+}
+
 void
 plstream::arrows(PLFLT *u, PLFLT *v, PLFLT *x, PLFLT *y, PLINT n,
                  PLFLT scale, PLFLT dx, PLFLT dy)
@@ -388,6 +397,7 @@ void plstream::box( const char *xopt, PLFLT xtick, PLINT nxsub,
     plbox( xopt, xtick, nxsub, yopt, ytick, nysub );
 }
 
+
 // This is the 3-d analogue of plbox().
 
 void
@@ -402,6 +412,13 @@ plstream::box3( const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
 	    zopt, zlabel, ztick, nsubz );
 }
 
+// Calculate broken-down time from continuous time for current stream.
+void plstream::btime(PLINT &year, PLINT &month, PLINT &day, PLINT &hour, PLINT &min, PLFLT &sec, PLFLT ctime) {
+    set_stream();
+
+    plbtime( &year, &month, &day, &hour, &min, &sec, ctime );
+}
+  
 // Calculate world coordinates and subpage from relative device coordinates.
 
 void plstream::calc_world(PLFLT rx, PLFLT ry, PLFLT& wx, PLFLT& wy, 
@@ -458,6 +475,21 @@ void plstream::col( PLFLT c )
     plcol1( c );
 }
 
+// Configure transformation between continuous and broken-down time (and
+// vice versa) for current stream.
+void plstream::configtime( PLFLT scale, PLFLT offset1, PLFLT offset2, 
+			   PLINT ccontrol, PLBOOL ifbtime_offset, PLINT year, 
+			   PLINT month, PLINT day, PLINT hour, PLINT min, 
+			   PLFLT sec) 
+{
+    set_stream();
+
+    plconfigtime(scale, offset1, offset2, ccontrol, ifbtime_offset, year, 
+		 month, day, hour, min, sec);
+}
+  
+
+
 // Draws a contour plot from data in f(nx,ny).  Is just a front-end to
 // plfcont, with a particular choice for f2eval and f2eval_data.
 
@@ -508,6 +540,14 @@ void plstream::cpstrm( plstream &pls, PLINT flags )
     plcpstrm(pls.stream,(PLBOOL)flags);
 }
 
+// Calculate continuous time from broken-down time for current stream.
+void plstream::ctime(PLINT year, PLINT month, PLINT day, PLINT hour, PLINT min, PLFLT sec, PLFLT &ctime) 
+{
+    set_stream();
+
+    plctime( year, month, day, hour, min, sec, &ctime);
+}
+  
 // Converts input values from relative device coordinates to relative plot
 // coordinates.
 
@@ -1690,7 +1730,7 @@ plstream::shade( Contourable_Data& d, PLFLT xmin, PLFLT xmax,
 		xmin, xmax, ymin, ymax, shade_min, shade_max,
 		sh_cmap, sh_color, sh_width,
 		min_color, min_width, max_color, max_width,
-		::plfill, (bool) rectangular,
+		::plfill, rectangular!=0,
 		Coord_Xform_evaluator, pcxf );
 }
 
@@ -1792,6 +1832,16 @@ plstream::fshade( PLFLT (*f2eval) (PLINT, PLINT, PLPointer),
 	      fill, (PLBOOL) rectangular, pltr, pltr_data );
 }
 
+/* Setup a user-provided custom labeling function */
+
+void plstream::slabelfunc( void (*label_func)(PLINT, PLFLT, char *, PLINT, PLPointer),
+                             PLPointer label_data)
+{
+    set_stream();
+
+    plslabelfunc(label_func, label_data);
+}
+
 /* Set up lengths of major tick marks. */
 
 void plstream::smaj( PLFLT def, PLFLT scale )
@@ -1829,6 +1879,24 @@ void plstream::spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
     plspage(xp,yp,xleng,yleng,xoff,yoff);
 }
 
+/* Set the colors for color table 0 from a cmap0 file */
+
+void plstream::spal0(const char *filename)
+{
+  set_stream();
+
+  plspal0(filename);
+}
+
+/* Set the colors for color table 1 from a cmap1 file */
+
+void plstream::spal1(const char *filename, bool interpolate)
+{
+  set_stream();
+
+  plspal1(filename, (PLBOOL) interpolate);
+}
+
 /* Set the pause (on end-of-page) status */
 
 void plstream::spause( bool pause )
@@ -2132,7 +2200,7 @@ void plstream::xormod(bool mode, bool *status)
 
    plxormod((PLBOOL) mode, &loc_status);
 
-   *status = (bool) loc_status;
+   *status = (loc_status!=0);
 }
 
 // Deprecated version using PLINT not bool
@@ -2260,13 +2328,15 @@ void plstream::tr2p( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty,
 // }
 
 /* Example linear transformation function for contour plotter. */
-
+/* This is not actually a part of the core library any more */
+/*
 void  plstream::xform( PLFLT x, PLFLT y, PLFLT * tx, PLFLT * ty )
 {
     set_stream();
 
     xform(x,y,tx,ty);
 }
+*/
 
 	/* Function evaluators */
 
