@@ -1,5 +1,5 @@
 //----------------------------------*-C++-*----------------------------------//
-// $Id: plstream.h 9285 2009-01-08 23:46:45Z andrewross $
+// $Id: plstream.h 10304 2009-08-20 09:05:43Z andrewross $
 // Geoffrey Furnish
 // Sep 21 1994
 //
@@ -121,6 +121,11 @@ class PLDLLIMPEXP_CXX plstream {
 
     void adv( PLINT page );
 
+// Plot an arc
+
+    void arc( PLFLT x, PLFLT y, PLFLT a, PLFLT b, PLFLT angle1, PLFLT angle2,
+                  PLBOOL fill );
+
 // Simple arrow plotter
     void arrows( PLFLT *u, PLFLT *v, PLFLT *x, PLFLT *y, PLINT n,
                  PLFLT scale, PLFLT dx, PLFLT dy );
@@ -157,6 +162,11 @@ class PLDLLIMPEXP_CXX plstream {
 	       const char *yopt, const char *ylabel, PLFLT ytick, PLINT nsuby,
 	       const char *zopt, const char *zlabel, PLFLT ztick, PLINT nsubz );
 
+// Calculate broken-down time from continuous time for current stream.
+
+    void btime( PLINT &year, PLINT &month, PLINT &day, PLINT &hour, 
+		  PLINT &min, PLFLT &sec, PLFLT ctime );
+
 // Calculate world coordinates and subpage from relative device coordinates.
     
     void calc_world(PLFLT rx, PLFLT ry, PLFLT& wx, PLFLT& wy, PLINT& window);
@@ -183,6 +193,12 @@ class PLDLLIMPEXP_CXX plstream {
 // avoided in new code.
     void col( PLFLT c );
 
+// Configure transformation between continuous and broken-down time (and
+// vice versa) for current stream.
+    void configtime( PLFLT scale, PLFLT offset1, PLFLT offset2, 
+		     PLINT ccontrol, PLBOOL ifbtime_offset, PLINT year, 
+		     PLINT month, PLINT day, PLINT hour, PLINT min, PLFLT sec);
+  
 // Draws a contour plot from data in f(nx,ny).  Is just a front-end to
 // plfcont, with a particular choice for f2eval and f2eval_data.
 
@@ -207,6 +223,9 @@ class PLDLLIMPEXP_CXX plstream {
 
      void cpstrm( plstream &pls, bool flags );
 
+// Calculate continuous time from broken-down time for current stream.
+     void ctime(PLINT year, PLINT month, PLINT day, PLINT hour, PLINT min, PLFLT sec, PLFLT &ctime);
+  
 // Converts input values from relative device coordinates to relative plot
 // coordinates.
 
@@ -723,6 +742,11 @@ void pat( PLINT nlin, PLINT *inc, PLINT *del );
 		 void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
 		 PLPointer pltr_data );
 
+/* Setup a user-provided custom labeling function */
+
+    void slabelfunc( void (*label_func)(PLINT, PLFLT, char *, PLINT, PLPointer),
+                         PLPointer label_data );
+
 /* Set up lengths of major tick marks. */
 
     void smaj( PLFLT def, PLFLT scale );
@@ -744,6 +768,14 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 
     void spause( bool pause );
 
+/* Set the colors for color table 0 from a cmap0 file */
+
+    void spal0(const char *filename);
+
+/* Set the colors for color table 1 from a cmap1 file */
+
+    void spal1(const char *filename, bool interpolate = true);
+
 /* Set stream number.  */
 
     void sstrm( PLINT strm );
@@ -936,8 +968,8 @@ void spage( PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 //     void tr2f( PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, void *pltr_data );
 
 /* Example linear transformation function for contour plotter. */
-
-    void  xform( PLFLT x, PLFLT y, PLFLT * tx, PLFLT * ty );
+/* This is not actually part of the core library any more */
+    //void  xform( PLFLT x, PLFLT y, PLFLT * tx, PLFLT * ty );
 
 	/* Function evaluators */
 
