@@ -1,4 +1,4 @@
-/* $Id: plstubs.h 8953 2008-10-22 04:25:30Z arjenmarkus $
+/* $Id: plstubs.h 10281 2009-08-18 13:52:20Z andrewross $
 
    Maurice LeBrun
    IFS, University of Texas
@@ -167,11 +167,13 @@
 #define    PL_SETCONTLABELPARAMa	FNAME(PL_SETCONTLABELPARAM_,pl_setcontlabelparam_)
 #define    PLABORT7	FNAME(PLABORT7,plabort7)
 #define    PLADV	FNAME(PLADV,pladv)
+#define    PLARC	FNAME(PLARC,plarc)
 #define    PLAXES7	FNAME(PLAXES7,plaxes7)
 #define    PLBIN	FNAME(PLBIN,plbin)
 #define    PLBOP	FNAME(PLBOP,plbop)
 #define    PLBOX37	FNAME(PLBOX37,plbox37)
 #define    PLBOX7	FNAME(PLBOX7,plbox7)
+#define    PLBTIME	FNAME(PLBTIME,plbtime)
 #define    PLCALC_WORLD 	FNAME(PLCALC_WORLD,plcalc_world)
 #define    PLCALC_WORLDa	FNAME(PLCALC_WORLD_,plcalc_world_)
 #define    PLCLEAR	FNAME(PLCLEAR,plclear)
@@ -179,11 +181,13 @@
 #define    PLCOL	FNAME(PLCOL,plcol)
 #define    PLCOL0	FNAME(PLCOL0,plcol0)
 #define    PLCOL1	FNAME(PLCOL1,plcol1)
+#define    PLCONFIGTIME	FNAME(PLCONFIGTIME,plconfigtime)
 #define    PLCON07	FNAME(PLCON07,plcon07)
 #define    PLCON17	FNAME(PLCON17,plcon17)
 #define    PLCON27	FNAME(PLCON27,plcon27)
 #define    PLCONT7	FNAME(PLCONT7,plcont7)
 #define    PLCPSTRM	FNAME(PLCPSTRM,plcpstrm)
+#define    PLCTIME	FNAME(PLCTIME,plctime)
 #define    PLEND	FNAME(PLEND,plend)
 #define    PLEND1	FNAME(PLEND1,plend1)
 #define    PLENV	FNAME(PLENV,plenv)
@@ -299,11 +303,14 @@
 #define    PLSHADES17	FNAME(PLSHADES17,plshades17)
 #define    PLSHADES27	FNAME(PLSHADES27,plshades27)
 #define    PLSHADES7	FNAME(PLSHADES7,plshades7)
+#define    PLSLABELFUNC FNAME(PLSLABELFUNC,plslabelfunc)
 #define    PLSMAJ	FNAME(PLSMAJ,plsmaj)
 #define    PLSMEM	FNAME(PLSMEM,plsmem)
 #define    PLSMIN	FNAME(PLSMIN,plsmin)
 #define    PLSORI	FNAME(PLSORI,plsori)
 #define    PLSPAGE	FNAME(PLSPAGE,plspage)
+#define    PLSPAL07     FNAME(PLSPAL07,plspal07)
+#define    PLSPAL17     FNAME(PLSPAL17,plspal17)
 #define    PLSPAUSE	FNAME(PLSPAUSE,plspause)
 #define    PLSSTRM	FNAME(PLSSTRM,plsstrm)
 #define    PLSSUB	FNAME(PLSSUB,plssub)
