@@ -1,4 +1,4 @@
-/* $Id: scstubs.c 9278 2009-01-08 14:30:16Z andrewross $
+/* $Id: scstubs.c 10304 2009-08-20 09:05:43Z andrewross $
 
 	C stub routines.
 
@@ -29,8 +29,16 @@
 
 #include "plstubs.h"
 
-static void (*plmapform)(PLINT *, PLFLT *, PLFLT *) ; /* Note: slightly different prototype than
-                                                         (*mapform)! */
+#ifdef CVF
+#define STDCALL __stdcall
+#else
+#define STDCALL
+#endif
+static void (STDCALL *plmapform)(PLINT *, PLFLT *, PLFLT *) ; /* Note: slightly different prototype than
+                                                                 (*mapform)! */
+/* Slightly different to (*label_func) as we don't support PLPointer for
+ * additional data in f77. */
+static void (STDCALL *pllabelfunc)(PLINT *, PLFLT *, char *, PLINT *);
 
 void
 PL_SETCONTLABELFORMAT(PLINT *lexp, PLINT *sigdig)
@@ -68,6 +76,12 @@ PLADV(PLINT *sub)
     c_pladv(*sub);
 }
 
+void
+PLARC(PLFLT *x, PLFLT *y, PLFLT *a, PLFLT *b, PLFLT *angle1, PLFLT *angle2, PLBOOL *fill)
+{
+  c_plarc(*x, *y, *a, *b, *angle1, *angle2, *fill);
+}
+
 void
 PLAXES7(PLFLT *x0, PLFLT *y0, const char *xopt, PLFLT *xtick,
 	PLINT *nxsub, const char *yopt, PLFLT *ytick, PLINT *nysub)
@@ -81,6 +95,12 @@ PLBIN(PLINT *nbin, PLFLT *x, PLFLT *y, PLINT *center)
     c_plbin(*nbin, x, y, *center);
 }
 
+void
+PLBTIME(PLINT *year, PLINT *month, PLINT *day, PLINT *hour, PLINT *min, PLFLT *sec, PLFLT *ctime)
+{
+  c_plbtime(year, month, day, hour, min, sec, *ctime);
+}
+
 void
 PLBOP(void)
 {
@@ -142,12 +162,24 @@ PLCOL(PLINT *icol)
     c_plcol0(*icol);
 }
 
+void
+PLCONFIGTIME(PLFLT *scale, PLFLT *offset1, PLFLT *offset2, PLINT *ccontrol, PLBOOL *ifbtime_offset, PLINT *year, PLINT *month, PLINT *day, PLINT *hour, PLINT *min, PLFLT *sec) 
+{
+    c_plconfigtime(*scale, *offset1, *offset2, *ccontrol, *ifbtime_offset, *year, *month, *day, *hour, *min, *sec);
+}
+
 void
 PLCPSTRM(PLINT *iplsr, PLBOOL *flags)
 {
     c_plcpstrm(*iplsr, *flags);
 }
 
+void
+PLCTIME(PLINT *year, PLINT *month, PLINT *day, PLINT *hour, PLINT *min, PLFLT *sec, PLFLT *ctime)
+{
+    c_plctime(*year, *month, *day, *hour, *min, *sec, ctime);
+}
+
 void
 PLEND(void)
 {
@@ -265,7 +297,7 @@ PLGCOMPRESSION(PLINT *compression)
 }
 
 void
-PLGDEV7(char *dev, int length )
+PLGDEV7(char *dev, int length)
 {
     c_plgdev(dev);
 }
@@ -300,15 +332,13 @@ PLGFAM(PLINT *fam, PLINT *num, PLINT *bmax)
     c_plgfam(fam, num, bmax);
 }
 
-/* Note: Fortran does not have unsigned integers so we need to use a
- * 64 bit signed integer which corresponds to a fortran integer*8
- * in order to contain the number.  */
+/* Note: Fortran does not distinguish between unsigned and signed integers
+   so the 32-bit PLUNICODE can be mapped to 4-byte Fortran integer outside
+   this routine. */
 void
-PLGFCI(PLINT64 *pfci)
+PLGFCI(PLUNICODE *pfci)
 {
-    PLUNICODE fci;
-    c_plgfci(&fci);
-    *pfci = (PLINT64) fci;
+    c_plgfci(pfci);
 }
 
 void
@@ -489,6 +519,21 @@ PLLAB7(const char *xlab, const char *ylab, const char *title)
     c_pllab(xlab, ylab, title);
 }
 
+static void
+pllabelfuncf2c( PLINT axis, PLFLT value, char *label, PLINT length, PLPointer data)
+{
+    int i;
+
+    (*pllabelfunc)( &axis, &value, label, &length );
+
+    /* Ensure string is null terminated */
+    i = length-1;
+    while ((i >= 0) && (label[i]== ' '))
+      i--;
+    label[i+1] = '\0';
+
+}
+
 void
 PLLIGHTSOURCE(PLFLT *x, PLFLT *y, PLFLT *z)
 {
@@ -812,7 +857,7 @@ PLSESC(PLINT *esc)
 */
 #define    PLSETMAPFORMC	FNAME(PLSETMAPFORMC,plsetmapformc)
 void
-PLSETMAPFORMC( void (*mapform)(PLINT *, PLFLT *, PLFLT *) )
+PLSETMAPFORMC( void (STDCALL *mapform)(PLINT *, PLFLT *, PLFLT *) )
 {
     plmapform = mapform ;
 }
@@ -829,16 +874,13 @@ PLSFAM(PLINT *fam, PLINT *num, PLINT *bmax)
     c_plsfam(*fam, *num, *bmax);
 }
 
-/* Note: Fortran does not have unsigned integers so we need to use a
- * 64 bit signed integer which corresponds to a fortran integer*8
- * in order to contain the number.  */
-/* PLSFCI(PLINT64 *fci) */
+/* Note: Fortran does not distinguish between unsigned and signed integers
+   so the 32-bit PLUNICODE can be mapped to 4-byte Fortran integer outside
+   this routine. */
 void
-PLSFCI(PLINT64 *fci)
+PLSFCI(PLUNICODE *fci)
 {
-    PLUNICODE f;
-    f = (PLUNICODE) (*fci & 0xffffffff);
-    c_plsfci(f);
+    c_plsfci(*fci);
 }
 
 void
@@ -853,6 +895,14 @@ PLSFONT(PLINT *family, PLINT *style, PLINT *weight)
     c_plsfont(*family, *style, *weight);
 }
 
+void
+PLSLABELFUNC( void (STDCALL *labelfunc)(PLINT *, PLFLT *, char *, PLINT *))
+{
+    pllabelfunc = labelfunc;
+    /* N.B. neglect pointer to additional data for f77 */
+    c_plslabelfunc(pllabelfuncf2c, NULL);
+}
+
 void
 PLSMAJ(PLFLT *def, PLFLT *scale)
 {
@@ -884,6 +934,18 @@ PLSPAGE(PLFLT *xpmm, PLFLT *ypmm,
     c_plspage(*xpmm, *ypmm, *xwid, *ywid, *xoff, *yoff);
 }
 
+void
+PLSPAL07(const char *filename)
+{
+  c_plspal0(filename);
+}
+
+void
+PLSPAL17(const char *filename, PLBOOL *interpolate)
+{
+  c_plspal1(filename,*interpolate);
+}
+
 void
 PLSPAUSE(PLBOOL *pause)
 {
