@@ -1,5 +1,5 @@
 !***********************************************************************
-!  $Id: sfstubs.f90 8578 2008-07-24 13:11:19Z andrewross $
+!  $Id: sfstubs.f90 10304 2009-08-20 09:05:43Z andrewross $
 !  sfstubs.f
 !
 !  Copyright (C) 2004  Alan W. Irwin
@@ -669,6 +669,39 @@
 
       end subroutine
 
+!***********************************************************************
+
+      subroutine plspal0(filename)
+
+      implicit none
+      character*(*) filename
+
+      include 'sfstubs.h'
+
+      call plstrf2c(filename, string1, maxlen)
+
+      s1 = transfer( string1, s1 )
+      call plspal07(s1)
+
+      end subroutine
+
+!***********************************************************************
+
+      subroutine plspal1(filename,interpolate)
+
+      implicit none
+      character*(*) filename
+      integer interpolate
+
+      include 'sfstubs.h'
+
+      call plstrf2c(filename, string1, maxlen)
+
+      s1 = transfer( string1, s1 )
+      call plspal17(s1,interpolate)
+
+      end subroutine
+
 !***********************************************************************
 
       subroutine plmtex(side,disp,pos,xjust,text)
