@@ -1,5 +1,5 @@
 !***********************************************************************
-!  $Id: sfstubsf95.f90 8189 2008-01-29 21:04:48Z andrewross $
+!  $Id: sfstubsf95.f90 9133 2008-12-16 14:12:45Z andrewross $
 !  sfstubsf95.f
 !
 !  Copyright (C) 2005, 2006  Arjen Markus
@@ -100,13 +100,38 @@
          end interface
          private :: plshades_multiple_0, plshades_multiple_1, &
                     plshades_multiple_2, plshades_multiple_tr
+
+         interface plimagefr
+            module procedure plimagefr_0
+            module procedure plimagefr_1
+            module procedure plimagefr_2
+            module procedure plimagefr_tr
+         end interface
+         private :: plimagefr_0, plimagefr_1, plimagefr_2, plimagefr_tr
+
       contains
          include 'sfstubs.f90'
       end module plplotp
 
+      module plplot_types
+        use plplot_flt
+        type :: PLGraphicsIn
+           integer type          ! of event (CURRENTLY UNUSED)
+           integer state         ! key or button mask
+           integer keysym        ! key selected
+           integer button        ! mouse button selected
+           integer subwindow     ! subwindow (alias subpage, alias subplot) number
+           character(len=16) string   ! translated string
+           integer pX, pY        ! absolute device coordinates of pointer
+           real(kind=plflt) dX, dY    ! relative device coordinates of pointer
+           real(kind=plflt) wX, wY    ! world coordinates of pointer
+        end type PLGraphicsIn
+      end module plplot_types
+
       module plplot
       use plplotp
       use plplot_flt
+      use plplot_types
       !
       ! To be added: renaming list
       !
@@ -144,6 +169,8 @@
       integer, parameter :: PL_FONT_STANDARD   =  0
       integer, parameter :: PL_FONT_EXTENDED   =  1
 
+      real(kind=plflt), parameter :: PL_NOTSET = -42.0_plflt
+
       !
       ! TODO:
       ! Parameters for fill patterns and symbols
@@ -328,12 +355,33 @@
          end subroutine plgdiplt
       end interface
 
+      interface
+         subroutine plgetcursor( gin )
+           use plplot_flt
+           use plplot_types
+           type(PLGraphicsIn) :: gin
+         end subroutine plgetcursor
+      end interface
+
       interface
          subroutine plgfam( fam, num, bmax )
             integer :: fam, num, bmax
          end subroutine plgfam
       end interface
 
+      interface
+         subroutine plgfci( fci )
+            use plplot_flt
+            integer(kind=plunicode) :: fci
+         end subroutine plgfci
+      end interface
+
+      interface
+         subroutine plgfont( family, style, weight )
+            integer :: family, style, weight
+         end subroutine plgfont
+      end interface
+
       interface
          subroutine plglevel( level )
             integer :: level
@@ -653,6 +701,12 @@
          end subroutine plsdiplz
       end interface
 
+      interface
+         subroutine plseed( s )
+           integer :: s
+         end subroutine plseed
+      end interface
+
       ! TODO: character-version
       interface
          subroutine plsesc( esc )
@@ -682,6 +736,19 @@
          end subroutine plsfam
       end interface
 
+      interface
+         subroutine plsfci( fci )
+            use plplot_flt
+            integer(kind=plunicode) :: fci
+         end subroutine plsfci
+      end interface
+
+      interface
+         subroutine plsfont( family, style, weight )
+            integer :: family, style, weight
+         end subroutine plsfont
+      end interface
+
       interface
          subroutine plsmaj( def, scale )
             use plplot_flt
@@ -700,8 +767,7 @@
 
       interface
          subroutine plsori( rot )
-            use plplot_flt
-            real(kind=plflt) :: rot
+            integer :: rot
          end subroutine plsori
       end interface
 
@@ -737,9 +803,8 @@
       end interface
 
       interface
-         subroutine plstar( x, y )
-            use plplot_flt
-            real(kind=plflt) :: x, y
+         subroutine plstar( nx, ny )
+            integer :: nx, ny
          end subroutine plstar
       end interface
 
@@ -922,8 +987,9 @@
       end subroutine plfill3
 
       subroutine plgriddata( x, y, z, xg, yg, zg, type, data )
-         real(kind=plflt), dimension(:)   :: x, y, z, xg, yg, data
+         real(kind=plflt), dimension(:)   :: x, y, z, xg, yg
          real(kind=plflt), dimension(:,:) :: zg
+         real(kind=plflt)                 :: data
          integer                          :: type
 
          call plgriddataf77( x, y, z, size(x), xg, size(xg), yg, size(yg), zg, &
@@ -940,6 +1006,35 @@
          call plhistf77( size(data), data, datmin, datmax, nbin, oldwin )
       end subroutine plhist
 
+!     subroutine plimagefr( idata, xmin, xmax, ymin, ymax, zmin, zmax, &
+!                           dxmin, dxmax, dymin, dymax, valuemin, valuemax )
+!        real(kind=plflt), dimension(:,:) :: idata
+!        real(kind=plflt)                 :: xmin,  xmax,  ymin,  ymax,  zmin, zmax
+!        real(kind=plflt)                 :: dxmin, dxmax, dymin, dymax, &
+!                                            valuemin, valuemax
+!
+!        integer                          :: nx, ny
+!
+!        nx = size(idata,1)
+!        ny = size(idata,2)
+!        call plimagefrf77( idata, nx, ny, xmin, xmax, ymin, ymax, zmin, zmax, &
+!                           dxmin, dxmax, dymin, dymax, valuemin, valuemax )
+!     end subroutine plimagefr
+
+      subroutine plimage( idata, xmin, xmax, ymin, ymax, zmin, zmax, &
+                          dxmin, dxmax, dymin, dymax )
+         real(kind=plflt), dimension(:,:) :: idata
+         real(kind=plflt)                 :: xmin,  xmax,  ymin,  ymax,  zmin, zmax
+         real(kind=plflt)                 :: dxmin, dxmax, dymin, dymax
+
+         integer                          :: nx, ny
+
+         nx = size(idata,1)
+         ny = size(idata,2)
+         call plimagef77( idata, nx, ny, xmin, xmax, ymin, ymax, zmin, zmax, &
+                          dxmin, dxmax, dymin, dymax )
+      end subroutine plimage
+
       subroutine plline( x, y )
          real(kind=plflt), dimension(:) :: x, y
 
@@ -1042,6 +1137,13 @@
          call plpoly3f77( size(x), x, y, z, idraw, iifcc )
       end subroutine plpoly3
 
+      real (kind=plflt) function plrandd()
+        external plranddf77
+        real(kind=plflt) :: plranddf77
+
+        plrandd = plranddf77()
+      end function plrandd
+
       subroutine plscmap0( r, g, b )
          integer, dimension(:) :: r, g, b
 
