@@ -118,6 +118,11 @@ public void adv(int page) {
     plplotjavac.pladv(page);
 }
 
+public void arc(double x, double y, double a, double b, double angle1, double angle2, boolean fill ) {
+    if (set_stream() == -1) return;
+    plplotjavac.plarc(x, y, a, b, angle1, angle2, fill);
+}
+
 public void axes(double x0, double y0, String xopt, double xtick, int nxsub, 
 		 String yopt, double ytick, int nysub) {
     if (set_stream() == -1) return;
@@ -148,6 +153,11 @@ public void box3(String xopt, String xlabel, double xtick, int nsubx,
 		    zopt, zlabel, ztick, nsubz);
 }
 
+public void btime(int year[], int month[], int day[], int hour[], int min[], double sec[], double ctime) {
+    if (set_stream() == -1) return;
+    plplotjavac.plbtime(year, month, day, hour, min, sec, ctime);
+}
+
 public void calc_world(double rx, double ry, double[] wx, double[] wy, int[] window) {
     if (set_stream() == -1) return;
     plplotjavac.plcalc_world(rx, ry, wx, wy, window);
@@ -168,6 +178,15 @@ public void col1(double col1) {
     plplotjavac.plcol1(col1);
 }
 
+public void configtime( double scale, double offset1, double offset2, 
+			int ccontrol, boolean ifbtime_offset, int year, 
+			int month, int day, int hour, int min, 
+			double sec) {
+    if (set_stream() == -1) return;
+    plplotjavac.plconfigtime(scale, offset1, offset2, ccontrol, ifbtime_offset,
+			     year, month, day, hour, min, sec);
+}
+
 public void cont(double[][] f, int kx, int lx, int ky, int ly, 
 		double[] clevel, double[][] pltr, double[][] OBJECT_DATA) {
     if (set_stream() == -1) return;
@@ -179,6 +198,11 @@ public void cpstrm(PLStream pls, boolean flags) {
     plplotjavac.plcpstrm(pls.stream_id, flags);
 }
 
+public void ctime(int year, int month, int day, int hour, int min, double sec, double ctime[]) {
+    if (set_stream() == -1) return;
+    plplotjavac.plctime(year, month, day, hour, min, sec, ctime);
+}
+
 // The end / end1 functions have extra code in to keep track of the
 // stream references in the class. 
 public void end() {
@@ -445,12 +469,12 @@ public void lsty(int lin) {
     plplotjavac.pllsty(lin);
 }
 
-public void map(PLCallback mapform, String type, double minlong, double maxlong, double minlat, double maxlat) {
+public void map(PLCallbackMapform mapform, String type, double minlong, double maxlong, double minlat, double maxlat) {
     if (set_stream() == -1) return;
     plplotjavac.plmap(mapform, type, minlong, maxlong, minlat, maxlat);
 }
 
-public void meridians(PLCallback mapform, double dlong, double dlat, double minlong, double maxlong, double minlat, double maxlat) {
+public void meridians(PLCallbackMapform mapform, double dlong, double dlat, double minlong, double maxlong, double minlat, double maxlat) {
     if (set_stream() == -1) return;
     plplotjavac.plmeridians(mapform, dlong, dlat, minlong, maxlong, minlat, maxlat);
 }
@@ -744,6 +768,16 @@ public void shade(double[][] a, double left, double right, double bottom,
 		    max_color, max_width, rectangular, pltr, OBJECT_DATA);
 }
 
+public void slabelfunc(PLCallbackLabel label, Object obj) {
+   if (set_stream() == -1) return;
+   plplotjavac.plslabelfunc(label,obj);
+}
+
+public void slabelfunc(PLCallbackLabel label) {
+   if (set_stream() == -1) return;
+   plplotjavac.plslabelfunc(label,null);
+}
+
 public void smaj(double def, double scale) {
     if (set_stream() == -1) return;
     plplotjavac.plsmaj(def, scale);
@@ -764,6 +798,16 @@ public void spage(double xp, double yp, int xleng, int yleng, int xoff, int yoff
     plplotjavac.plspage(xp, yp, xleng, yleng, xoff, yoff);
 }
 
+public void spal0(String filename) {
+    if (set_stream() == -1) return;
+    plplotjavac.plspal0(filename);
+}
+
+public void spal1(String filename, boolean interpolate) {
+    if (set_stream() == -1) return;
+    plplotjavac.plspal1(filename,interpolate);
+}
+
 public void spause(boolean pause) {
     if (set_stream() == -1) return;
     plplotjavac.plspause(pause);
