@@ -21,13 +21,8 @@ function __pl_contour(x, y, z, n)
 
   unwind_protect
     
-  if (exist("warn_empty_list_elements"))
-    old_empty_list_elements_ok = warn_empty_list_elements;
-  warn_empty_list_elements = 0;
-  else
-    old_empty_list_elements_ok = warning("query","Octave:empty-list-elements");
-    warning("off","Octave:empty-list-elements");
-  endif
+  old_empty_list_elements_ok = warning("query","Octave:empty-list-elements");
+  warning("off","Octave:empty-list-elements");
 
   grid = 0;
   if (__pl.grid(strm))
@@ -117,11 +112,7 @@ function __pl_contour(x, y, z, n)
 
   unwind_protect_cleanup  
   
-  if (exist("warn_empty_list_elements"))
-    warn_empty_list_elements = old_empty_list_elements_ok;
-  else
-    warning(old_empty_list_elements_ok.state,"Octave:empty-list-elements");
-  endif
+  warning(old_empty_list_elements_ok.state,"Octave:empty-list-elements");
 
   end_unwind_protect  
 
