@@ -28,6 +28,14 @@ void plfcont(PLFLT (*f2eval) (PLINT, PLINT, PLPointer),
 	void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
 	PLPointer pltr_data);  //%nowrap
 
+/* Plot an image with distortion */
+
+void plimagefr(PLFLT **idata, PLINT nx, PLINT ny,
+	       PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, 
+	       PLFLT zmin, PLFLT zmax, PLFLT valuemin, PLFLT valuemax,
+	       void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+	  PLPointer pltr_data);  //%nowrap
+  
 /* plot continental outline in world coordinates */
 
 void plmap(void (*mapform)(PLINT, PLFLT *, PLFLT *), char *type,
@@ -102,7 +110,7 @@ void c_plstripc(PLINT *id, char *xspec, char *yspec,
 /* Plot vector arrows */
 void c_plvect(PLFLT **u, PLFLT **v, PLINT nx, PLINT ny, PLFLT scale,
 	void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
-	PLPointer pltr_data);
+	PLPointer pltr_data); //%nowrap
 
 
 /* Set the function pointer for the keyboard event handler */
@@ -116,4 +124,4 @@ void plsButtonEH(void (*ButtonEH) (PLGraphicsIn *, void *, int *),
 	    
 /* Sets an optional user exit handler. */
 
-void plsexit(int (*handler) (char *));   
+void plsexit(int (*handler) (char *));  //%nowrap 
