@@ -1,4 +1,4 @@
-/* $Id: matrixInit.c 7082 2006-09-18 04:36:21Z arjenmarkus $
+/* $Id: matrixInit.c 8876 2008-10-10 20:30:22Z airwin $
 
     Tcl Matrix initializer.
     Vince Darley
@@ -26,7 +26,7 @@
 #include "pldll.h"
 #include "tclMatrix.h"
 
-int PLDLLIMPEXP Matrix_Init( Tcl_Interp *interp ) {
+int Matrix_Init( Tcl_Interp *interp ) {
 
     /* matrix -- matrix	support	command	*/
     Tcl_CreateCommand(interp, "matrix",	(Tcl_CmdProc *) Tcl_MatrixCmd,
