@@ -1,4 +1,4 @@
-/* $Id: tclAPI.c 9324 2009-01-16 11:12:39Z andrewross $
+/* $Id: tclAPI.c 10169 2009-07-20 21:12:55Z andrewross $
 
     Copyright 1994, 1995
     Maurice LeBrun			mjl@dino.ph.utexas.edu
@@ -34,7 +34,7 @@
 #include "plplotP.h"
 #include "pltcl.h"
 #ifndef __WIN32__
-#ifdef HAVE_UNISTD_H
+#ifdef PL_HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #else
