@@ -1,4 +1,4 @@
-/* $Id: tclMain.c 8186 2008-01-29 10:50:48Z andrewross $
+/* $Id: tclMain.c 9116 2008-12-15 12:40:45Z andrewross $
  *
  * Modified version of tclMain.c, from Tcl 8.3.2.
  * Maurice LeBrun
@@ -45,13 +45,11 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclMain.c 8186 2008-01-29 10:50:48Z andrewross $
+ * RCS: @(#) $Id: tclMain.c 9116 2008-12-15 12:40:45Z andrewross $
  */
 
 #include <tcl.h>
 #include "plplot.h"
-#define MAKINGPLDLL
-#include "pldll.h"
 
 #ifdef HAVE_TCL_GT_84
 /* From (private) tclInt.h in tcl8.5 */
