@@ -1,4 +1,4 @@
-/* $Id: plplotter.c 8196 2008-01-30 15:59:12Z andrewross $
+/* $Id: plplotter.c 10169 2009-07-20 21:12:55Z andrewross $
  * Copyright (C) 2004  Joao Cardoso
  *
  * This file is part of PLplot.
@@ -82,7 +82,7 @@
 #endif
 
 #ifndef __WIN32__
-#ifdef HAVE_UNISTD_H
+#ifdef PL_HAVE_UNISTD_H
 #include <unistd.h>
 #include <fcntl.h>
 #endif
