@@ -1,4 +1,4 @@
-/* $Id: plframe.c 8353 2008-04-02 04:24:26Z arjenmarkus $
+/* $Id: plframe.c 10169 2009-07-20 21:12:55Z andrewross $
 
     Copyright 1993, 1994, 1995
     Maurice LeBrun			mjl@dino.ph.utexas.edu
@@ -54,7 +54,7 @@
 #include "plxwd.h"
 #include "tcpip.h"
 
-#ifdef HAVE_UNISTD_H
+#ifdef PL_HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #include <fcntl.h>
