@@ -1,4 +1,4 @@
-/* $Id: plserver.h 8186 2008-01-29 10:50:48Z andrewross $
+/* $Id: plserver.h 9885 2009-05-02 22:09:40Z airwin $
  *
  * Maurice LeBrun
  * 6-May-93
@@ -43,12 +43,12 @@ plPlotterCmd(ClientData clientData, Tcl_Interp *interp,
 /* plr.c */
 /* Set default state parameters before anyone else has a chance to. */
 
-void
+PLDLLIMPEXP_TCLTK void
 plr_start(PLRDev *plr);
 
 /* Read & process commands until "nbyte_max" bytes have been read. */
 
-int
+PLDLLIMPEXP_TCLTK int
 plr_process(PLRDev *plr);
 
 #endif	/* __PLSERVER_H__ */
