@@ -1,4 +1,4 @@
-/* $Id: pltk.h 8198 2008-01-30 18:58:16Z andrewross $
+/* $Id: pltk.h 8877 2008-10-10 20:31:23Z airwin $
  *
  * Maurice LeBrun
  * 28-Apr-95
@@ -23,12 +23,12 @@ extern "C" {
 #define TCL_STORAGE_CLASS DLLEXPORT
 #endif /* BUILD_Vfs */
 
-EXTERN int
+EXTERN PLDLLIMPEXP_TCLTK int
 Pltk_Init( Tcl_Interp *interp );
 
 /* Main program for wish, with PLplot extensions. */
 
-int
+EXTERN PLDLLIMPEXP_TCLTK int
 pltkMain(int argc, const char **argv, char *RcFileName,
 	 int (*AppInit)(Tcl_Interp *interp));
 
