@@ -1,4 +1,4 @@
-# $Id: pltools.tcl 4229 2002-12-29 22:55:21Z mlebrun $
+# $Id: pltools.tcl 8312 2008-03-22 16:23:58Z mlebrun $
 
 #----------------------------------------------------------------------------
 # PLPLOT TK/TCL graphics renderer support procs
@@ -258,7 +258,7 @@ proc max {args} {
 proc fileSelect {{filter {}}} {
 
     # Use the Iwidgets file selector if available
-    if ![catch {package require Iwidgets 3.0}] {
+    if ![catch {package require Iwidgets}] {
 	if {![winfo exist .fs]} {
 	    iwidgets::fileselectiondialog .fs -modality application
 	}
