@@ -1,4 +1,4 @@
-/* $Id: tcpip.c 8353 2008-04-02 04:24:26Z arjenmarkus $
+/* $Id: tcpip.c 10169 2009-07-20 21:12:55Z andrewross $
  *
  * Maurice LeBrun
  * 6-Jan-94
@@ -93,7 +93,7 @@
 #if defined(__sgi) && !defined(SVR3)
 #include <sys/select.h>
 #endif
-#ifdef HAVE_UNISTD_H
+#ifdef PL_HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
