@@ -1,4 +1,4 @@
-/* $Id: tcpip.h 4103 2002-12-03 08:39:28Z airwin $
+/* $Id: tcpip.h 9885 2009-05-02 22:09:40Z airwin $
  *
  * Maurice LeBrun
  * 31-May-95
@@ -15,13 +15,13 @@
 
 /* Modified version of the "Tdp_PacketSend" command. */
 
-int
+PLDLLIMPEXP_TCLTK int
 pl_PacketSend		PLARGS((Tcl_Interp *interp, PLiodev *iodev,
 				PDFstrm *pdfs));
 
 /* Modified version of the "Tdp_PacketReceive" command. */
 
-int
+PLDLLIMPEXP_TCLTK int
 pl_PacketReceive	PLARGS((Tcl_Interp *interp, PLiodev *iodev,
 				PDFstrm *pdfs));
 
