@@ -1,4 +1,4 @@
-/* $Id: tkMain.c 8875 2008-10-10 20:27:47Z airwin $
+/* $Id: tkMain.c 9866 2009-04-30 09:08:06Z andrewross $
  *
  * Modified version of tkMain.c, from Tk 3.6.
  * Maurice LeBrun
@@ -185,6 +185,10 @@ pltkMain(int argc, const char **argv, char *RcFileName,
     char buf[20];
     int code;
 
+#ifdef HAVE_PTHREAD
+    XInitThreads();
+#endif
+
     Tcl_FindExecutable(argv[0]);
     interp = Tcl_CreateInterp();
 #ifdef TCL_MEM_DEBUG
