@@ -35,6 +35,7 @@
 
 /* PLplot header files (must occur before driver-dependent includes) */
 
+#include "plDevs.h"
 #include "plplotP.h"
 #include "drivers.h"
 
@@ -73,20 +74,30 @@ static int text_clipping;
 static int text_anti_aliasing;
 static int graphics_anti_aliasing;
 static int external_drawable;
+static int rasterize_image;
 static DrvOpt cairo_options[] = {{"text_clipping", DRV_INT, &text_clipping, "Use text clipping (text_clipping=0|1)"},
 				 {"text_anti_aliasing", DRV_INT, &text_anti_aliasing, "Set desired text anti-aliasing (text_anti_aliasing=0|1|2|3). The numbers are in the same order as the cairo_antialias_t enumeration documented at http://cairographics.org/manual/cairo-cairo-t.html#cairo-antialias-t)"},
 				 {"graphics_anti_aliasing", DRV_INT, &graphics_anti_aliasing, "Set desired graphics anti-aliasing (graphics_anti_aliasing=0|1|2|3). The numbers are in the same order as the cairo_antialias_t enumeration documented at http://cairographics.org/manual/cairo-cairo-t.html#cairo-antialias-t"},
 				 {"external_drawable", DRV_INT, &external_drawable, "Plot to external X drawable"},
+                                 {"rasterize_image", DRV_INT, &rasterize_image, "Raster or vector image rendering (rasterize_image=0|1)"},
                                  {NULL, DRV_INT, NULL, NULL}};
 
 typedef struct {
   cairo_surface_t *cairoSurface;
   cairo_t *cairoContext;
+  cairo_surface_t *cairoSurface_raster;
+  cairo_t *cairoContext_raster;
   short text_clipping;
   short text_anti_aliasing;
   short graphics_anti_aliasing;
-  PLFLT downscale;
+  short rasterize_image;
+  double downscale;
+  char *pangoMarkupString;
+  short upDown;
+  float fontSize;
 #if defined(PLD_xcairo)
+  cairo_surface_t *cairoSurface_X;
+  cairo_t *cairoContext_X;
   short exit_event_loop;
   Display *XDisplay;
   Window XWindow;
@@ -157,7 +168,10 @@ const char *envFamilyLookup[NPANGOLOOKUP] = {
   "PLPLOT_FREETYPE_SYMBOL_FAMILY"
 };
 
-char familyLookup[NPANGOLOOKUP][1024];
+#define FAMILY_LOOKUP_LEN 1024
+char familyLookup[NPANGOLOOKUP][FAMILY_LOOKUP_LEN];
+
+#define TAG_LEN 200
 
 const char *weightLookup[2] = {
   "normal",
@@ -187,20 +201,30 @@ const char *styleLookup[3] = {
 
 PLCairo *stream_and_font_setup(PLStream *, int);
 cairo_status_t write_to_stream(void *, unsigned char *, unsigned int);
+void set_clip(PLStream *pls);
 
 /* String processing */
 
 static void proc_str(PLStream *, EscText *);
+static void text_begin_cairo(PLStream *pls, EscText *args);
+static void text_char_cairo(PLStream *pls, EscText *args);
+static void text_esc_cairo(PLStream *pls, EscText *args);
+static void text_end_cairo(PLStream *pls, EscText *args);
 static char *ucs4_to_pango_markup_format(PLUNICODE *, int, float);
 static void open_span_tag(char *, PLUNICODE, float, int);
 static void close_span_tag(char *, int);
+static char *rise_span_tag(int, int);
 
 /* Graphics */
 
 static void set_current_context(PLStream *);
 static void poly_line(PLStream *, short *, short *, PLINT);
 static void filled_polygon(PLStream *pls, short *xa, short *ya, PLINT npts);
+static void arc(PLStream *, arc_struct *);
 static void rotate_cairo_surface(PLStream *, float, float, float, float, float, float);
+/* Rasterization of plotted material */
+static void start_raster(PLStream*);
+static void end_raster(PLStream*);
 
 /* PLplot interface functions */
 
@@ -213,6 +237,84 @@ void plD_tidy_cairo              (PLStream *);
 void plD_line_cairo              (PLStream *, short, short, short, short);
 void plD_polyline_cairo          (PLStream *, short *, short *, PLINT);
 
+/*----------------------------------------------------------------------
+  start_raster()
+
+  Set up off-screen rasterized rendering
+  ----------------------------------------------------------------------*/
+
+void start_raster(PLStream *pls)
+{
+  PLCairo *aStream;
+  cairo_surface_t *tmp_sfc;
+  cairo_t *tmp_context;
+
+  aStream = (PLCairo *)pls->dev;
+
+  /* Do not use the external surface if the user says not to */
+  if (!aStream->rasterize_image)
+    return;
+
+  /* Create an image surface and context for the offscreen rendering */
+  aStream->cairoSurface_raster =
+    cairo_image_surface_create(CAIRO_FORMAT_ARGB32, pls->xlength, pls->ylength);
+  aStream->cairoContext_raster = cairo_create(aStream->cairoSurface_raster);
+
+  /* Disable antialiasing for the raster surface.  The output seems to look
+     better that way. */
+  cairo_set_antialias(aStream->cairoContext_raster, CAIRO_ANTIALIAS_NONE);
+
+  /* Swap the raster and main plot surfaces and contexts */
+  tmp_sfc = aStream->cairoSurface;
+  tmp_context = aStream->cairoContext;
+  aStream->cairoSurface = aStream->cairoSurface_raster;
+  aStream->cairoContext = aStream->cairoContext_raster;
+  /* Save the main plot surface and context for when we are finished */
+  aStream->cairoSurface_raster = tmp_sfc;
+  aStream->cairoContext_raster = tmp_context;
+}
+
+/*----------------------------------------------------------------------
+  end_raster()
+
+  Finish off-screen rasterized rendering and copy the result on to the
+  main plot surface.
+  ----------------------------------------------------------------------*/
+
+void end_raster(PLStream *pls)
+{
+  PLCairo *aStream;
+  cairo_surface_t *tmp_sfc;
+  cairo_t *tmp_context;
+
+  aStream = (PLCairo *)pls->dev;
+
+  /* Do not use the external surface if the user says not to */
+  if (!aStream->rasterize_image)
+    return;
+
+  /* Some Cairo devices support delayed device setup (eg: xcairo with
+     external drawable and extcairo with an external context). */
+  if (aStream->cairoContext == NULL)
+    plexit("Can not plot to a Cairo device with no context");
+
+  /* Restore the main plot surface and context for future plotting */
+  tmp_sfc = aStream->cairoSurface;
+  tmp_context = aStream->cairoContext;
+  aStream->cairoSurface = aStream->cairoSurface_raster;
+  aStream->cairoContext = aStream->cairoContext_raster;
+  aStream->cairoSurface_raster = tmp_sfc;
+  aStream->cairoContext_raster = tmp_context;
+
+  /* Blit the raster surface on to the main plot */
+  cairo_set_source_surface(aStream->cairoContext, aStream->cairoSurface_raster, 0.0, 0.0);
+  cairo_paint(aStream->cairoContext);
+
+  /* Free the now extraneous surface and context */
+  cairo_destroy(aStream->cairoContext_raster);
+  cairo_surface_destroy(aStream->cairoSurface_raster);
+}
+
 /*----------------------------------------------------------------------
   plD_bop_cairo()
   
@@ -232,11 +334,12 @@ void plD_bop_cairo(PLStream *pls)
 
   /* Fill in the window with the background color. */
   cairo_rectangle(aStream->cairoContext, 0.0, 0.0, pls->xlength, pls->ylength);
-  cairo_set_source_rgb(aStream->cairoContext,
+  cairo_set_source_rgba(aStream->cairoContext,
 		       (double)pls->cmap0[0].r/255.0,
 		       (double)pls->cmap0[0].g/255.0,
-		       (double)pls->cmap0[0].b/255.0);
-  cairo_fill(aStream->cairoContext);  
+		       (double)pls->cmap0[0].b/255.0,
+		       (double)pls->cmap0[0].a);
+  cairo_fill(aStream->cairoContext);
 }
 
 /*---------------------------------------------------------------------
@@ -245,17 +348,41 @@ void plD_bop_cairo(PLStream *pls)
   Draw a line in the current color from (x1,y1) to (x2,y2).
   ----------------------------------------------------------------------*/
 
+/*---------------------------------------------------------------------
+  (get|set)_line_properties
+
+  (Get|Set) the current Cairo line drawing properties.
+  ---------------------------------------------------------------------*/
+void get_line_properties(PLCairo *aStream, cairo_line_join_t *join, cairo_line_cap_t *cap)
+{
+  *join = cairo_get_line_join(aStream->cairoContext);
+  *cap = cairo_get_line_cap(aStream->cairoContext);
+}
+
+void set_line_properties(PLCairo *aStream, cairo_line_join_t join, cairo_line_cap_t cap)
+{
+    cairo_set_line_join(aStream->cairoContext, join);
+    cairo_set_line_cap(aStream->cairoContext, cap);
+}
+
 void plD_line_cairo(PLStream *pls, short x1a, short y1a, short x2a, short y2a)
 {
   PLCairo *aStream;
+  cairo_line_join_t old_join;
+  cairo_line_cap_t old_cap;
 
   aStream = (PLCairo *)pls->dev;
 
   set_current_context(pls);
 
+  get_line_properties(aStream, &old_join, &old_cap);
+  set_line_properties(aStream, old_join, CAIRO_LINE_CAP_ROUND);
+
   cairo_move_to(aStream->cairoContext, aStream->downscale * (double) x1a, aStream->downscale * (double) y1a);
   cairo_line_to(aStream->cairoContext, aStream->downscale * (double) x2a, aStream->downscale * (double) y2a);
   cairo_stroke(aStream->cairoContext);
+
+  set_line_properties(aStream, old_join, old_cap);
 }
 
 /*---------------------------------------------------------------------
@@ -267,11 +394,18 @@ void plD_line_cairo(PLStream *pls, short x1a, short y1a, short x2a, short y2a)
 void plD_polyline_cairo(PLStream *pls, short *xa, short *ya, PLINT npts)
 {
   PLCairo *aStream;
+  cairo_line_join_t old_join;
+  cairo_line_cap_t old_cap;
 
   aStream = (PLCairo *)pls->dev;
 
+  get_line_properties(aStream, &old_join, &old_cap);
+  set_line_properties(aStream, CAIRO_LINE_JOIN_BEVEL, CAIRO_LINE_CAP_BUTT);
+
   poly_line(pls, xa, ya, npts);
   cairo_stroke(aStream->cairoContext);
+
+  set_line_properties(aStream, old_join, old_cap);
 }
 
 /*---------------------------------------------------------------------
@@ -338,12 +472,210 @@ void plD_esc_cairo(PLStream *pls, PLINT op, void *ptr)
     case PLESC_FILL:     /* filled polygon */
       filled_polygon(pls, pls->dev_x, pls->dev_y, pls->dev_npts);
       break;
-    case PLESC_HAS_TEXT: /* render rext */
+    case PLESC_HAS_TEXT:
       proc_str(pls, (EscText *) ptr);
       break;
+    case PLESC_BEGIN_TEXT: /* get ready to get a handle a string of text */
+      text_begin_cairo(pls, (EscText *) ptr);
+      break;
+    case PLESC_TEXT_CHAR: /* handle a character of text to display */
+      text_char_cairo(pls, (EscText *) ptr);
+      break;
+    case PLESC_CONTROL_CHAR: /* handle a control character (super/subscript of fontchange) */
+      text_esc_cairo(pls, (EscText *) ptr);
+      break;
+    case PLESC_END_TEXT: /* finish a string of text */
+      text_end_cairo(pls, (EscText *) ptr);
+      break;
+    case PLESC_START_RASTERIZE: /* Start offscreen/rasterized rendering */
+      start_raster(pls);
+      break;
+    case PLESC_END_RASTERIZE: /* End offscreen/rasterized rendering */
+      end_raster(pls);
+      break;
+    case PLESC_ARC: /* Draw an arc, either filled or outline */
+      arc(pls, (arc_struct *) ptr);
+      break;
     }
 }
 
+/*---------------------------------------------------------------------
+  text_begin_cairo()
+  
+  Begin text.
+  ---------------------------------------------------------------------*/
+
+void text_begin_cairo(PLStream *pls, EscText *args)
+{
+  int i;
+  PLCairo *aStream;
+
+  aStream = (PLCairo *)pls->dev;
+  aStream->upDown = 0;
+  aStream->pangoMarkupString = (char *) malloc (sizeof(char) * MAX_MARKUP_LEN);
+  aStream->fontSize = pls->chrht * DPI/25.4;
+  for(i = 0; i < MAX_MARKUP_LEN; i++){
+    aStream->pangoMarkupString[i] = 0;
+  }
+  open_span_tag(aStream->pangoMarkupString, args->n_fci, aStream->fontSize, 0);
+}
+
+/*---------------------------------------------------------------------
+  text_char_cairo()
+  
+  Add text.
+  ---------------------------------------------------------------------*/
+
+void text_char_cairo(PLStream *pls, EscText *args)
+{
+  char utf8[5];
+  PLCairo *aStream;
+
+  aStream = (PLCairo *)pls->dev;
+  /* make sure we are not too close to the end of the string */
+  if(strlen(aStream->pangoMarkupString) < (MAX_MARKUP_LEN - 50)){
+    switch (args->n_char)
+      {
+      case 38:
+	strncat(aStream->pangoMarkupString, "&#38;", MAX_MARKUP_LEN-1-strlen(aStream->pangoMarkupString));
+	break;
+      case 60:
+	strncat(aStream->pangoMarkupString, "&#60;", MAX_MARKUP_LEN-1-strlen(aStream->pangoMarkupString));
+	break;
+      case 62:
+	strncat(aStream->pangoMarkupString, "&#62;", MAX_MARKUP_LEN-1-strlen(aStream->pangoMarkupString));
+	break;
+      default:
+	ucs4_to_utf8(args->n_char,utf8);
+	strncat(aStream->pangoMarkupString, utf8, MAX_MARKUP_LEN-1-strlen(aStream->pangoMarkupString));
+	break;
+      }
+  }
+}
+
+/*---------------------------------------------------------------------
+  text_esc_cairo()
+  
+  A font change, superscript, subscript, etc...
+  ---------------------------------------------------------------------*/
+
+void text_esc_cairo(PLStream *pls, EscText *args)
+{
+  PLCairo *aStream;
+
+  aStream = (PLCairo *)pls->dev;
+  switch(args->n_ctrl_char)
+    {
+    case PLTEXT_FONTCHANGE:
+      close_span_tag(aStream->pangoMarkupString, aStream->upDown);
+      open_span_tag(aStream->pangoMarkupString, args->n_fci, aStream->fontSize, aStream->upDown);
+      break;
+    case PLTEXT_SUPERSCRIPT:
+      if(aStream->upDown < 0){
+	strncat(aStream->pangoMarkupString, "</span>", MAX_MARKUP_LEN-1-strlen(aStream->pangoMarkupString));
+      } else {
+	strncat(aStream->pangoMarkupString, rise_span_tag(aStream->upDown, 1), MAX_MARKUP_LEN-1-strlen(aStream->pangoMarkupString));
+      }
+      aStream->upDown++;
+      break;
+    case PLTEXT_SUBSCRIPT:
+      if(aStream->upDown > 0){
+	strncat(aStream->pangoMarkupString, "</span>", MAX_MARKUP_LEN-1-strlen(aStream->pangoMarkupString));
+      } else {
+	strncat(aStream->pangoMarkupString, rise_span_tag(aStream->upDown, -1), MAX_MARKUP_LEN-1-strlen(aStream->pangoMarkupString));
+      }
+      aStream->upDown--;
+      break;
+    }
+}
+
+/*---------------------------------------------------------------------
+  text_end_cairo()
+  
+  Draw the text and clean up.
+  ---------------------------------------------------------------------*/
+
+void text_end_cairo(PLStream *pls, EscText *args)
+{
+  int textXExtent, textYExtent;
+  PLFLT rotation, shear, stride, cos_rot, sin_rot, cos_shear, sin_shear;
+  cairo_matrix_t *cairoTransformMatrix;
+  cairo_font_options_t *cairoFontOptions;
+  PangoContext *context;
+  PangoLayout *layout;
+  PLCairo *aStream;
+
+  aStream = (PLCairo *)pls->dev;
+
+  set_current_context(pls);
+
+  /* Close the last span tag. */
+  close_span_tag(aStream->pangoMarkupString, aStream->upDown);
+
+  /* Create the Pango text layout so we can figure out how big it is */
+  layout = pango_cairo_create_layout(aStream->cairoContext);
+  pango_layout_set_markup(layout, aStream->pangoMarkupString, -1);
+  pango_layout_get_pixel_size(layout, &textXExtent, &textYExtent);
+
+  /* Set font aliasing */
+  context = pango_layout_get_context(layout);
+  cairoFontOptions = cairo_font_options_create();
+  cairo_font_options_set_antialias(cairoFontOptions, aStream->text_anti_aliasing);
+  pango_cairo_context_set_font_options(context, cairoFontOptions);
+  pango_layout_context_changed(layout);
+  cairo_font_options_destroy(cairoFontOptions);
+
+  /* Save current transform matrix & clipping region */
+  cairo_save(aStream->cairoContext);
+
+  /* Set up the clipping region if we are doing text clipping */
+  if(aStream->text_clipping){
+    set_clip(pls);
+  }
+
+  /* Move to the string reference point */
+  cairo_move_to(aStream->cairoContext, aStream->downscale * (double) args->x, aStream->downscale * (double) args->y);
+
+  /* Invert the coordinate system so that the text is drawn right side up */
+  cairoTransformMatrix = (cairo_matrix_t *) malloc (sizeof(cairo_matrix_t));
+  cairo_matrix_init(cairoTransformMatrix, 1.0, 0.0, 0.0, -1.0, 0.0, 0.0);
+  cairo_transform(aStream->cairoContext, cairoTransformMatrix);
+
+  /* Extract rotation angle and shear from the PLplot tranformation matrix.
+     Compute sines and cosines of the angles as an optimization. */
+  plRotationShear(args->xform, &rotation, &shear, &stride);
+  rotation -= pls->diorot * PI / 2.0;
+  cos_rot = cos(rotation);
+  sin_rot = sin(rotation);
+  cos_shear = cos(shear);
+  sin_shear = sin(shear);
+
+  /* Apply the transform matrix */
+  cairo_matrix_init(cairoTransformMatrix,             
+		    cos_rot * stride,
+		    -sin_rot * stride,
+		    cos_rot * sin_shear + sin_rot * cos_shear,
+		    -sin_rot * sin_shear + cos_rot * cos_shear,
+		    0,0);
+  cairo_transform(aStream->cairoContext, cairoTransformMatrix);
+  free(cairoTransformMatrix);
+  
+  /* Move to the text starting point */
+  cairo_rel_move_to(aStream->cairoContext, 
+		    (double)(-1.0 * args->just * (double)textXExtent), 
+		    (double)(-0.5 * textYExtent));
+
+  /* Render the text */
+  pango_cairo_show_layout(aStream->cairoContext, layout);
+
+  /* Restore the transform matrix to its state prior to the text transform. */
+  cairo_restore(aStream->cairoContext);
+  
+  /* Free the layout object and the markup string. */
+  g_object_unref(layout);
+  free(aStream->pangoMarkupString);
+}
+
 /*---------------------------------------------------------------------
   proc_str()
   
@@ -352,7 +684,6 @@ void plD_esc_cairo(PLStream *pls, PLINT op, void *ptr)
 
 void proc_str(PLStream *pls, EscText *args)
 {
-  int i;
   float fontSize;
   int textXExtent, textYExtent;
   char *textWithPangoMarkup;
@@ -361,7 +692,6 @@ void proc_str(PLStream *pls, EscText *args)
   cairo_font_options_t *cairoFontOptions;
   PangoContext *context;
   PangoLayout *layout;
-  PangoFontDescription *fontDescription;
   PLCairo *aStream;
 
   aStream = (PLCairo *)pls->dev;
@@ -404,8 +734,7 @@ void proc_str(PLStream *pls, EscText *args)
 
   /* Set up the clipping region if we are doing text clipping */
   if(aStream->text_clipping){
-    cairo_rectangle(aStream->cairoContext, aStream->downscale * pls->clpxmi, aStream->downscale * pls->clpymi, aStream->downscale * (pls->clpxma - pls->clpxmi), aStream->downscale * (pls->clpyma - pls->clpymi));
-    cairo_clip(aStream->cairoContext);
+    set_clip(pls);
   }
 
   /* Move to the string reference point */
@@ -419,7 +748,7 @@ void proc_str(PLStream *pls, EscText *args)
   /* Extract rotation angle and shear from the PLplot tranformation matrix.
      Compute sines and cosines of the angles as an optimization. */
   plRotationShear(args->xform, &rotation, &shear, &stride);
-  rotation -= pls->diorot * 3.14159 / 2.0;
+  rotation -= pls->diorot * PI / 2.0;
   cos_rot = cos(rotation);
   sin_rot = sin(rotation);
   cos_shear = cos(shear);
@@ -495,17 +824,17 @@ char *ucs4_to_pango_markup_format(PLUNICODE *ucs4, int ucs4Len, float fontSize)
 	switch(ucs4[i])
 	  {
 	  case 38:
-	    strcat(pangoMarkupString, "&#38;");
+	    strncat(pangoMarkupString, "&#38;", MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
 	    break;
 	  case 60:
-	    strcat(pangoMarkupString, "&#60;");
+	    strncat(pangoMarkupString, "&#60;", MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
 	    break;
 	  case 62:
-	    strcat(pangoMarkupString, "&#62;");
+	    strncat(pangoMarkupString, "&#62;", MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
 	    break;
 	  default:
 	    ucs4_to_utf8(ucs4[i],utf8);
-	    strcat(pangoMarkupString, utf8);
+	    strncat(pangoMarkupString, utf8, MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
 	    break;
 	  }
 	i++;
@@ -514,24 +843,24 @@ char *ucs4_to_pango_markup_format(PLUNICODE *ucs4, int ucs4Len, float fontSize)
       i++;
       if (ucs4[i] == (PLUNICODE)plplotEsc){   /* a escape character to display */
 	ucs4_to_utf8(ucs4[i],utf8);
-	strcat(pangoMarkupString, utf8);
+	strncat(pangoMarkupString, utf8, MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
 	i++;
 	continue;
       }
       else {
 	if(ucs4[i] == (PLUNICODE)'u'){	/* Superscript */
 	  if(upDown < 0){
-	    strcat(pangoMarkupString, "</sub>");
+	    strncat(pangoMarkupString, "</span>", MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
 	  } else {
-	    strcat(pangoMarkupString, "<sup>");
+	    strncat(pangoMarkupString, rise_span_tag(upDown, 1), MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
 	  }
 	  upDown++;
 	}
 	if(ucs4[i] == (PLUNICODE)'d'){	/* Subscript */
 	  if(upDown > 0){
-	    strcat(pangoMarkupString, "</sup>");
+	    strncat(pangoMarkupString, "</span>", MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
 	  } else {
-	    strcat(pangoMarkupString, "<sub>");
+	    strncat(pangoMarkupString, rise_span_tag(upDown, -1), MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
 	  }
 	  upDown--;
 	}
@@ -564,35 +893,34 @@ char *ucs4_to_pango_markup_format(PLUNICODE *ucs4, int ucs4Len, float fontSize)
 
 void open_span_tag(char *pangoMarkupString, PLUNICODE fci, float fontSize, int upDown)
 {
-  int i;
   unsigned char fontFamily, fontStyle, fontWeight;
-  char openTag[200];
+  char openTag[TAG_LEN];
 
   /* Generate the font info for the open tag & concatenate this
      onto the markup string. */
   plP_fci2hex(fci, &fontFamily, PL_FCI_FAMILY);
   plP_fci2hex(fci, &fontStyle, PL_FCI_STYLE);
   plP_fci2hex(fci, &fontWeight, PL_FCI_WEIGHT);
-  sprintf(openTag, "<span font_desc=\"%s %.2f\" ", familyLookup[fontFamily], fontSize);
-  strcat(pangoMarkupString, openTag);
+  snprintf(openTag, TAG_LEN, "<span font_desc=\"%s %.2f\" ", familyLookup[fontFamily], fontSize);
+  strncat(pangoMarkupString, openTag, MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
 
-  sprintf(openTag, "style=\"%s\" ", styleLookup[fontStyle]);
-  strcat(pangoMarkupString, openTag);
+  snprintf(openTag, TAG_LEN, "style=\"%s\" ", styleLookup[fontStyle]);
+  strncat(pangoMarkupString, openTag, MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
 
-  sprintf(openTag, "weight=\"%s\">", weightLookup[fontWeight]);
-  strcat(pangoMarkupString, openTag);
+  snprintf(openTag, TAG_LEN, "weight=\"%s\">", weightLookup[fontWeight]);
+  strncat(pangoMarkupString, openTag, MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
 
   /* Move to the right sub/super-script level */
   if(upDown > 0){
     while(upDown > 0){
-      strcat(pangoMarkupString, "<sup>");
       upDown--;
+      strncat(pangoMarkupString, rise_span_tag(upDown, 1), MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
     }
   }
   if(upDown < 0){
     while(upDown < 0){
-      strcat(pangoMarkupString, "<sub>");
       upDown++;
+      strncat(pangoMarkupString, rise_span_tag(upDown, -1), MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
     }
   }
 }
@@ -607,18 +935,47 @@ void close_span_tag(char *pangoMarkupString, int upDown)
 {
   if(upDown > 0){
     while(upDown > 0){
-      strcat(pangoMarkupString, "</sup>");
+      strncat(pangoMarkupString, "</span>", MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
       upDown--;
     }
   }
   if(upDown < 0){
     while(upDown < 0){
-      strcat(pangoMarkupString, "</sub>");
+      strncat(pangoMarkupString, "</span>", MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
       upDown++;
     }
   }
 
-  strcat(pangoMarkupString, "</span>");
+  strncat(pangoMarkupString, "</span>", MAX_MARKUP_LEN-1-strlen(pangoMarkupString));
+}
+
+/*---------------------------------------------------------------------
+  rise_span_tag
+  
+  Create a rise span tag w/ appropriate font size & baseline offset
+  ---------------------------------------------------------------------*/
+
+#define STEPSIZE 7500.0
+
+char *rise_span_tag(int level, int direction)
+{
+  int i;
+  float multiplier = 1.0;
+  float rise = STEPSIZE;
+  static char tag[100];
+
+  for(i=0;i<abs(level);i++){
+    multiplier = multiplier * 0.9;
+    rise += STEPSIZE * multiplier;
+  }
+  if(direction>0){
+    sprintf(tag, "<span rise=\"%d\" size=\"smaller\">", (int)rise);
+  }
+  else{
+    sprintf(tag, "<span rise=\"%d\" size=\"smaller\">", (int)-rise);
+  }
+
+  return(tag);
 }
 
 /*---------------------------------------------------------------------
@@ -664,8 +1021,10 @@ PLCairo *stream_and_font_setup(PLStream *pls, int interactive)
   pls->color = 1;            /* Supports color */
   pls->dev_text = 1;         /* Handles text */
   pls->dev_unicode = 1;      /* Wants unicode text */
+  pls->alt_unicode = 1;      /* Wants to handle unicode character by character */
   pls->page = 0;
   pls->dev_fill0 = 1;        /* Supports hardware solid fills */
+  pls->dev_arc = 1;          /* Supports driver-level arcs */
   pls->plbuf_write = 1;      /* Activate plot buffer */
   
   
@@ -676,9 +1035,9 @@ PLCairo *stream_and_font_setup(PLStream *pls, int interactive)
   /* Calculate ratio of (smaller) external coordinates used for cairo
      devices to (larger) internal PLplot coordinates. */
   if (pls->xlength > pls->ylength)
-    downscale = (PLFLT)pls->xlength/(PLFLT)(PIXELS_X-1);
+    downscale = (double)pls->xlength/(double)(PIXELS_X-1);
   else
-    downscale = (PLFLT)pls->ylength/(PLFLT)PIXELS_Y;
+    downscale = (double)pls->ylength/(double)PIXELS_Y;
   plP_setphy((PLINT) 0, (PLINT) (pls->xlength / downscale), (PLINT) 0, (PLINT) (pls->ylength / downscale));
   plP_setpxl(DPI/25.4/downscale, DPI/25.4/downscale);
 
@@ -686,10 +1045,12 @@ PLCairo *stream_and_font_setup(PLStream *pls, int interactive)
      This was copied from the psttf driver. */
   for(i=0;i<NPANGOLOOKUP;i++){
     if((a = getenv(envFamilyLookup[i])) != NULL){
-      strcpy(familyLookup[i],a);
+      strncpy(familyLookup[i],a,FAMILY_LOOKUP_LEN-1);
+      familyLookup[i][FAMILY_LOOKUP_LEN-1] = '\0';
     }
     else {
-      strcpy(familyLookup[i],defaultFamilyLookup[i]);
+      strncpy(familyLookup[i],defaultFamilyLookup[i],FAMILY_LOOKUP_LEN-1);
+      familyLookup[i][FAMILY_LOOKUP_LEN-1] = '\0';
     }
   }
 
@@ -703,23 +1064,26 @@ PLCairo *stream_and_font_setup(PLStream *pls, int interactive)
   aStream->cairoContext = NULL;
   aStream->downscale = downscale;
 
-  /* Set text clipping off as this makes the driver pretty slow */
-  aStream->text_clipping = 0;
-  text_clipping = 0;
-  text_anti_aliasing = 0;     // use 'default' text aliasing by default
-  graphics_anti_aliasing = 0; // use 'default' graphics aliasing by default
+  /* Set text clipping on by default since it makes little difference in
+     speed for a modern cairo stack.*/
+  aStream->text_clipping = 1;
+  text_clipping = 1;
+  text_anti_aliasing = 0;     /* use 'default' text aliasing by default */
+  graphics_anti_aliasing = 0; /* use 'default' graphics aliasing by default */
+  rasterize_image = 1; /* Enable rasterization by default */
 
   /* Check for cairo specific options */
   plParseDrvOpts(cairo_options);
 
-  /* Turn on text clipping if the user desires this */
-  if(text_clipping){
-    aStream->text_clipping = 1;
+  /* Turn off text clipping if the user desires this */
+  if(!text_clipping){
+    aStream->text_clipping = 0;
   }
 
-  /* Record users desired text and graphics aliasing */
+  /* Record users desired text and graphics aliasing and rasterization */
   aStream->text_anti_aliasing = text_anti_aliasing;
   aStream->graphics_anti_aliasing = graphics_anti_aliasing;
+  aStream->rasterize_image = rasterize_image;
 
   return aStream;
 }
@@ -782,9 +1146,19 @@ void filled_polygon(PLStream *pls, short *xa, short *ya, PLINT npts)
 {
   int i;
   PLCairo *aStream;
+  cairo_line_join_t old_line_join;
+  cairo_line_cap_t old_line_cap;
+  cairo_antialias_t aa_state;
 
   aStream = (PLCairo *)pls->dev;
 
+  /* Save the previous line drawing style */
+  get_line_properties(aStream, &old_line_join, &old_line_cap);
+
+  /* These line properties make for a nicer looking polygon mesh */
+  set_line_properties(aStream, CAIRO_LINE_JOIN_BEVEL, CAIRO_LINE_CAP_BUTT);
+
+  /* Draw the polygons */
   cairo_move_to(aStream->cairoContext, aStream->downscale * (double) xa[0], aStream->downscale * (double) ya[0]);
   for(i=1;i<npts;i++)
     cairo_line_to(aStream->cairoContext, aStream->downscale * (double) xa[i], aStream->downscale * (double) ya[i]);
@@ -793,12 +1167,115 @@ void filled_polygon(PLStream *pls, short *xa, short *ya, PLINT npts)
       (double)pls->curcolor.g/255.0,
       (double)pls->curcolor.b/255.0,
       (double)pls->curcolor.a);
-  cairo_set_line_width(aStream->cairoContext, 1.0);
-  if(pls->curcolor.a>0.99) {
+  aa_state = cairo_get_antialias(aStream->cairoContext);
+  /* Add an extra outline stroke to the polygon unless the plotting color is
+     not opaque or antialiasing is disabled. */
+  if((pls->curcolor.a > 0.99) && (aa_state != CAIRO_ANTIALIAS_NONE)) {
     cairo_fill_preserve(aStream->cairoContext);
+    cairo_set_line_width(aStream->cairoContext, 1.0);
     cairo_stroke(aStream->cairoContext);
   } else
     cairo_fill(aStream->cairoContext);
+
+  /* Restore the previous line drawing style */
+  set_line_properties(aStream, old_line_join, old_line_cap);
+}
+
+/*---------------------------------------------------------------------
+  set_clip()
+
+  Set the clipping region to the plot window.
+  NOTE: cairo_save() and cairo_restore() should probably be called before
+  and after this, respectively.
+  ---------------------------------------------------------------------*/
+
+void set_clip(PLStream *pls)
+{
+  PLINT rcx[4], rcy[4];
+  PLCairo *aStream;
+  aStream = (PLCairo *)pls->dev;
+
+  /* Use PLplot core routine to get the corners of the clipping rectangle */
+  difilt_clip(rcx, rcy);
+
+  /* Layout the bounds of the clipping region */
+  /* Should we convert PLINT to short and use the polyline routine? */
+  cairo_move_to(aStream->cairoContext, 
+      	  aStream->downscale * (double) rcx[0],
+      	  aStream->downscale * (double) rcy[0]);
+  cairo_line_to(aStream->cairoContext,
+      	  aStream->downscale * (double) rcx[1],
+      	  aStream->downscale * (double) rcy[1]);
+  cairo_line_to(aStream->cairoContext,
+      	  aStream->downscale * (double) rcx[2],
+      	  aStream->downscale * (double) rcy[2]);
+  cairo_line_to(aStream->cairoContext,
+      	  aStream->downscale * (double) rcx[3],
+      	  aStream->downscale * (double) rcy[3]);
+  cairo_line_to(aStream->cairoContext,
+      	  aStream->downscale * (double) rcx[0],
+      	  aStream->downscale * (double) rcy[0]);
+
+  /* Set the clipping region */
+  cairo_clip(aStream->cairoContext);
+
+  /* Apparently, in some older Cairo versions, cairo_clip does not consume
+     the current path. */
+  cairo_new_path(aStream->cairoContext);
+}
+
+/*---------------------------------------------------------------------
+  arc()
+
+  Draws an arc, possibly filled.
+  ---------------------------------------------------------------------*/
+
+void arc(PLStream *pls, arc_struct *arc_info)
+{
+  PLCairo *aStream;
+  double x, y, a, b;
+  double angle1, angle2;
+
+  set_current_context(pls);
+
+  aStream = (PLCairo *)pls->dev;
+
+  /* Scale to the proper Cairo coordinates */
+  x = aStream->downscale * arc_info->x;
+  y = aStream->downscale * arc_info->y;
+  a = aStream->downscale * arc_info->a;
+  b = aStream->downscale * arc_info->b;
+
+  /* Degrees to radians */
+  angle1 = arc_info->angle1 * M_PI / 180.0;
+  angle2 = arc_info->angle2 * M_PI / 180.0;
+
+  cairo_save(aStream->cairoContext);
+
+  /* Clip the output to the plotting window */
+  set_clip(pls);
+
+  /* Make sure the arc is properly shaped and oriented */
+  cairo_save(aStream->cairoContext);
+  cairo_translate(aStream->cairoContext, x, y);
+  cairo_scale(aStream->cairoContext, a, b);
+  cairo_arc(aStream->cairoContext, 0.0, 0.0, 1.0, angle1, angle2);
+  if (arc_info->fill)
+    cairo_line_to(aStream->cairoContext, 0.0, 0.0);
+  cairo_restore(aStream->cairoContext);
+
+  cairo_set_source_rgba(aStream->cairoContext,
+      (double)pls->curcolor.r/255.0,
+      (double)pls->curcolor.g/255.0,
+      (double)pls->curcolor.b/255.0,
+      (double)pls->curcolor.a);
+  if (arc_info->fill) {
+    cairo_fill(aStream->cairoContext);
+  }
+  else {
+    cairo_stroke(aStream->cairoContext);
+  }
+  cairo_restore(aStream->cairoContext);
 }
 
 /*---------------------------------------------------------------------
@@ -849,10 +1326,11 @@ void plD_bop_famcairo(PLStream *pls)
 
   /* Fill in the window with the background color. */
   cairo_rectangle(aStream->cairoContext, 0.0, 0.0, pls->xlength, pls->ylength);
-  cairo_set_source_rgb(aStream->cairoContext,
+  cairo_set_source_rgba(aStream->cairoContext,
 		       (double)pls->cmap0[0].r/255.0,
 		       (double)pls->cmap0[0].g/255.0,
-		       (double)pls->cmap0[0].b/255.0);
+		       (double)pls->cmap0[0].b/255.0,
+		       (double)pls->cmap0[0].a);
   cairo_fill(aStream->cairoContext);
 }
 
@@ -872,6 +1350,7 @@ static Window rootWindow;
 
 void plD_dispatch_init_xcairo    (PLDispatchTable *pdt);
 void plD_init_xcairo             (PLStream *);
+void plD_bop_xcairo              (PLStream *);
 void plD_eop_xcairo              (PLStream *);
 void plD_tidy_xcairo             (PLStream *);
 void plD_esc_xcairo              (PLStream *, PLINT, void *);
@@ -895,7 +1374,7 @@ void plD_dispatch_init_xcairo(PLDispatchTable *pdt)
    pdt->pl_line     = (plD_line_fp)     plD_line_cairo;
    pdt->pl_polyline = (plD_polyline_fp) plD_polyline_cairo;
    pdt->pl_eop      = (plD_eop_fp)      plD_eop_xcairo;
-   pdt->pl_bop      = (plD_bop_fp)      plD_bop_cairo;
+   pdt->pl_bop      = (plD_bop_fp)      plD_bop_xcairo;
    pdt->pl_tidy     = (plD_tidy_fp)     plD_tidy_xcairo;
    pdt->pl_state    = (plD_state_fp)    plD_state_cairo;
    pdt->pl_esc      = (plD_esc_fp)      plD_esc_xcairo;
@@ -923,7 +1402,11 @@ static signed int xcairo_init_cairo(PLStream *pls)
   /* Create an cairo surface & context that are associated with the X window. */
   defaultVisual = DefaultVisual(aStream->XDisplay, 0);
   /* Dimension units are pixels from cairo documentation. */
-  aStream->cairoSurface = cairo_xlib_surface_create(aStream->XDisplay, aStream->XWindow, defaultVisual, pls->xlength, pls->ylength);
+  /* This is the X window Cairo surface. */
+  aStream->cairoSurface_X = cairo_xlib_surface_create(aStream->XDisplay, aStream->XWindow, defaultVisual, pls->xlength, pls->ylength);
+  aStream->cairoContext_X = cairo_create(aStream->cairoSurface_X);
+  /* This is the Cairo surface PLplot will actually plot to. */
+  aStream->cairoSurface = cairo_image_surface_create(CAIRO_FORMAT_RGB24, pls->xlength, pls->ylength);
   aStream->cairoContext = cairo_create(aStream->cairoSurface);
 
   /* Invert the surface so that the graphs are drawn right side up. */
@@ -944,7 +1427,6 @@ static signed int xcairo_init_cairo(PLStream *pls)
 void plD_init_xcairo(PLStream *pls)
 {
   char plotTitle[40];
-  XGCValues values;
   PLCairo *aStream;
 
   /* Setup the PLStream and the font lookup table. */
@@ -984,6 +1466,41 @@ void plD_init_xcairo(PLStream *pls)
 
 }
 
+/*---------------------------------------------------------------------
+  blit_to_x()
+
+  Blit the offscreen image to the X window.
+  ---------------------------------------------------------------------*/
+
+void blit_to_x(PLCairo *aStream)
+{
+  cairo_set_source_surface(aStream->cairoContext_X, aStream->cairoSurface, 0.0, 0.0);
+  cairo_paint(aStream->cairoContext_X);
+}
+
+/*----------------------------------------------------------------------
+  plD_bop_xcairo()
+
+  X Windows specific start of page.
+  ----------------------------------------------------------------------*/
+
+void plD_bop_xcairo(PLStream *pls)
+{
+  PLCairo *aStream;
+
+  aStream = (PLCairo *)pls->dev;
+
+  plD_bop_cairo(pls);
+
+  if (aStream->xdrawable_mode)
+    return;
+
+  /* Be sure the window title is set appropriately. */
+  XStoreName(aStream->XDisplay, aStream->XWindow, "PLplot");
+
+  XFlush(aStream->XDisplay);
+}
+
 /*---------------------------------------------------------------------
   plD_eop_xcairo()
   
@@ -1005,10 +1522,18 @@ void plD_eop_xcairo(PLStream *pls)
   if (aStream->xdrawable_mode)
     return;
 
+  /* Blit the offscreen image to the X window. */
+  blit_to_x(aStream);
+
   XFlush(aStream->XDisplay);
 
+  /* Only pause if nopause is unset. */
+  if (pls->nopause)
+    aStream->exit_event_loop = 1;
+  else
+    XStoreName(aStream->XDisplay, aStream->XWindow, "PLplot - Press Enter or right-click to continue");
+
   /* Loop, handling selected events, till the user elects to close the plot. */
-  printf("Click on the plot and key <Return> to exit.\n");
   event_mask = ButtonPressMask | KeyPressMask | ExposureMask;
   XSelectInput(aStream->XDisplay, aStream->XWindow, event_mask);
   while(!aStream->exit_event_loop){
@@ -1021,17 +1546,19 @@ void plD_eop_xcairo(PLStream *pls)
 	aStream->exit_event_loop = 1;
       }
       break;
+    case ButtonPress:
+      if (((XButtonEvent *)&event)->button == Button3)
+        aStream->exit_event_loop = 1;
+      break;
     case Expose:
-      plD_bop_cairo(pls);
-      plRemakePlot(pls);
+      /* Blit the image again after an expose event. */
+      blit_to_x(aStream);
       XFlush(aStream->XDisplay);
       break;
     }
   }
   aStream->exit_event_loop = 0;
 
-  /*  printf("Key <Return> to finish\n"); */
-  /* getc(stdin); */
 }
 
 /*---------------------------------------------------------------------
@@ -1048,6 +1575,10 @@ void plD_tidy_xcairo(PLStream *pls)
 
   plD_tidy_cairo(pls);
 
+  /* Also free up the Cairo X surface and context */
+  cairo_destroy(aStream->cairoContext_X);
+  cairo_surface_destroy(aStream->cairoSurface_X);
+
   if (aStream->xdrawable_mode)
     return;
 
@@ -1073,13 +1604,8 @@ void plD_esc_xcairo(PLStream *pls, PLINT op, void *ptr)
 
   switch(op)
     {
-    case PLESC_FILL:     /* filled polygon */
-      filled_polygon(pls, pls->dev_x, pls->dev_y, pls->dev_npts);
-      break;
-    case PLESC_HAS_TEXT: /* render rext */
-      proc_str(pls, (EscText *) ptr);
-      break;
     case PLESC_FLUSH:    /* forced update of the window */
+      blit_to_x(aStream);
       XFlush(aStream->XDisplay);
       break;
     case PLESC_GETC:     /* get cursor position */
@@ -1117,7 +1643,10 @@ void plD_esc_xcairo(PLStream *pls, PLINT op, void *ptr)
         plbop();
 
         break;
-      }
+    }
+    default:
+      plD_esc_cairo(pls, op, ptr);
+      break;
     }
 }
 
@@ -1178,9 +1707,9 @@ void xcairo_get_cursor(PLStream *pls, PLGraphicsIn *gin)
   gin->state = xButtonEvent->state;
   gin->button = xButtonEvent->button;
   gin->pX = event.xbutton.x;
-  gin->pY = event.xbutton.y;
+  gin->pY = pls->ylength - event.xbutton.y;
   gin->dX = (PLFLT)event.xbutton.x/((PLFLT)(pls->xlength));
-  gin->dY = (PLFLT)event.xbutton.y/((PLFLT)(pls->ylength));
+  gin->dY = (PLFLT)(pls->ylength - event.xbutton.y)/((PLFLT)(pls->ylength));
 
   /* Switch back to normal cursor */
   XUndefineCursor(aStream->XDisplay, aStream->XWindow);
@@ -1818,12 +2347,6 @@ void plD_esc_extcairo(PLStream *pls, PLINT op, void *ptr)
 
   switch(op)
     {
-    case PLESC_FILL:     /* filled polygon */
-      filled_polygon(pls, pls->dev_x, pls->dev_y, pls->dev_npts);
-      break;
-    case PLESC_HAS_TEXT: /* render text */
-      proc_str(pls, (EscText *) ptr);
-      break;
     case PLESC_DEVINIT: /* Set external context */
       aStream->cairoContext = (cairo_t *)ptr;
       /* Set graphics aliasing */
@@ -1836,6 +2359,9 @@ void plD_esc_extcairo(PLStream *pls, PLINT op, void *ptr)
          Cairo does not provide a way to query the dimensions of a context? */
 
       break;
+    default: /* Fall back on default Cairo actions */
+      plD_esc_cairo(pls, op, ptr);
+      break;
     }
 }
 
@@ -1851,4 +2377,3 @@ void plD_tidy_extcairo(PLStream *pls)
 }
 
 #endif
-
