@@ -1,4 +1,4 @@
-/* $Id: gd.c 9207 2008-12-19 18:09:25Z airwin $
+/* $Id: gd.c 10287 2009-08-18 18:18:11Z airwin $
 
          PNG, GIF, and JPEG device driver based on libgd
 
@@ -140,7 +140,7 @@ PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_gd =
   "jpeg:JPEG file:0:gd:40:jpeg\n"
 #endif
 #if defined(PLD_gif)
-  "gif:GIF file:0:gd:47:gif"
+  "gif:GIF file:0:gd:47:gif\n"
 #endif
 ;
 
@@ -560,7 +560,7 @@ plD_init_gif_Dev(PLStream *pls)
     static int red15=0;
 #ifdef HAVE_FREETYPE
     static int freetype=1;
-    static int smooth_text=1;
+    static int smooth_text=0;
     FT_Data *FT;
 #endif
 
@@ -1305,6 +1305,7 @@ void plD_eop_png(PLStream *pls)
     int im_size=0;
     int png_compression;
     void *im_ptr=NULL;
+    size_t nwrite;
 
     if (pls->family || pls->page == 1) {
 
@@ -1348,7 +1349,9 @@ void plD_eop_png(PLStream *pls)
          im_ptr = gdImagePngPtr(dev->im_out, &im_size);
        #endif
        if( im_ptr ) {
-         fwrite(im_ptr, sizeof(char), im_size, pls->OutFile);
+         nwrite = fwrite(im_ptr, sizeof(char), im_size, pls->OutFile);
+         if (nwrite != im_size) 
+           plabort("gd driver: Error writing png file");
          gdFree(im_ptr);
        }
 
@@ -1528,15 +1531,27 @@ void plD_eop_jpeg(PLStream *pls)
     png_Dev *dev=(png_Dev *)pls->dev;
     int im_size=0;
     void *im_ptr=NULL;
+    size_t nwrite;
+    int jpeg_compression;
 
     if (pls->family || pls->page == 1) {
+      /*  Set the compression/quality level for JPEG files
+       *  The higher the value, the bigger/better the image is
+       */
+      if ( (pls->dev_compression<=0)||(pls->dev_compression>99) )
+        jpeg_compression=90;
+      else
+        jpeg_compression = pls->dev_compression;
+
        /* image is written to output file by the driver
           since if the gd.dll is linked to a different c
           lib a crash occurs - this fix works also in Linux */
-       /* gdImageJpeg(dev->im_out, pls->OutFile, pls->dev_compression); */
-       im_ptr = gdImageJpegPtr(dev->im_out, &im_size, pls->dev_compression);
+       /* gdImageJpeg(dev->im_out, pls->OutFile, jpeg_compression); */
+       im_ptr = gdImageJpegPtr(dev->im_out, &im_size, jpeg_compression);
        if( im_ptr ) {
-         fwrite(im_ptr, sizeof(char), im_size, pls->OutFile);
+         nwrite = fwrite(im_ptr, sizeof(char), im_size, pls->OutFile);
+         if (nwrite != im_size) 
+           plabort("gd driver: Error writing png file");
          gdFree(im_ptr);
        }
 
@@ -1560,6 +1575,7 @@ void plD_eop_gif(PLStream *pls)
     png_Dev *dev=(png_Dev *)pls->dev;
     int im_size=0;
     void *im_ptr=NULL;
+    size_t nwrite;
 
     if (pls->family || pls->page == 1) {
        /* image is written to output file by the driver
@@ -1568,7 +1584,9 @@ void plD_eop_gif(PLStream *pls)
        /* gdImageGif(dev->im_out, pls->OutFile); */
        im_ptr = gdImageGifPtr(dev->im_out, &im_size);
        if( im_ptr ) {
-         fwrite(im_ptr, sizeof(char), im_size, pls->OutFile);
+         nwrite = fwrite(im_ptr, sizeof(char), im_size, pls->OutFile);
+         if (nwrite != im_size) 
+           plabort("gd driver: Error writing png file");
          gdFree(im_ptr);
        }
 
