@@ -1,4 +1,4 @@
-/* $Id: gnome.c 8882 2008-10-11 06:15:24Z airwin $
+/* $Id: gnome.c 10255 2009-08-15 03:35:02Z airwin $
 
         PLplot GnomeCanvas device driver.
 
@@ -39,7 +39,7 @@
 #include <unistd.h>
 
 /* Device info */
-PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_gnome = "gnome:Gnome Canvas:1:gnome:6:gnome";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_gnome = "gnome:Gnome Canvas:1:gnome:6:gnome\n";
 
 /*#undef DEBUG*/
 #define DEBUG
@@ -67,6 +67,8 @@ PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_gnome = "gnome:Gnome Canvas:1:gno
 /* Magnification factor for the PLplot physical dimensions */
 #define MAG_FACTOR 10
 
+#define BUFFER_LEN 128
+
 #ifndef ABS
 #define ABS(x) ((x < 0) ? (-(x)) : (x))
 #endif
@@ -248,7 +250,7 @@ canvas_pressed_cb(GnomeCanvasItem *item, GdkEvent *event,
   static guint dragging;
   guint move;
   GdkCursor *cursor;
-  char buffer[128];
+  char buffer[BUFFER_LEN];
   PLGraphicsIn* gin = &(page->gin);
   ItemColor* color;
   GnomeCanvasItem* item_at_cursor;
@@ -342,13 +344,13 @@ canvas_pressed_cb(GnomeCanvasItem *item, GdkEvent *event,
     plTranslateCursor (gin);
 
     if (color == NULL)
-      sprintf (buffer, "");
+      buffer[0] = '\0';
     else
       if (color->cmap == 0)
-	sprintf (buffer, "   x = %f   y = %f   color = %d (cmap0)",
+	snprintf (buffer, BUFFER_LEN, "   x = %f   y = %f   color = %d (cmap0)",
 		 gin->wX, gin->wY, (int) color->color);
       else
-	sprintf (buffer, "   x = %f   y = %f   color = %f (cmap1)",
+	snprintf (buffer, BUFFER_LEN, "   x = %f   y = %f   color = %f (cmap1)",
 		 gin->wX, gin->wY, color->color);
 
     /*// FIXME : Terrible global variable hack*/
@@ -540,7 +542,7 @@ new_page (PLStream* pls)
   GnomeCanvasPoints* points;
   guint np;
   guint32 loclinecolor;
-  char buffer[32];
+  char buffer[BUFFER_LEN];
 
   dev = pls->dev;
   page = g_malloc (sizeof (GnomePLdevPage));
@@ -700,7 +702,7 @@ new_page (PLStream* pls)
 
   gtk_notebook_set_show_tabs (dev->notebook, (np > 0));
 
-  sprintf (buffer, "Page %d", np+1);
+  snprintf (buffer, BUFFER_LEN, "Page %d", np+1);
   gtk_notebook_append_page (dev->notebook, GTK_WIDGET (page->sw),
 			    gtk_label_new (buffer));
 
@@ -809,7 +811,7 @@ plD_init_gnome (PLStream *pls)
   pls->termin = 1;		/* Is an interactive terminal */
   pls->dev_flush = 1;		/* Handle our own flushes */
   pls->dev_fill0 = 1;		/* Handle solid fills */
-  pls->dev_fill1 = 1;		/* Handle pattern fills */
+  pls->dev_fill1 = 1;		/* Driver handles pattern fills */
   pls->dev_dash = 1;		/* Handle dashed lines */
   pls->plbuf_write = 1;	        /* Use plot buffer to replot to another device */
   pls->width = 1;
