@@ -1,4 +1,4 @@
-/* $Id: impress.c 9113 2008-12-15 10:39:03Z andrewross $
+/* $Id: impress.c 9708 2009-03-10 23:52:24Z airwin $
 
 	PLplot ImPress device driver.
 */
@@ -10,7 +10,7 @@
 #include "drivers.h"
 
 /* Device info */
-PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_impress = "imp:Impress File:0:impress:37:imp";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_impress = "imp:Impress File:0:impress:37:imp\n";
 
 /* Function prototypes */
 
