@@ -1,4 +1,4 @@
-/* $Id: linuxvga.c 8882 2008-10-11 06:15:24Z airwin $
+/* $Id: linuxvga.c 9709 2009-03-11 00:01:06Z airwin $
 
 	S. Fanchiotti (Using gnusvga.c by Geoffrey Furnish)
 	4 May 1993
@@ -18,7 +18,7 @@
 #include <vga.h>
 
 /* Device info */
-PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_linuxvga = "linuxvga:Linux VGA driver:0:linuxvga:8:vga";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_linuxvga = "linuxvga:Linux VGA driver:0:linuxvga:8:vga\n";
 
 
 /* Function prototypes */
