@@ -1,4 +1,4 @@
-/* $Id: ljii.c 8882 2008-10-11 06:15:24Z airwin $
+/* $Id: ljii.c 9708 2009-03-10 23:52:24Z airwin $
 
 	PLplot Laser Jet II device driver.
 
@@ -23,7 +23,7 @@
 
 /* Device info */
 PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_ljii =
-  "ljii:LaserJet II Bitmap File (150 dpi):0:ljii:33:ljii";
+  "ljii:LaserJet II Bitmap File (150 dpi):0:ljii:33:ljii\n";
 
 /* Function prototypes */
 
