@@ -1,4 +1,4 @@
-/* $Id: ljiip.c 8882 2008-10-11 06:15:24Z airwin $
+/* $Id: ljiip.c 9708 2009-03-10 23:52:24Z airwin $
 
 	PLplot Laser Jet IIp device driver.
 	Based on old LJII driver, modifications by Wesley Ebisuzaki
@@ -28,7 +28,7 @@
 
 /* Device info */
 PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_ljiip =
-  "ljiip:LaserJet IIp/deskjet compressed graphics:0:ljiip:32:ljiip";
+  "ljiip:LaserJet IIp/deskjet compressed graphics:0:ljiip:32:ljiip\n";
 
 /* Function prototypes */
 
