@@ -1,4 +1,4 @@
-/* $Id: null.c 8882 2008-10-11 06:15:24Z airwin $
+/* $Id: null.c 9708 2009-03-10 23:52:24Z airwin $
 
 	PLplot Null device driver.
 */
@@ -10,7 +10,7 @@
 #include "drivers.h"
 
 /* Device info */
-PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_null = "null:Null device:-1:null:42:null";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_null = "null:Null device:-1:null:42:null\n";
 
 void plD_dispatch_init_null	( PLDispatchTable *pdt );
 
