@@ -1,5 +1,5 @@
 /*
-  $Id: pbm.c 8882 2008-10-11 06:15:24Z airwin $
+  $Id: pbm.c 10255 2009-08-15 03:35:02Z airwin $
 
   PLplot PBM (PPM) device driver.
 
@@ -14,7 +14,7 @@
 #include "drivers.h"
 
 /* Device info */
-PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_pbm = "pbm:PDB (PPM) Driver:0:pbm:38:pbm";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_pbm = "pbm:PDB (PPM) Driver:0:pbm:38:pbm\n";
 
 
 void plD_dispatch_init_pbm	( PLDispatchTable *pdt );
@@ -81,8 +81,8 @@ plD_init_pbm(PLStream *pls)
 
     pls->color = 1;		/* Is a color device */
     pls->dev_fill0 = 0;		/* Handle solid fills */
-    pls->dev_fill1 = 0;		/* Handle pattern fills */
-    pls->nopause = 1;		/* Don`t pause between frames */
+    pls->dev_fill1 = 0;		/* Use PLplot core fallback for pattern fills */
+    pls->nopause = 1;		/* Don't pause between frames */
 
 /* Prompt for a file name if not already set */
 
@@ -235,6 +235,7 @@ void
 plD_eop_pbm(PLStream *pls)
 {
     FILE *fp = pls->OutFile;
+    size_t im_size, nwrite;
 
     if (fp != NULL) {
 	fprintf(fp, "%s\n", "P6");
@@ -249,7 +250,10 @@ plD_eop_pbm(PLStream *pls)
 			fprintf(fp, "%c", cmap[i][j][k]);
 	}
     */
-	fwrite( cmap, 1, pls->xlength * pls->ylength * 3, fp );
+        im_size = pls->xlength*pls->ylength*3;
+	nwrite = fwrite( cmap, 1, im_size, fp );
+        if (nwrite != im_size) 
+            plabort("gd driver: Error writing png file");
 
 	fclose(fp);
     } 
