@@ -1,4 +1,4 @@
-/* $Id: plmeta.c 8882 2008-10-11 06:15:24Z airwin $
+/* $Id: plmeta.c 10255 2009-08-15 03:35:02Z airwin $
 
     Copyright 1991, 1992, 1993, 1994, 1995
     Geoffrey Furnish			furnish@dino.ph.utexas.edu
@@ -37,7 +37,7 @@
 #include <string.h>
 
 /* Device info */
-PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_plmeta = "plmeta:PLplot Native Meta-File:0:plmeta:26:plm";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_plmeta = "plmeta:PLplot Native Meta-File:0:plmeta:26:plm\n";
 
 
 void plD_dispatch_init_plm	( PLDispatchTable *pdt );
@@ -67,7 +67,8 @@ typedef struct {
 
 /* Used for constructing error messages */
 
-static char buffer[256];
+#define BUFFER_LEN 256
+static char buffer[BUFFER_LEN];
 
 /* Function prototypes */
 
@@ -135,7 +136,7 @@ plD_init_plm(PLStream *pls)
 
     pls->color = 1;		/* Is a color device */
     pls->dev_fill0 = 1;		/* Handle solid fills */
-    pls->dev_fill1 = 1;		/* Handle pattern fills */
+    pls->dev_fill1 = 1;		/* Driver handles pattern fills */
 
 /* Initialize family file info */
 
@@ -410,7 +411,7 @@ UpdatePrevPagehdr(PLStream *pls)
     /* The forward byte offset is located exactly 7 bytes after the BOP */
 	fwbyte_offset = dev->lp_offset + 7;
 	if (pl_fsetpos(file, &fwbyte_offset)) {
-	    sprintf(buffer, "UpdatePrevPagehdr (plmeta.c): fsetpos to fwbyte_offset (%d) failed",
+	    snprintf(buffer, BUFFER_LEN, "UpdatePrevPagehdr (plmeta.c): fsetpos to fwbyte_offset (%d) failed",
 		    (int) fwbyte_offset);
 	    plexit(buffer);
 	}
@@ -435,7 +436,7 @@ UpdatePrevPagehdr(PLStream *pls)
 
 #ifdef DEBUG
 	if (pl_fsetpos(file, &fwbyte_offset)) {
-	    sprintf(buffer, "UpdatePrevPagehdr (plmeta.c): fsetpos to fwbyte_offset (%d) failed",
+	    snprintf(buffer, BUFFER_LEN, "UpdatePrevPagehdr (plmeta.c): fsetpos to fwbyte_offset (%d) failed",
 		    (int) fwbyte_offset);
 	    plexit(buffer);
 	}
@@ -450,7 +451,7 @@ UpdatePrevPagehdr(PLStream *pls)
     /* Return to current page offset */
 
 	if (pl_fsetpos(file, &cp_offset)) {
-	    sprintf(buffer, "UpdatePrevPagehdr (plmeta.c): fsetpos to cp_offset (%d) failed",
+	    snprintf(buffer, BUFFER_LEN, "UpdatePrevPagehdr (plmeta.c): fsetpos to cp_offset (%d) failed",
 		    (int) cp_offset);
 	    plexit(buffer);
 	}
@@ -478,7 +479,7 @@ UpdateIndex(PLStream *pls, FPOS_T cp_offset)
 		(int) cp_offset, (int) dev->lp_offset);
 
 	if (pl_fsetpos(file, &dev->index_offset)) {
-	    sprintf(buffer, "UpdateIndex (plmeta.c): fsetpos to index_offset (%d) failed",
+	    snprintf(buffer, BUFFER_LEN, "UpdateIndex (plmeta.c): fsetpos to index_offset (%d) failed",
 		    (int) dev->index_offset);
 	    plexit(buffer);
 	}
@@ -490,7 +491,7 @@ UpdateIndex(PLStream *pls, FPOS_T cp_offset)
 		(int) dev->lp_offset, (int) cp_offset);
 
 	if (pl_fsetpos(file, &cp_offset)) {
-	    sprintf(buffer, "UpdateIndex (plmeta.c): fsetpos to cp_offset (%d) failed",
+	    snprintf(buffer, BUFFER_LEN, "UpdateIndex (plmeta.c): fsetpos to cp_offset (%d) failed",
 		    (int) cp_offset);
 	    plexit(buffer);
 	}
