@@ -1,4 +1,4 @@
-/* $Id: ps.c 9074 2008-12-10 10:08:05Z andrewross $
+/* $Id: ps.c 9728 2009-03-12 08:19:17Z smekal $
 
 	PLplot PostScript device driver.
 
@@ -51,7 +51,7 @@
 
 PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_ps = 
   "ps:PostScript File (monochrome):0:ps:29:psm\n"
-  "psc:PostScript File (color):0:ps:30:psc";
+  "psc:PostScript File (color):0:ps:30:psc\n";
 
 
 /* Prototypes for functions in this file. */
@@ -65,7 +65,8 @@ static void  fill_polygon	(PLStream *pls);
 static void  proc_str           (PLStream *, EscText *);
 static void  esc_purge          (unsigned char *, unsigned char *);
 
-static char  outbuf[128];
+#define OUTBUF_LEN 128
+static char  outbuf[OUTBUF_LEN];
 static int text = 1;
 static int color;
 static int hrshsym = 1;
@@ -408,7 +409,7 @@ plD_line_ps(PLStream *pls, short x1a, short y1a, short x2a, short y2a)
 	else
 	    putc(' ', OF);
 
-	sprintf(outbuf, "%d %d D", x2, y2);
+	snprintf(outbuf, OUTBUF_LEN, "%d %d D", x2, y2);
 	dev->ptcnt++;
 	pls->linepos += 12;
     }
@@ -417,9 +418,9 @@ plD_line_ps(PLStream *pls, short x1a, short y1a, short x2a, short y2a)
 	pls->linepos = 0;
 
 	if (x1 == x2 && y1 == y2) /* must be a single dot, draw a circle */
-	  sprintf(outbuf, "%d %d A", x1, y1);
+	  snprintf(outbuf, OUTBUF_LEN, "%d %d A", x1, y1);
 	else
-	  sprintf(outbuf, "%d %d M %d %d D", x1, y1, x2, y2);
+	  snprintf(outbuf, OUTBUF_LEN, "%d %d M %d %d D", x1, y1, x2, y2);
 	dev->llx = MIN(dev->llx, x1);
 	dev->lly = MIN(dev->lly, y1);
 	dev->urx = MAX(dev->urx, x1);
@@ -657,7 +658,7 @@ fill_polygon(PLStream *pls)
 /* First time through start with a x y moveto */
 
 	if (n == 0) {
-	    sprintf(outbuf, "N %d %d M", x, y);
+	    snprintf(outbuf, OUTBUF_LEN, "N %d %d M", x, y);
 	    dev->llx = MIN(dev->llx, x);
 	    dev->lly = MIN(dev->lly, y);
 	    dev->urx = MAX(dev->urx, x);
@@ -676,7 +677,7 @@ fill_polygon(PLStream *pls)
 
 	pls->bytecnt++;
 
-	sprintf(outbuf, "%d %d D", x, y);
+	snprintf(outbuf, OUTBUF_LEN, "%d %d D", x, y);
 	dev->llx = MIN(dev->llx, x);
 	dev->lly = MIN(dev->lly, y);
 	dev->urx = MAX(dev->urx, x);
@@ -734,7 +735,7 @@ proc_str (PLStream *pls, EscText *args)
   #define PROC_STR_STRING_LENGTH 1000
   unsigned char *strp, str[PROC_STR_STRING_LENGTH], *cur_strp, 
      cur_str[PROC_STR_STRING_LENGTH];
-  float font_factor = 1.4;
+  float font_factor = 1.4f;
   PLINT clxmin, clxmax, clymin, clymax; /* Clip limits */
   PLINT clipx[4],clipy[4]; /* Current clip limits */
 
@@ -851,8 +852,8 @@ proc_str (PLStream *pls, EscText *args)
 	
 	/* Determine the adjustment for page orientation */
 	theta -= 90.*pls->diorot;
-	args->y += offset*cos(theta*PI/180.);
-	args->x -= offset*sin(theta*PI/180.);
+	args->y += (PLINT)(offset*cos(theta*PI/180.));
+	args->x -= (PLINT)(offset*sin(theta*PI/180.));
 		
 	/* ps driver is rotated by default */
 	plRotPhy(ORIENTATION, dev->xmin, dev->ymin, dev->xmax, dev->ymax, 
@@ -1018,10 +1019,10 @@ proc_str (PLStream *pls, EscText *args)
 	l1 *= 0.6;
 	l2 *= 0.6;
 	
-	dev->llx = MIN(dev->llx, args->x + (MIN(l1*cs,l2*cs)-1.5) * font_factor * ft_ht * ENLARGE );
-	dev->lly = MIN(dev->lly, args->y + (MIN(l1*sn,l2*sn)-1.5) * font_factor * ft_ht * ENLARGE );
-	dev->urx = MAX(dev->urx, args->x + (MAX(l1*cs,l2*cs)+1.5) * font_factor * ft_ht * ENLARGE );
-	dev->ury = MAX(dev->ury, args->y + (MAX(l1*sn,l2*sn)+1.5) * font_factor * ft_ht * ENLARGE );
+	dev->llx = (int)(MIN(dev->llx, args->x + (MIN(l1*cs,l2*cs)-1.5) * font_factor * ft_ht * ENLARGE));
+	dev->lly = (int)(MIN(dev->lly, args->y + (MIN(l1*sn,l2*sn)-1.5) * font_factor * ft_ht * ENLARGE));
+	dev->urx = (int)(MAX(dev->urx, args->x + (MAX(l1*cs,l2*cs)+1.5) * font_factor * ft_ht * ENLARGE));
+	dev->ury = (int)(MAX(dev->ury, args->y + (MAX(l1*sn,l2*sn)+1.5) * font_factor * ft_ht * ENLARGE));
 
      }
 }
