@@ -1,4 +1,4 @@
-/* $Id: psttf.cc 9074 2008-12-10 10:08:05Z andrewross $
+/* $Id: psttf.cc 9708 2009-03-10 23:52:24Z airwin $
 
 	PLplot PostScript device driver using LASi to provide fonts
 	based on original ps.c PostScript driver
@@ -58,7 +58,7 @@ using namespace std;
 
 PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_psttf = 
   "psttf:PostScript File (monochrome):0:psttf:55:psttfm\n"
-  "psttfc:PostScript File (color):0:psttf:56:psttfc";
+  "psttfc:PostScript File (color):0:psttf:56:psttfc\n";
 
 
 /* Prototypes for functions in this file. */
@@ -72,7 +72,8 @@ static void  fill_polygon	(PLStream *pls);
 static void  proc_str           (PLStream *, EscText *);
 static void  esc_purge          (char *, char *);
 
-static char  outbuf[128];
+#define OUTBUF_LEN 128
+static char  outbuf[OUTBUF_LEN];
 static int text = 1;
 static int color;
 static int hrshsym = 0;
@@ -97,7 +98,8 @@ const char * EnvFamilyLookup[N_Pango_Lookup] = {
   "PLPLOT_FREETYPE_SYMBOL_FAMILY"
 };
 
-char FamilyLookup[N_Pango_Lookup][1024];
+#define FAMILY_LOOKUP_LEN 1024
+char FamilyLookup[N_Pango_Lookup][FAMILY_LOOKUP_LEN];
 
 const FontWeight WeightLookup[2] = {
   NORMAL_WEIGHT,
@@ -283,10 +285,12 @@ ps_init(PLStream *pls)
     // or defaults.
     for (i=0;i<N_Pango_Lookup;i++) {
       if ( (a = getenv(EnvFamilyLookup[i])) != NULL ) {
-	strcpy(FamilyLookup[i],a);
+	strncpy(FamilyLookup[i],a,FAMILY_LOOKUP_LEN-1);
+        FamilyLookup[i][FAMILY_LOOKUP_LEN-1] = '\0';
       }
       else {
-	strcpy(FamilyLookup[i],DefaultFamilyLookup[i]);
+	strncpy(FamilyLookup[i],DefaultFamilyLookup[i],FAMILY_LOOKUP_LEN);
+        FamilyLookup[i][FAMILY_LOOKUP_LEN-1] = '\0';
       }
     }
 
@@ -471,7 +475,7 @@ plD_line_psttf(PLStream *pls, short x1a, short y1a, short x2a, short y2a)
 	else
 	    doc->osBody() << ' ';
 
-	sprintf(outbuf, "%d %d D", x2, y2);
+	snprintf(outbuf, OUTBUF_LEN, "%d %d D", x2, y2);
 	dev->ptcnt++;
 	pls->linepos += 12;
     }
@@ -480,9 +484,9 @@ plD_line_psttf(PLStream *pls, short x1a, short y1a, short x2a, short y2a)
 	pls->linepos = 0;
 
 	if (x1 == x2 && y1 == y2) /* must be a single dot, draw a circle */
-	  sprintf(outbuf, "%d %d A", x1, y1);
+	  snprintf(outbuf, OUTBUF_LEN, "%d %d A", x1, y1);
 	else
-	  sprintf(outbuf, "%d %d M %d %d D", x1, y1, x2, y2);
+	  snprintf(outbuf, OUTBUF_LEN, "%d %d M %d %d D", x1, y1, x2, y2);
 	dev->llx = MIN(dev->llx, x1);
 	dev->lly = MIN(dev->lly, y1);
 	dev->urx = MAX(dev->urx, x1);
@@ -734,7 +738,7 @@ fill_polygon(PLStream *pls)
 /* First time through start with a x y moveto */
 
 	if (n == 0) {
-	    sprintf(outbuf, "N %d %d M", x, y);
+	    snprintf(outbuf, OUTBUF_LEN, "N %d %d M", x, y);
 	    dev->llx = MIN(dev->llx, x);
 	    dev->lly = MIN(dev->lly, y);
 	    dev->urx = MAX(dev->urx, x);
@@ -753,7 +757,7 @@ fill_polygon(PLStream *pls)
 
 	pls->bytecnt++;
 
-	sprintf(outbuf, "%d %d D", x, y);
+	snprintf(outbuf, OUTBUF_LEN, "%d %d D", x, y);
 	dev->llx = MIN(dev->llx, x);
 	dev->lly = MIN(dev->lly, y);
 	dev->urx = MAX(dev->urx, x);
