@@ -1,4 +1,4 @@
-/* $Id: tek.c 8882 2008-10-11 06:15:24Z airwin $
+/* $Id: tek.c 9708 2009-03-10 23:52:24Z airwin $
 
 	PLplot tektronix device & emulators driver.
 */
@@ -49,7 +49,7 @@ PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_tek =
   "vlt:VLT vt100/tek emulator:1:tek:23:vlt\n"
 #endif
 #if defined(PLD_xterm)
-  "xterm:Xterm Window:1:tek:18:xterm"
+  "xterm:Xterm Window:1:tek:18:xterm\n"
 #endif
 ;
 
