@@ -1,4 +1,4 @@
-/* $Id: tk.c 8882 2008-10-11 06:15:24Z airwin $
+/* $Id: tk.c 10255 2009-08-15 03:35:02Z airwin $
  *
  *	PLplot Tcl/Tk and Tcl-DP device drivers.
  *	Should be broken up somewhat better to allow use of DP w/o X.
@@ -46,7 +46,7 @@
 #include "metadefs.h"
 #include "plevent.h"
 
-#if HAVE_UNISTD_H
+#if PL_HAVE_UNISTD_H
 # include <unistd.h>
 #endif
 #include <sys/types.h>
@@ -63,7 +63,7 @@
 #endif
 
 /* Device info */
-PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_tk = "tk:Tcl/TK Window:1:tk:7:tk";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_tk = "tk:Tcl/TK Window:1:tk:7:tk\n";
 
 
 /* Number of instructions to skip between updates */
@@ -79,6 +79,9 @@ PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_tk = "tk:Tcl/TK Window:1:tk:7:tk"
 #define LOCATE_INVOKED_VIA_API		1
 #define LOCATE_INVOKED_VIA_DRIVER	2
 
+#define STR_LEN 10
+#define CMD_LEN 100
+
 /* A handy command wrapper */
 
 #define tk_wr(code) \
@@ -226,7 +229,7 @@ init(PLStream *pls)
     pls->dev_di = 1;		/* Handle driver interface commands */
     pls->dev_flush = 1;		/* Handle our own flushes */
     pls->dev_fill0 = 1;		/* Handle solid fills */
-    pls->dev_fill1 = 1;		/* Handle pattern fills */
+    pls->dev_fill1 = 1;		/* Driver handles pattern fills */
     pls->server_nokill = 1;     /* don't kill if ^C */
     pls->dev_xor = 1;           /* device support xor mode */
 
@@ -641,7 +644,7 @@ static void
 tk_di(PLStream *pls)
 {
     TkDev *dev = (TkDev *) pls->dev;
-    char str[10];
+    char str[STR_LEN];
 
     dbug_enter("tk_di");
 
@@ -659,7 +662,7 @@ tk_di(PLStream *pls)
 /* Change orientation */
 
     if (pls->difilt & PLDI_ORI) {
-	sprintf(str, "%f", pls->diorot);
+	snprintf(str, STR_LEN, "%f", pls->diorot);
 	Tcl_SetVar(dev->interp, "rot", str, 0);
 
 	server_cmd( pls, "$plwidget cmd plsetopt -ori $rot", 1 );
@@ -669,13 +672,13 @@ tk_di(PLStream *pls)
 /* Change window into plot space */
 
     if (pls->difilt & PLDI_PLT) {
-	sprintf(str, "%f", pls->dipxmin);
+	snprintf(str, STR_LEN, "%f", pls->dipxmin);
 	Tcl_SetVar(dev->interp, "xl", str, 0);
-	sprintf(str, "%f", pls->dipymin);
+	snprintf(str, STR_LEN, "%f", pls->dipymin);
 	Tcl_SetVar(dev->interp, "yl", str, 0);
-	sprintf(str, "%f", pls->dipxmax);
+	snprintf(str, STR_LEN, "%f", pls->dipxmax);
 	Tcl_SetVar(dev->interp, "xr", str, 0);
-	sprintf(str, "%f", pls->dipymax);
+	snprintf(str, STR_LEN, "%f", pls->dipymax);
 	Tcl_SetVar(dev->interp, "yr", str, 0);
 
 	server_cmd( pls, "$plwidget cmd plsetopt -wplt $xl,$yl,$xr,$yr", 1 );
@@ -685,13 +688,13 @@ tk_di(PLStream *pls)
 /* Change window into device space */
 
     if (pls->difilt & PLDI_DEV) {
-	sprintf(str, "%f", pls->mar);
+	snprintf(str, STR_LEN, "%f", pls->mar);
 	Tcl_SetVar(dev->interp, "mar", str, 0);
-	sprintf(str, "%f", pls->aspect);
+	snprintf(str, STR_LEN, "%f", pls->aspect);
 	Tcl_SetVar(dev->interp, "aspect", str, 0);
-	sprintf(str, "%f", pls->jx);
+	snprintf(str, STR_LEN, "%f", pls->jx);
 	Tcl_SetVar(dev->interp, "jx", str, 0);
-	sprintf(str, "%f", pls->jy);
+	snprintf(str, STR_LEN, "%f", pls->jy);
 	Tcl_SetVar(dev->interp, "jy", str, 0);
 
 	server_cmd( pls, "$plwidget cmd plsetopt -mar $mar", 1 );
@@ -1324,7 +1327,7 @@ static void
 plwindow_init(PLStream *pls)
 {
     TkDev *dev = (TkDev *) pls->dev;
-    char command[100];
+    char command[CMD_LEN];
     unsigned int bg;
 
     dbug_enter("plwindow_init");
@@ -1346,7 +1349,7 @@ plwindow_init(PLStream *pls)
 
     bg = pls->cmap0[0].b | (pls->cmap0[0].g << 8) | (pls->cmap0[0].r << 16);
     if (bg > 0) {
-	sprintf(command, "$plwidget configure -plbg #%06x", bg);
+	snprintf(command, CMD_LEN, "$plwidget configure -plbg #%06x", bg);
 	server_cmd( pls, command, 0 );
     }
 
@@ -1368,12 +1371,12 @@ plwindow_init(PLStream *pls)
 /* color map options */
 
     if (pls->ncol0) {
-	sprintf(command, "$plwidget cmd plsetopt -ncol0 %d", pls->ncol0);
+	snprintf(command, CMD_LEN, "$plwidget cmd plsetopt -ncol0 %d", pls->ncol0);
 	server_cmd( pls, command, 0 );
     }
 
     if (pls->ncol1) {
-	sprintf(command, "$plwidget cmd plsetopt -ncol1 %d", pls->ncol1);
+	snprintf(command, CMD_LEN, "$plwidget cmd plsetopt -ncol1 %d", pls->ncol1);
 	server_cmd( pls, command, 0 );
     }
 
@@ -1393,7 +1396,7 @@ static void
 set_windowname(PLStream *pls)
 {
   const char *pname;
-  int i;
+  int i, maxlen;
 
   /* Set to "plclient" if not initialized via plargs or otherwise */
 
@@ -1409,14 +1412,15 @@ set_windowname(PLStream *pls)
     pname = pls->program;
 
   if (pls->plwindow == NULL) { /* dont override -plwindow cmd line option */
-    pls->plwindow = (char *) malloc(10+(strlen(pname)) * sizeof(char));
+    maxlen = strlen(pname) + 10;
+    pls->plwindow = (char *) malloc(maxlen * sizeof(char));
 
     /* Allow for multiple widgets created by multiple streams */
 
     if (pls->ipls == 0)
-      sprintf(pls->plwindow, ".%s", pname);
+      snprintf(pls->plwindow, maxlen, ".%s", pname);
     else
-      sprintf(pls->plwindow, ".%s_%d", pname, (int) pls->ipls);
+      snprintf(pls->plwindow, maxlen, ".%s_%d", pname, (int) pls->ipls);
 
     /* Replace any ' 's with '_'s to avoid quoting problems. */
     /* Replace any '.'s (except leading) with '_'s to avoid bad window names. */
