@@ -1,4 +1,4 @@
-/* $Id: tkwin.c 8882 2008-10-11 06:15:24Z airwin $
+/* $Id: tkwin.c 9935 2009-05-07 12:43:52Z andrewross $
  *
  * PLplot Tk device driver.
  *
@@ -80,7 +80,7 @@
 #endif
 
 /* Device info */
-PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_tkwin = "tkwin:New tk driver:1:tkwin:45:tkwin";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_tkwin = "tkwin:New tk driver:1:tkwin:45:tkwin\n";
 
 
 void *	ckcalloc(size_t nmemb, size_t size);
@@ -364,8 +364,7 @@ plD_open_tkwin(PLStream *pls)
 	 * abort operations now
 	 */
 	if (pls->plPlotterPtr == NULL) {
-	    fprintf(stderr, "No tk plframe widget to connect to\n");
-	    exit(1);
+	    plexit("No tk plframe widget to connect to");
 	}
 	/* Old version for MacOS Tk8.0 */
 	/*
@@ -389,8 +388,7 @@ plD_open_tkwin(PLStream *pls)
 	tkwd->display = XOpenDisplay(pls->FileName);
 #endif
 	if (tkwd->display == NULL) {
-	    fprintf(stderr, "Can't open display\n");
-	    exit(1);
+	    plexit( "Can't open display");
 	}
 	tkwd->displayName = pls->FileName;
 	tkwd->screen = DefaultScreen(tkwd->display);
