@@ -1,4 +1,4 @@
-/* $Id: wxwidgets.cpp 9320 2009-01-16 08:56:02Z smekal $
+/* $Id: wxwidgets.cpp 10360 2009-09-01 06:47:01Z smekal $
 
    Copyright (C) 2005  Werner Smekal, Sjaak Verdoold
    Copyright (C) 2005  Germain Carrera Corraleche
@@ -25,6 +25,11 @@
  * - NA
  */
 
+/* wxwidgets headers */
+#include <wx/wx.h>
+#include <wx/wfstream.h>
+#include <wx/except.h>
+
 #include "plDevs.h"
 
 /* plplot headers */
@@ -34,11 +39,6 @@
 /* C/C++ headers */
 #include <cstdio>
 
-/* wxwidgets headers */
-#include <wx/wx.h>
-#include <wx/wfstream.h>
-#include <wx/except.h>
-
 #include "wxwidgets.h"
 
 #ifdef __WXMAC__
@@ -115,7 +115,7 @@ PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_wxwidgets =
  *
  *  Contructor of base class of wxPLDev classes.
  *--------------------------------------------------------------------------*/
-wxPLDevBase::wxPLDevBase( void )
+wxPLDevBase::wxPLDevBase( int bcknd ) : backend(bcknd)
 {
   // Log_Verbose( "wxPLDevBase::wxPLDevBase()" );
 
@@ -128,6 +128,8 @@ wxPLDevBase::wxPLDevBase( void )
   comcount = 0;
 
   m_frame=NULL;
+  xpos=0;
+  ypos=0;
   // width, height are set in plD_init_wxwidgets
   // bm_width, bm_height are set in install_buffer
   
@@ -212,14 +214,14 @@ void wxPLDevBase::PSDrawText( PLUNICODE* ucs4, int ucs4Len, bool drawText )
     if( ucs4[i] < PL_FCI_MARK ) {	/* not a font change */
       if( ucs4[i] != (PLUNICODE)plplotEsc ) {  /* a character to display */
         ucs4_to_utf8( ucs4[i], utf8 );
-        strcat( utf8_string, utf8 );
+        strncat( utf8_string, utf8, max_string_length );
       	i++;
       	continue;
       }
       i++;
       if( ucs4[i] == (PLUNICODE)plplotEsc ) {   /* a escape character to display */
         ucs4_to_utf8( ucs4[i], utf8 );
-        strcat( utf8_string, utf8 );
+        strncat( utf8_string, utf8, max_string_length );
         i++;
         continue;
       } else {
@@ -289,16 +291,16 @@ wxPLDevBase* common_init(  PLStream *pls )
   wxPLDevBase* dev;
 
   /* default options */
-  static PLINT freetype=0;
+  static PLINT freetype=-1;
   static PLINT smooth_text=1;
-  static PLINT text=1;
+  static PLINT text=-1;
   static PLINT hrshsym = 0;
   
   /* default backend uses wxGraphicsContext, if not available
      the agg library will be used, if not available the basic
      backend will be used. */
   static PLINT backend=wxBACKEND_DC;
-	#if wxUSE_GRAPHICS_CONTEXT
+  #if wxUSE_GRAPHICS_CONTEXT
 		backend=wxBACKEND_GC;
 	#else
 		#ifdef HAVE_AGG 
@@ -306,16 +308,16 @@ wxPLDevBase* common_init(  PLStream *pls )
 		#endif
 	#endif
 
-  
-DrvOpt wx_options[] = {
+  DrvOpt wx_options[] = {
 #ifdef HAVE_FREETYPE
-  {"freetype", DRV_INT, &freetype, "Use FreeType library"},
-  {"smooth", DRV_INT, &smooth_text, "Turn text smoothing on (1) or off (0)"},
+    {"freetype", DRV_INT, &freetype, "Use FreeType library"},
+    {"smooth", DRV_INT, &smooth_text, "Turn text smoothing on (1) or off (0)"},
 #endif
-  {"hrshsym", DRV_INT, &hrshsym, "Use Hershey symbol set (hrshsym=0|1)"},
-  {"backend", DRV_INT, &backend, "Choose backend: (0) standard, (1) using AGG library, (2) using wxGraphicsContext"},
-  {"text", DRV_INT, &text, "Use own text routines (text=0|1)"},
-  {NULL, DRV_INT, NULL, NULL}};
+    {"hrshsym", DRV_INT, &hrshsym, "Use Hershey symbol set (hrshsym=0|1)"},
+    {"backend", DRV_INT, &backend, "Choose backend: (0) standard, (1) using AGG library, (2) using wxGraphicsContext"},
+    {"text", DRV_INT, &text, "Use own text routines (text=0|1)"},
+    {NULL, DRV_INT, NULL, NULL}
+  };
 
   /* Check for and set up driver options */
   plParseDrvOpts( wx_options );
@@ -328,6 +330,9 @@ DrvOpt wx_options[] = {
      if available) in this list will be used */
 #if wxUSE_GRAPHICS_CONTEXT    
     dev = new wxPLDevGC;
+    /* by default the own text routines are used for wxGC */
+    if(text==-1)
+      text=1; 
     freetype = 0; /* this backend is vector oriented and doesn't know pixels */
     break;
 #endif
@@ -336,16 +341,26 @@ DrvOpt wx_options[] = {
      will be used */
 #ifdef HAVE_AGG
     dev = new wxPLDevAGG;
+    /* by default the freetype text routines are used for wxAGG */
     text = 0; /* text processing doesn't work yet for the AGG backend */
+    if(freetype==-1)
+      freetype=1;
     break;
 #endif
   default:
     dev = new wxPLDevDC;
+    /* by default the own text routines are used for wxDC */
+    if(text==-1)
+      if(freetype!=1)
+        text=1;
+      else
+        text=0;
+    if(freetype==-1)
+      freetype=0;      
     break;
   }
 	if( dev == NULL) {
-    fprintf( stderr, "Insufficient memory\n" );
-    exit( 0 );
+    plexit( "Insufficient memory" );
   }
   pls->dev = (void*)dev;
  
@@ -359,6 +374,7 @@ DrvOpt wx_options[] = {
 #endif
 
   pls->color = 1;		    /* Is a color device */
+  pls->dev_flush = 1;   /* Handles flushes */
   pls->dev_fill0 = 1;		/* Can handle solid fills */
   pls->dev_fill1 = 0;		/* Can't handle pattern fills */
   pls->dev_dash = 0;
@@ -372,6 +388,8 @@ DrvOpt wx_options[] = {
   }
   
 #ifdef HAVE_FREETYPE
+  /* own text routines have higher priority over freetype
+     if text and freetype option are set to 1 */
   if( !text) {
     dev->smooth_text=smooth_text;
     dev->freetype=freetype;
@@ -389,7 +407,7 @@ DrvOpt wx_options[] = {
   }
 #endif
 
-  /* initialize device storage */
+  /* initialize frame size and position */
   if( pls->xlength <= 0 || pls->ylength <=0 )
     plspage( 0.0, 0.0, (PLINT)(CANVAS_WIDTH*DEVICE_PIXELS_PER_IN), 
                        (PLINT)(CANVAS_HEIGHT*DEVICE_PIXELS_PER_IN), 0, 0 );
@@ -399,6 +417,12 @@ DrvOpt wx_options[] = {
   dev->clipminx=pls->xlength;
   dev->clipminy=pls->ylength;
   
+  if( pls->xoffset!=0 || pls->yoffset!=0) {
+    dev->xpos = (int)(pls->xoffset);
+    dev->ypos = (int)(pls->yoffset);
+  }
+
+  
   /* If portrait mode, apply a rotation and set freeaspect */
   if( pls->portrait ) {
     plsdiori( (PLFLT)(4 - ORIENTATION) );
@@ -526,9 +550,11 @@ void plD_init_wxpng( PLStream *pls )
   plOpenFile( pls );  
 
   pls->plbuf_write = 1;        /* use the plot buffer! */
-  pls->termin = 0;             /* interactive device */
+  pls->dev_flush = 0;          /* No need for flushes */
+  pls->termin = 0;             /* file oriented device */
   pls->graphx = GRAPHICS_MODE; /*  No text mode for this driver (at least for now, might add a console window if I ever figure it out and have the inclination) */
-
+  pls->page = 0;
+  
   dev->showGUI = false;  
   dev->bitmapType = wxBITMAP_TYPE_PNG;
 }
@@ -554,7 +580,7 @@ void plD_line_wxwidgets( PLStream *pls, short x1a, short y1a, short x2a, short y
   dev->DrawLine( x1a, y1a, x2a, y2a );
     
   if( !(dev->resizing) && dev->ownGUI ) {
-		dev->comcount+=10;
+		dev->comcount++;
 		if( dev->comcount>MAX_COMCOUNT ) {
 			wxRunApp( pls, true );
 			dev->comcount=0;
@@ -582,7 +608,7 @@ void plD_polyline_wxwidgets( PLStream *pls, short *xa, short *ya, PLINT npts )
   dev->DrawPolyline( xa, ya, npts );
 
   if( !(dev->resizing) && dev->ownGUI ) {
-    dev->comcount+=10;
+    dev->comcount++;
 		if( dev->comcount>MAX_COMCOUNT ) {
 			wxRunApp( pls, true );
 			dev->comcount=0;
@@ -642,6 +668,22 @@ void plD_bop_wxwidgets( PLStream *pls )
   wxPLDevBase* dev = (wxPLDevBase*)pls->dev;
 
   if( dev->ready ) {
+    /*if( pls->termin==0 ) {
+      plGetFam( pls );*/
+      /* force new file if pls->family set for all subsequent calls to plGetFam
+         n.b. putting this after plGetFam call is important since plinit calls
+         bop, and you don't want the familying sequence started until after
+         that first call to bop.*/
+
+      /* n.b. pls->dev can change because of an indirect call to plD_init_png
+         from plGetFam if familying is enabled.  Thus, wait to define dev until
+         now. */
+      /*dev = (wxPLDevBase*)pls->dev;
+
+      pls->famadv = 1;
+      pls->page++;
+    }*/
+
     /* clear background */
 		PLINT bgr, bgg, bgb;  /* red, green, blue */
 		plgcolbg( &bgr, &bgg, &bgb);  /* get background color information */
@@ -808,11 +850,22 @@ void plD_esc_wxwidgets( PLStream *pls, PLINT op, void *ptr )
 													pls->sppxmi, pls->sppymi, pls->sppxma, pls->sppyma );
 		break;
   
+	case PLESC_FLUSH:    /* forced update of the window */
+		if( !(dev->resizing) && dev->ownGUI ) {
+			wxRunApp( pls, true );
+			dev->comcount=0;
+		}
+		break;
+
   case PLESC_GETC:
     if( dev->ownGUI )
       GetCursorCmd( pls, (PLGraphicsIn *) ptr );
 	  break;
 
+  case PLESC_GETBACKEND:
+    *((int*)ptr) = dev->backend;
+	  break;
+
   default:
     break;
   }
@@ -1092,11 +1145,12 @@ static void init_freetype_lv2( PLStream *pls )
          }
         FT->smooth_text=1;      /* Yippee ! We had success setting up the extended cmap0 */
       }
+    else
+      plwarn("Insufficient colour slots available in CMAP0 to do text smoothing.");
   } else if ((FT->want_smooth_text==1)&&(FT->BLENDED_ANTIALIASING==1))    /* If we have a truecolour device, we wont even bother trying to change the palette */
    {
      FT->smooth_text=1;
-   } else
-     plwarn("Insufficient colour slots available in CMAP0 to do text smoothing.");
+   } 
 }
 
 #endif
@@ -1169,7 +1223,7 @@ static void install_buffer( PLStream *pls )
     wxTRY {
       wxPLGetApp().CallOnInit();
     }
-    wxCATCH_ALL( wxPLGetApp().OnUnhandledException(); fprintf(stderr, "Can't init wxWidgets!\n"); exit(0); )
+    wxCATCH_ALL( wxPLGetApp().OnUnhandledException(); plexit( "Can't init wxWidgets!"); )
     initApp=true;
   }
   
@@ -1190,7 +1244,14 @@ static void install_buffer( PLStream *pls )
   }
   dev->m_frame = new wxPLplotFrame( title, pls );
   wxPLGetApp().AddFrame( dev->m_frame );
+
+  /* set size and position of window */
   dev->m_frame->SetClientSize( dev->width, dev->height );
+  if( dev->xpos!=0 || dev->ypos!=0)
+    dev->m_frame->SetSize( dev->xpos, dev->ypos,
+                           wxDefaultCoord, wxDefaultCoord,
+                           wxSIZE_USE_EXISTING );    
+  
   if( dev->showGUI ) {
     dev->m_frame->Show( true );
     dev->m_frame->Raise();
@@ -1248,7 +1309,7 @@ static void wxRunApp( PLStream *pls, bool runonce )
 		wxPLGetApp().OnRun();   /* start wxWidgets application */
     callOnExit.exit=false;
   }
-  wxCATCH_ALL( wxPLGetApp().OnUnhandledException(); fprintf(stderr, "Problem running wxWidgets!\n"); exit(0); )
+  wxCATCH_ALL( wxPLGetApp().OnUnhandledException(); plexit("Problem running wxWidgets!"); )
 
   if( dev->exit ) {
     wxPLGetApp().OnExit();
