@@ -1,4 +1,4 @@
-/* $Id: wxwidgets.h 9183 2008-12-18 08:38:53Z smekal $
+/* $Id: wxwidgets.h 10360 2009-09-01 06:47:01Z smekal $
 
    Copyright (C) 2008  Werner Smekal
 
@@ -89,7 +89,7 @@ class wxPLplotFrame;
 class wxPLDevBase
 {
 public: /* methods */
-	wxPLDevBase( void );
+	wxPLDevBase( int bcknd );
 	virtual ~wxPLDevBase( void );
 
   // virtual functions which need to implemented
@@ -115,16 +115,18 @@ public: /* methods */
   virtual void PSSetFont( PLUNICODE fci )=0;
 
 public: /* variables */
+  const int backend;
   bool ready;
   bool ownGUI;
   bool showGUI;
   bool waiting;
   bool resizing;
   bool exit;
-  int backend;
   int comcount;
   
   wxPLplotFrame* m_frame;
+  PLINT xpos;
+  PLINT ypos;
   PLINT width;
   PLINT height;
   PLINT bm_width;
@@ -304,6 +306,8 @@ private: /* variables */
 
 
 #if wxUSE_GRAPHICS_CONTEXT
+#include <wx/graphics.h>
+
 class wxPLDevGC : public wxPLDevBase
 {
 public: /* methods */
@@ -359,7 +363,7 @@ struct dev_entry {
 
 
 /* after how many commands the window should be refreshed */
-#define MAX_COMCOUNT 5000
+#define MAX_COMCOUNT 10000
 
 /* wxwidgets application definition (if needed) */
 WX_DEFINE_ARRAY( wxPLplotFrame*, wxArrayOfwxPLplotFrame );
