@@ -1,4 +1,4 @@
-/* $Id: wxwidgets_agg.cpp 9183 2008-12-18 08:38:53Z smekal $
+/* $Id: wxwidgets_agg.cpp 9715 2009-03-11 14:33:48Z smekal $
 
    Copyright (C) 2008  Werner Smekal
 
@@ -24,15 +24,15 @@
  *   is commented out, since there are problems with the affine transformation 
  */
 
+/* wxwidgets headers */
+#include <wx/wx.h>
+#include <wx/strconv.h>
+
 #include "plDevs.h"
 
 /* plplot headers */
 #include "plplotP.h"
 #include "plfci-truetype.h"
-
-/* wxwidgets headers */
-#include <wx/wx.h>
-#include <wx/strconv.h>
    
 /* std and driver headers */
 #include "wxwidgets.h"
@@ -65,7 +65,7 @@
  *  class. Initialisations of variables and objects are done.
  *--------------------------------------------------------------------------*/
 wxPLDevAGG::wxPLDevAGG() :
-		wxPLDevBase(),
+		wxPLDevBase(wxBACKEND_AGG),
     mRenderingBuffer(),
     mPixFormat( mRenderingBuffer ),
     mRendererBase( mPixFormat ),
@@ -93,8 +93,6 @@ wxPLDevAGG::wxPLDevAGG() :
     mColorGreenFill( 0 ),
     mColorBlueFill( 0 )
 {
-  backend=wxBACKEND_AGG;
-	
   mCurves.approximation_scale( 2.0 );
   mContour.auto_detect_orientation( false );
   mConvStroke.line_join( agg::round_join );
@@ -107,7 +105,7 @@ wxPLDevAGG::wxPLDevAGG() :
     char WINDIR_PATH[255];
     char *b;
     b=getenv("WINDIR");
-    strcpy(WINDIR_PATH,b);*/
+    strncpy(WINDIR_PATH,b,255);*/
 
 /*
  * Work out if we have Win95+ or Win3.?... sort of.
@@ -129,7 +127,7 @@ wxPLDevAGG::wxPLDevAGG() :
     }
     else
     {
-      strcat(WINDIR_PATH,"\\fonts\\arial.ttf");
+      strncat(WINDIR_PATH,"\\fonts\\arial.ttf",255);
       if (access(WINDIR_PATH, F_OK)==0)
         {
           b=strrchr(WINDIR_PATH,'\\');
