@@ -1,4 +1,4 @@
-/* $Id: xfig.c 9271 2009-01-07 12:13:11Z andrewross $
+/* $Id: xfig.c 9718 2009-03-11 15:29:54Z smekal $
 
 	PLplot xfig device driver.
 */
@@ -10,7 +10,7 @@
 #include "drivers.h"
 
 /* Device info */
-PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_xfig = "xfig:Fig file:0:xfig:31:xfig";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_xfig = "xfig:Fig file:0:xfig:31:xfig\n";
 
 typedef struct {
   PLINT xold, yold;
@@ -141,7 +141,7 @@ plD_init_xfig(PLStream *pls)
       pls->color = 1;         /* Is a color device */
 
     plP_setpxl(dev->xscale_dev, dev->xscale_dev); /* dpmm -- dots per mm */
-    plP_setphy(0, FIGX * dev->xscale_dev, 0, FIGY * dev->yscale_dev); /* physical dimension in mm */ 
+    plP_setphy(0, (PLINT)(FIGX * dev->xscale_dev), 0, (PLINT)(FIGY * dev->yscale_dev)); /* physical dimension in mm */ 
 
 /* Write out header */
 
@@ -541,8 +541,8 @@ proc_str (PLStream *pls, EscText *args)
     ref = DPI/72. * ft_ht / 2.;
 
   /* rotate point in xfig is lower left corner, compensate */
-  args->y = dev->offset + dev->ymax * (int)dev->xscale_dev - (args->y - ref*cos(alpha));
-  args->x = args->x + ref*sin(alpha);
+  args->y = (PLINT)(dev->offset + dev->ymax * (int)dev->xscale_dev - (args->y - ref*cos(alpha)));
+  args->x = (PLINT)(args->x + ref*sin(alpha));
 
   /*
    *  font family, serie and shape. Currently not supported by plplot
