@@ -1,4 +1,4 @@
-/* $Id: xwin.c 8882 2008-10-11 06:15:24Z airwin $
+/* $Id: xwin.c 9935 2009-05-07 12:43:52Z andrewross $
 
 	PLplot X-windows device driver.
 
@@ -45,7 +45,7 @@ static int already = 0;
 #endif
 
 /* Device info */
-PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_xwin = "xwin:X-Window (Xlib):1:xwin:5:xw";
+PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_xwin = "xwin:X-Window (Xlib):1:xwin:5:xw\n";
 
 static int synchronize = 0;	/* change to 1 for X synchronized operation */
                                 /* Use "-drvopt sync" cmd line option to set. */
@@ -112,6 +112,8 @@ static int usepthreads = 1;     /* use "-drvopt usepth=0" to not use pthreads to
 #define ROMAP_CMAP1_COLORS 50
 #define TC_CMAP1_COLORS 200
 
+#define HEADER_LEN 1024
+
 /* Variables to hold RGB components of given colormap. */
 /* Used in an ugly hack to get past some X11R5 and TK limitations. */
 
@@ -923,12 +925,11 @@ OpenXwin(PLStream *pls)
 #ifdef HAVE_PTHREAD
 	if (usepthreads)
 	  if (! XInitThreads())
-	    plexit("xwin: XInitThreads() not successful.\n");
+	    plexit("xwin: XInitThreads() not successful.");
 #endif
 	xwd->display = XOpenDisplay(pls->FileName);
 	if (xwd->display == NULL) {
-	    fprintf(stderr, "Can't open display\n");
-	    exit(1);
+	    plexit("Can't open display");
 	}
 	xwd->displayName = pls->FileName;
 	xwd->screen = DefaultScreen(xwd->display);
@@ -1085,7 +1086,7 @@ InitMain(PLStream *pls)
     XSizeHints hint;
     int x, y;
     U_INT width, height, border, depth;
-    char header[1024];
+    char header[HEADER_LEN];
 
     dbug_enter("InitMain");
 
@@ -1129,13 +1130,14 @@ InitMain(PLStream *pls)
 /* Window title */
 
     if (pls->plwindow){    /* allow -plwindow to specify wm decoration name */
-	sprintf(header, "%s", pls->plwindow);
+	strncpy(header, pls->plwindow, HEADER_LEN);
     }
     else if(pls->program) {
-	sprintf(header, "%s", pls->program); /* else program name */
+	strncpy(header, pls->program, HEADER_LEN); /* else program name */
     }
     else
-	sprintf(header,"%s","Plplot");
+	strncpy(header,"Plplot",HEADER_LEN);
+    header[HEADER_LEN-1] = '\0';
 
 /* Window creation */
 
@@ -2450,8 +2452,7 @@ GetVisual(PLStream *pls)
 		}
 	    }
 	    if (!found) {
-		printf( "Unable to get a StaticColor visual.\n" );
-		exit(1);
+		plexit( "Unable to get a StaticColor visual." );
 	    }
 	    printf( "Found StaticColor visual, depth=%d\n", xwd->depth );
 	}
