@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x01.cc 9130 2008-12-16 12:23:21Z andrewross $
+// $Id: x01.cc 10169 2009-07-20 21:12:55Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -31,11 +31,11 @@
 #include "plevent.h"
 #include <cctype>
 
-#ifdef HAVE_UNISTD_H
+#ifdef PL_HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
-#ifdef USE_NAMESPACE
+#ifdef PL_USE_NAMESPACE
 using namespace std;
 #endif
 
