@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x03.cc 9130 2008-12-16 12:23:21Z andrewross $
+// $Id: x03.cc 10352 2009-08-27 16:38:57Z airwin $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -28,7 +28,7 @@
 
 #include "plc++demos.h"
 
-#ifdef USE_NAMESPACE
+#ifdef PL_USE_NAMESPACE
 using namespace std;
 #endif
 
@@ -47,7 +47,7 @@ private:
 
 x03::x03( int argc, const char ** argv ) {
 
-  int i, j;
+  int i;
   char text[4];
   PLFLT dtr, theta, dx, dy, r, offset;
 
@@ -81,15 +81,9 @@ x03::x03( int argc, const char ** argv ) {
   // Set up viewport and window, but do not draw box.
 
   pls->env(-1.3, 1.3, -1.3, 1.3, 1, -2);
+  // Draw circles for polar grid
   for (i = 1; i <= 10; i++) {
-    for (j = 0; j <= 360; j++) {
-      x[j] = 0.1 * i * x0[j];
-      y[j] = 0.1 * i * y0[j];
-    }
-
-    // Draw circles for polar grid.
-
-    pls->line(361, x, y);
+      pls->arc(0.0, 0.0, 0.1 * i, 0.1 * i, 0.0, 360.0, 0);
   }
 
   pls->col0(2);
