@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x05.cc 8033 2007-11-23 15:28:09Z andrewross $
+// $Id: x05.cc 10169 2009-07-20 21:12:55Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -28,7 +28,7 @@
 
 #include "plc++demos.h"
 
-#ifdef USE_NAMESPACE
+#ifdef PL_USE_NAMESPACE
 using namespace std;
 #endif
 
