@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x09.cc 9130 2008-12-16 12:23:21Z andrewross $
+// $Id: x09.cc 10169 2009-07-20 21:12:55Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -28,7 +28,7 @@
 
 #include "plc++demos.h"
 
-#ifdef USE_NAMESPACE
+#ifdef PL_USE_NAMESPACE
 using namespace std;
 #endif
 
@@ -101,8 +101,8 @@ x09::x09( int argc, const char **argv ) {
 
   int i, j;
 
-  PLFLT xg1[XPTS];
-  PLFLT yg1[YPTS];
+  PLFLT *xg1 = new PLFLT[XPTS];
+  PLFLT *yg1 = new PLFLT[YPTS];
   PLcGrid cgrid1;
   PLcGrid2 cgrid2;
   PLFLT **z;
@@ -264,6 +264,9 @@ x09::x09( int argc, const char **argv ) {
   pls->Free2dGrid(w,XPTS,YPTS);
 
   delete pls;
+
+  delete yg1;
+  delete xg1;
 }
 
 void x09::polar()
