@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x13.cc 9130 2008-12-16 12:23:21Z andrewross $
+// $Id: x13.cc 10169 2009-07-20 21:12:55Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -28,7 +28,7 @@
 
 #include "plc++demos.h"
 
-#ifdef USE_NAMESPACE
+#ifdef PL_USE_NAMESPACE
 using namespace std;
 #endif
 
