@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x16.cc 8033 2007-11-23 15:28:09Z andrewross $
+// $Id: x16.cc 10352 2009-08-27 16:38:57Z airwin $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -28,7 +28,7 @@
 
 #include "plc++demos.h"
 
-#ifdef USE_NAMESPACE
+#ifdef PL_USE_NAMESPACE
 using namespace std;
 #endif
 
@@ -48,10 +48,6 @@ private:
   static int ny;
   static int exclude;
   const static int PERIMETERPTS;
-
-  // calculated constants and array that depends on them
-  PLFLT xspa;
-  PLFLT ypsa;
 public:
   static PLFLT tr[];
 
@@ -158,6 +154,10 @@ x16::x16( int argc, const char ** argv ) {
   pls->MergeOpts(options, "x16c options", notes);
   pls->parseopts( &argc, argv, PL_PARSE_FULL );
 
+  // Load colour palettes
+  pls->spal0("cmap0_black_on_white.pal");
+  pls->spal1("cmap1_gray.pal",true);
+
   // Reduce colors in cmap 0 so that cmap 1 is useful on a
   //16-color display
   pls->scmap0n(3);
@@ -169,11 +169,6 @@ x16::x16( int argc, const char ** argv ) {
   pls->Alloc2dGrid(&z,nx,ny);
   pls->Alloc2dGrid(&w,nx,ny);
 
-  // calculated constants and array that depends on them
-  PLFLT xspa =  2./(nx-1);
-  PLFLT yspa =  2./(ny-1);
-
-
   // Set up data array
 
   for (i = 0; i < nx; i++) {
@@ -242,6 +237,10 @@ x16::x16( int argc, const char ** argv ) {
 
   // Plot using 1d coordinate transform
 
+  pls->spal0("cmap0_black_on_white.pal");
+  pls->spal1("cmap1_blue_yellow.pal",true);
+  pls->scmap0n(3);
+
   pls->adv(0);
   pls->vpor(0.1, 0.9, 0.1, 0.9);
   pls->wind(-1.0, 1.0, -1.0, 1.0);
@@ -261,6 +260,10 @@ x16::x16( int argc, const char ** argv ) {
 
   // Plot using 2d coordinate transform
 
+  pls->spal0("cmap0_black_on_white.pal");
+  pls->spal1("cmap1_blue_red.pal",true);
+  pls->scmap0n(3);
+
   pls->adv(0);
   pls->vpor(0.1, 0.9, 0.1, 0.9);
   pls->wind(-1.0, 1.0, -1.0, 1.0);
@@ -281,6 +284,10 @@ x16::x16( int argc, const char ** argv ) {
 
   // Plot using 2d coordinate transform
 
+  pls->spal0("");
+  pls->spal1("",true);
+  pls->scmap0n(3);
+
   pls->adv(0);
   pls->vpor(0.1, 0.9, 0.1, 0.9);
   pls->wind(-1.0, 1.0, -1.0, 1.0);
@@ -302,6 +309,10 @@ x16::x16( int argc, const char ** argv ) {
   // Plot using 2d coordinate transform and exclusion
 
   if(exclude) {
+    pls->spal0("cmap0_black_on_white.pal");
+    pls->spal1("cmap1_gray.pal",true);
+    pls->scmap0n(3);
+
     pls->adv(0);
     pls->vpor(0.1, 0.9, 0.1, 0.9);
     pls->wind(-1.0, 1.0, -1.0, 1.0);
@@ -322,6 +333,10 @@ x16::x16( int argc, const char ** argv ) {
 
   //Example with polar coordinates.
 
+  pls->spal0("cmap0_black_on_white.pal");
+  pls->spal1("cmap1_gray.pal",true);
+  pls->scmap0n(3);
+
   pls->adv(0);
   pls->vpor( .1, .9, .1, .9 );
   pls->wind( -1., 1., -1., 1. );
