@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x17.cc 9283 2009-01-08 20:46:17Z andrewross $
+// $Id: x17.cc 10169 2009-07-20 21:12:55Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -27,15 +27,15 @@
 //---------------------------------------------------------------------------//
 
 #include "plc++demos.h"
-#ifdef HAVE_UNISTD_H
+#ifdef PL_HAVE_UNISTD_H
 # include <unistd.h>
 #else
-# ifdef HAS_POLL
+# ifdef PL_HAVE_POLL
 #  include <poll.h>
 # endif
 #endif
 
-#ifdef USE_NAMESPACE
+#ifdef PL_USE_NAMESPACE
 using namespace std;
 #endif
 
@@ -153,7 +153,7 @@ x17::x17( int argc, const char ** argv ) {
 #ifdef PL_HAVE_USLEEP
     usleep(10000);  /* wait a little (10 ms) to simulate time elapsing */
 #else
-# ifdef HAS_POLL
+# ifdef PL_HAVE_POLL
     poll(0,0,10);
 # else
     { int i; for( i=0; i<1000000; i++ ); }
