@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x20.cc 8839 2008-09-30 18:10:24Z airwin $
+// $Id: x20.cc 10169 2009-07-20 21:12:55Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -30,7 +30,7 @@
 #include "plevent.h"
 #include <fstream>
 
-#ifdef USE_NAMESPACE
+#ifdef PL_USE_NAMESPACE
 using namespace std;
 #endif
 
@@ -128,7 +128,9 @@ mypltr(PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data)
 }
 
 x20::x20( int argc, const char ** argv ) {
-  PLFLT x[XDIM], y[YDIM], **z, **r;
+  PLFLT *x = new PLFLT[XDIM];
+  PLFLT *y = new PLFLT[YDIM];
+  PLFLT **z, **r;
   PLFLT xi, yi, xe, ye;
   int i, j, width, height, num_col;
   PLFLT **img_f;
@@ -326,7 +328,9 @@ x20::x20( int argc, const char ** argv ) {
   pls->Free2dGrid(img_f, width, height);
 
   delete pls;
-
+  
+  delete y;
+  delete x;
 }
 
 // read image from file in binary ppm format
