@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x21.cc 9278 2009-01-08 14:30:16Z andrewross $
+// $Id: x21.cc 10169 2009-07-20 21:12:55Z andrewross $
 //---------------------------------------------------------------------------//
 //
 //---------------------------------------------------------------------------//
@@ -28,21 +28,12 @@
 
 #include "plc++demos.h"
 
-#if !defined(HAVE_ISNAN)
-  #define isnan(x) ((x) != (x))
-#endif
-
-#if defined(WIN32) && (defined(_MSC_VER) || defined(__BORLANDC__))
-#undef isnan
-#define isnan _isnan
-#endif
-
 // Need for some Mac OSX systems with broken <cmath> header
-#ifdef BROKEN_ISNAN_CXX
+#ifdef PL_BROKEN_ISNAN_CXX
 extern "C" int isnan (double);
 #endif
 
-#ifdef USE_NAMESPACE
+#ifdef PL_USE_NAMESPACE
 using namespace std;
 #endif
 
