@@ -1,4 +1,4 @@
-/* $Id: x30.cc 8979 2008-10-29 14:19:56Z andrewross $
+/* $Id: x30.cc 10169 2009-07-20 21:12:55Z andrewross $
 
   Alpha color values demonstration.
 
@@ -28,7 +28,7 @@
 
 #include "plc++demos.h"
 
-#ifdef USE_NAMESPACE
+#ifdef PL_USE_NAMESPACE
 using namespace std;
 #endif
 
