@@ -1,4 +1,4 @@
-/* $Id: x02c.c 8613 2008-08-07 22:04:18Z airwin $
+/* $Id: x02c.c 9616 2009-02-25 22:00:47Z smekal $
 
 	Multiple window and color map 0 demo.
 */
@@ -97,9 +97,9 @@ void demo2()
 	      i+16,h,l,s,r1,g1,b1); */
 
         /* Use 255.001 to avoid close truncation decisions in this example. */
-        r[i+16] = r1 * 255.001;
-        g[i+16] = g1 * 255.001;
-        b[i+16] = b1 * 255.001;
+        r[i+16] = (PLINT)(r1 * 255.001);
+        g[i+16] = (PLINT)(g1 * 255.001);
+        b[i+16] = (PLINT)(b1 * 255.001);
     }
 
 /* Load default cmap0 colors into our custom set */
