@@ -1,4 +1,4 @@
-/* $Id: x05c.c,v 1.17 2005/10/07 17:53:37 airwin Exp $
+/* $Id: x05c.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	Histogram demo.
 */
@@ -14,7 +14,7 @@
 \*--------------------------------------------------------------------------*/
 
 int
-main(int argc, char *argv[])
+main(int argc, const char *argv[])
 {
     int i;
     PLFLT data[NPTS], delta;
