@@ -1,4 +1,4 @@
-/* $Id: x06c.c,v 1.17 2005/04/05 19:16:15 airwin Exp $
+/* $Id: x06c.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	Font demo.
 */
@@ -12,7 +12,7 @@
 \*--------------------------------------------------------------------------*/
 
 int
-main(int argc, char *argv[])
+main(int argc, const char *argv[])
 {
     char text[10];
     int i, j, k;
