@@ -1,4 +1,4 @@
-/* $Id: x08c.c 6375 2005-10-07 17:53:37Z airwin $
+/* $Id: x08c.c 8033 2007-11-23 15:28:09Z andrewross $
 
 	3-d plot demo.
 
@@ -113,7 +113,7 @@ static PLOptionTable options[] = {
 #define LEVELS 10
 
 int
-main(int argc, char *argv[])
+main(int argc, const char *argv[])
 {
   int i, j, k;
   PLFLT *x, *y, **z;
