@@ -1,4 +1,4 @@
-/* $Id: x16c.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: x16c.c 10302 2009-08-20 00:09:10Z hezekiahcarty $
 
 	plshade demo, using color fill.
 
@@ -124,10 +124,11 @@ main(int argc, const char *argv[])
     plMergeOpts(options, "x16c options", notes);
     plparseopts(&argc, argv, PL_PARSE_FULL);
 
+/* Load colour palettes*/
+    plspal0("cmap0_black_on_white.pal");
+    plspal1("cmap1_gray.pal", 1);
 /* Reduce colors in cmap 0 so that cmap 1 is useful on a 16-color display */
-
     plscmap0n(3);
-
 /* Initialize plplot */
 
     plinit();
@@ -220,6 +221,12 @@ main(int argc, const char *argv[])
 
 /* Plot using 1d coordinate transform */
     
+/* Load colour palettes*/
+    plspal0("cmap0_black_on_white.pal");
+    plspal1("cmap1_blue_yellow.pal", 1);
+/* Reduce colors in cmap 0 so that cmap 1 is useful on a 16-color display */
+    plscmap0n(3);
+
     pladv(0);
     plvpor(0.1, 0.9, 0.1, 0.9);
     plwind(-1.0, 1.0, -1.0, 1.0);
@@ -241,6 +248,12 @@ main(int argc, const char *argv[])
 
 /* Plot using 2d coordinate transform */
 
+/* Load colour palettes*/
+    plspal0("cmap0_black_on_white.pal");
+    plspal1("cmap1_blue_red.pal", 1);
+/* Reduce colors in cmap 0 so that cmap 1 is useful on a 16-color display */
+    plscmap0n(3);
+
     pladv(0);
     plvpor(0.1, 0.9, 0.1, 0.9);
     plwind(-1.0, 1.0, -1.0, 1.0);
@@ -261,6 +274,12 @@ main(int argc, const char *argv[])
 
 /* Plot using 2d coordinate transform */
 
+/* Load colour palettes*/
+    plspal0("");
+    plspal1("", 1);
+/* Reduce colors in cmap 0 so that cmap 1 is useful on a 16-color display */
+    plscmap0n(3);
+
     pladv(0);
     plvpor(0.1, 0.9, 0.1, 0.9);
     plwind(-1.0, 1.0, -1.0, 1.0);
@@ -284,6 +303,12 @@ main(int argc, const char *argv[])
 /* Plot using 2d coordinate transform and exclusion*/
 
     if(exclude) {
+/* Load colour palettes*/
+    plspal0("cmap0_black_on_white.pal");
+    plspal1("cmap1_gray.pal", 1);
+/* Reduce colors in cmap 0 so that cmap 1 is useful on a 16-color display */
+    plscmap0n(3);
+
     pladv(0);
     plvpor(0.1, 0.9, 0.1, 0.9);
     plwind(-1.0, 1.0, -1.0, 1.0);
@@ -303,10 +328,17 @@ main(int argc, const char *argv[])
     }
 /* Example with polar coordinates. */
 
+/* Load colour palettes*/
+    plspal0("cmap0_black_on_white.pal");
+    plspal1("cmap1_gray.pal", 1);
+/* Reduce colors in cmap 0 so that cmap 1 is useful on a 16-color display */
+    plscmap0n(3);
+
     pladv(0);
     plvpor( .1, .9, .1, .9 );
     plwind( -1., 1., -1., 1. );
 
+
     plpsty(0);
 
     /* Build new coordinate matrices. */
