@@ -1,4 +1,4 @@
-/* $Id: x21c.c 9278 2009-01-08 14:30:16Z andrewross $
+/* $Id: x21c.c 9586 2009-02-23 15:54:44Z andrewross $
 	Grid data demo
 
    Copyright (C) 2004  Joao Cardoso
@@ -23,15 +23,6 @@
 
 #include "plcdemos.h"
 
-#if !defined(HAVE_ISNAN)
-#  define isnan(x) ((x) != (x))
-#endif
-
-#if defined(WIN32) && (defined(_MSC_VER) || defined(__BORLANDC__))
-#undef isnan
-#define isnan _isnan
-#endif
-
 /* Options data structure definition. */
 
 static PLINT pts = 500;
