@@ -1,4 +1,4 @@
-/* $Id: x29c.c 9129 2008-12-16 12:21:51Z andrewross $
+/* $Id: x29c.c 10261 2009-08-15 13:03:11Z andrewross $
 
        Sample plots using date / time formatting for axes
 
@@ -24,8 +24,6 @@
 
 #include "plcdemos.h"
 
-#include <time.h>
-
 static PLFLT x[365], y[365];
 static PLFLT xerr1[365], xerr2[365], yerr1[365], yerr2[365];
 
@@ -34,19 +32,25 @@ static PLFLT xerr1[365], xerr2[365], yerr1[365], yerr2[365];
 void plot1();
 void plot2();
 void plot3();
+void plot4();
 
 /*--------------------------------------------------------------------------*\
  * main
  * 
  * Draws several plots which demonstrate the use of date / time formats for
  * the axis labels.
- * Time formatting is done using the system strftime routine. See the 
- * documentation of this for full details of the available formats.
+ * Time formatting is done using the strfqsas routine from the qsastime
+ * library.  This is similar to strftime, but works for a broad
+ * date range even on 32-bit systems.  See the 
+ * documentation of strfqsas for full details of the available formats.
  *
  * 1) Plotting temperature over a day (using hours / minutes)
  * 2) Plotting 
  *
- * Note: Times are stored as seconds since the epoch (usually 1st Jan 1970). 
+ * Note: We currently use the default call for plconfigtime (done in
+ * plinit) which means continuous times are interpreted as seconds since
+ * 1970-01-01, but that may change in future, more extended versions of 
+ * this example.
  * 
 \*--------------------------------------------------------------------------*/
 
@@ -69,6 +73,8 @@ main(int argc, const char *argv[])
 
   plot3();
 
+  plot4();
+
   /* Don't forget to call plend() to finish off! */
   plend();
   exit(0);
@@ -186,37 +192,9 @@ plot3()
   int i, npts;
   PLFLT xmin, xmax, ymin, ymax;
   PLFLT tstart;
-  char *tz;
 
-  struct tm tm;
-
-  /* Calculate seconds since the Unix epoch for 2005-12-01 UTC. */
-#if defined(WIN32)
-  /* Adopt the known result for POSIX-compliant systems. */
-  tstart = (PLFLT) 1133395200;
-#else
-  tm.tm_year = 105; /* Years since 1900 = 2005 */
-  tm.tm_mon = 11;   /* 0 == January, 11 = December */
-  tm.tm_mday = 1;   /* 1 = 1st of month */
-  tm.tm_hour = 0;
-  tm.tm_min = 0;
-  tm.tm_sec = 0;
-
-  /* Use POSIX-compliant equivalent of timegm GNU extension. */
-  tz = getenv("TZ");
-  setenv("TZ", "", 1);
-  tzset();
-  /* tstart is a time_t value (cast to PLFLT) which represents the number
-   * of seconds elapsed since 00:00:00 on January 1, 1970, Coordinated 
-   * Universal Time (UTC) on  2005-12-01 (UTC). */
-  tstart = (PLFLT) mktime(&tm);
-  if (tz)
-    setenv("TZ", tz, 1);
-  else
-    unsetenv("TZ");
-  tzset();
-#endif
-   
+  /* Calculate continuous time corresponding to 2005-12-01 UTC. */
+  plctime(2005, 11, 01, 0, 0, 0., &tstart);
   npts = 62;
 
   xmin = tstart;
@@ -235,9 +213,8 @@ plot3()
   plwind(xmin, xmax, ymin, ymax);
 
   plcol0(1);
-  /* Set time format to be ISO 8601 standard YYYY-MM-DD. Note that this is
-   * equivalent to %f for C99 compliant implementations of strftime. */
-  pltimefmt("%Y-%m-%d");
+  /* Set time format to be ISO 8601 standard YYYY-MM-DD. */
+  pltimefmt("%F");
   /* Draw a box with ticks spaced every 14 days in X and 1 hour in Y. */
   plbox("bcnstd", 14*24.0*60.0*60.0,14, "bcnstv", 1, 4);
 
@@ -252,3 +229,135 @@ plot3()
   plline(npts, x, y);
  
 }
+
+void
+plot4() 
+{
+  /* TAI-UTC (seconds) as a function of time.
+     Use Besselian epochs as the continuous time interval just to prove
+     this does not introduce any issues. */
+  
+  PLFLT scale, offset1, offset2;  
+  PLFLT xmin, xmax, ymin, ymax, xlabel_step;
+  int kind, npts, if_TAI_time_format, i;
+  char time_format[10];
+  char title_suffix[100];
+  char xtitle[100];
+  char title[100];
+  PLFLT x[1001], y[1001];
+  PLINT tai_year, tai_month, tai_day, tai_hour, tai_min;
+  PLFLT tai_sec, tai;
+  PLINT utc_year, utc_month, utc_day, utc_hour, utc_min;
+  PLFLT utc_sec, utc;
+
+  /* Use the definition given in http://en.wikipedia.org/wiki/Besselian_epoch
+   * B = 1900. + (JD -2415020.31352)/365.242198781 
+   * ==> (as calculated with aid of "bc -l" command)
+   * B = (MJD + 678940.364163900)/365.242198781
+   * ==>
+   * MJD = B*365.24219878 - 678940.364163900 */
+  scale = 365.242198781;
+  offset1 = -678940.;
+  offset2 = -0.3641639;
+  plconfigtime(scale, offset1, offset2, 0x0, 0, 0, 0, 0, 0, 0, 0.);
+
+  for (kind=0;kind<7;kind++) {
+    if (kind == 0) {
+      plctime(1950,0,2,0,0,0.,&xmin);
+      plctime(2020,0,2,0,0,0.,&xmax);
+      npts = 70*12 + 1;
+      ymin = 0.0;
+      ymax = 36.0;
+      strncpy(time_format,"%Y%",10);
+      if_TAI_time_format = 1;
+      strncpy(title_suffix,"from 1950 to 2020",100);
+      strncpy(xtitle,  "Year", 100);
+      xlabel_step = 10.;
+    }
+    else if (kind == 1 || kind ==2) {
+      plctime(1961,7,1,0,0,1.64757-.20, &xmin);
+      plctime(1961,7,1,0,0,1.64757+.20, &xmax);
+      npts = 1001;
+      ymin = 1.625;
+      ymax = 1.725;
+      strncpy(time_format, "%S%2%", 10);
+      strncpy(title_suffix, "near 1961-08-01 (TAI)", 100);
+      xlabel_step = 0.05/(scale*86400.);
+      if (kind == 1) {
+        if_TAI_time_format = 1;
+        strncpy(xtitle, "Seconds (TAI)", 100);
+      }
+      else {
+        if_TAI_time_format = 0;
+        strncpy(xtitle, "Seconds (TAI) labelled with corresponding UTC", 100);
+      }
+    }
+    else if (kind == 3 || kind ==4) {
+      plctime(1963,10,1,0,0,2.6972788-.20, &xmin);
+      plctime(1963,10,1,0,0,2.6972788+.20, &xmax);
+      npts = 1001;
+      ymin = 2.55;
+      ymax = 2.75;
+      strncpy(time_format, "%S%2%", 10);
+      strncpy(title_suffix, "near 1963-11-01 (TAI)", 100);
+      xlabel_step = 0.05/(scale*86400.);
+      if (kind == 3) {
+	if_TAI_time_format = 1;
+	strncpy(xtitle, "Seconds (TAI)",100);
+      }
+      else {
+	if_TAI_time_format = 0;
+	strncpy(xtitle, "Seconds (TAI) labelled with corresponding UTC", 100);
+      }
+    }
+    else if (kind == 5 || kind == 6) {
+      plctime(2009,0,1,0,0,34.-5.,&xmin);
+      plctime(2009,0,1,0,0,34.+5.,&xmax);
+      npts = 1001;
+      ymin = 32.5;
+      ymax = 34.5;
+      strncpy(time_format, "%S%2%", 10);
+      strncpy(title_suffix, "near 2009-01-01 (TAI)",100);
+      xlabel_step = 1./(scale*86400.);
+      if (kind == 5) {
+        if_TAI_time_format = 1;
+        strncpy(xtitle, "Seconds (TAI)", 100);
+      }
+      else {
+        if_TAI_time_format = 0;
+        strncpy(xtitle, "Seconds (TAI) labelled with corresponding UTC", 100);
+      }
+    }
+
+    for (i=0;i<npts;i++) {
+      x[i] = xmin + i*(xmax-xmin)/((double)(npts-1));
+      plconfigtime(scale, offset1, offset2, 0x0, 0, 0, 0, 0, 0, 0, 0.);
+      tai = x[i];
+      plbtime(&tai_year, &tai_month, &tai_day, &tai_hour, &tai_min, &tai_sec, tai);
+      plconfigtime(scale, offset1, offset2, 0x2, 0, 0, 0, 0, 0, 0, 0.);
+      plbtime(&utc_year, &utc_month, &utc_day, &utc_hour, &utc_min, &utc_sec, tai);
+      plconfigtime(scale, offset1, offset2, 0x0, 0, 0, 0, 0, 0, 0, 0.);
+      plctime(utc_year, utc_month, utc_day, utc_hour, utc_min, utc_sec, &utc);
+      y[i]=(tai-utc)*scale*86400.;
+    }
+
+    pladv(0);
+    plvsta();
+    plwind(xmin, xmax, ymin, ymax);
+    plcol0(1);
+    if (if_TAI_time_format) 
+      plconfigtime(scale, offset1, offset2, 0x0, 0, 0, 0, 0, 0, 0, 0.);
+    else
+      plconfigtime(scale, offset1, offset2, 0x2, 0, 0, 0, 0, 0, 0, 0.);
+    pltimefmt(time_format);
+    plbox("bcnstd", xlabel_step, 0, "bcnstv", 0., 0);
+    plcol0(3);
+    strncpy(title,"@frPLplot Example 29 - TAI-UTC ", 100);
+    strncat(title,title_suffix,100);
+    pllab(xtitle, "TAI-UTC (sec)", title);
+    
+    plcol0(4);
+    
+    plline(npts, x, y);
+  }
+}
