@@ -1,4 +1,4 @@
-!   $Id: x01f.f90 7850 2007-09-09 19:08:12Z airwin $
+!   $Id: x01f.f90 9134 2008-12-16 14:13:49Z andrewross $
 !   Simple line plot and multiple windows demo.
 !
 !   Copyright (C) 2004  Alan W. Irwin
@@ -31,15 +31,13 @@
 !  Process command-line arguments
    call plparseopts(PL_PARSE_FULL)
 
-!  Divide page into 2x2 plots
-   call plssub(2, 2)
-
 !  Print plplot version
    call plgver(version)
    write (*,'(a,a)') 'PLplot library version: ', trim(version)
 
 !  Initialize plplot
-   call plinit()
+!  Divide page into 2x2 plots
+   call plstar(2,2)
 
 !  Set up the data
 !  Original case
