@@ -1,4 +1,4 @@
-!      $Id: x02f.f90 6883 2006-07-26 14:06:57Z andrewross $
+!      $Id: x02f.f90 8613 2008-08-07 22:04:18Z airwin $
 !      Demonstrates multiple windows and color map 0 
 !
 !      Copyright (C) 2004  Alan W. Irwin
@@ -96,9 +96,9 @@
 
          call plhlsrgb(h, l, s, r1, g1, b1)
          
-         r(i+17) = r1*255
-         g(i+17) = g1*255
-         b(i+17) = b1*255
+         r(i+17) = r1*255.001
+         g(i+17) = g1*255.001
+         b(i+17) = b1*255.001
       enddo
 
       do i=1,16
