@@ -1,4 +1,4 @@
-!      $Id: x07f.f90 6572 2006-05-16 20:24:14Z airwin $
+!      $Id: x07f.f90 8605 2008-08-02 08:50:07Z andrewross $
 !      Displays the plotter symbols for PLSYM
 !
 !      Copyright (C) 2004  Alan W. Irwin
@@ -62,8 +62,18 @@
         do i=0,9
 
 !          Write the digits to the left of the frame
+!          N.B. The chain of if statements is just to ensure no leading
+!          blanks, consistent with the C version of the example.
 
-          write (text,'(i4)') base(l)+10*i
+          if(base(l)+10*i.eq.0) then
+            write (text,'(i1)') base(l)+10*i
+          elseif(base(l)+10*i.lt.100) then
+            write (text,'(i2)') base(l)+10*i
+          elseif(base(l)+10*i.lt.1000) then
+            write (text,'(i3)') base(l)+10*i
+          else
+            write (text,'(i4)') base(l)+10*i
+          endif
           call plmtex('lv', 1.0_plflt, (0.95_plflt-0.1_plflt*i), &
             1.0_plflt, text)
           do j=0,9
