@@ -1,4 +1,4 @@
-!      $Id: x13f.f90 6572 2006-05-16 20:24:14Z airwin $
+!      $Id: x13f.f90 9134 2008-12-16 14:13:49Z andrewross $
 !      Pie chart demo.
 !
 !      Copyright (C) 2004  Alan W. Irwin
@@ -39,7 +39,12 @@
 
       call plinit()
 
-      call plenv( 0._plflt, 10._plflt, 0._plflt, 10._plflt, 1, -2 )
+      call pladv(0)
+!     Ensure window has aspect ratio of one so circle is
+!     plotted as a circle.
+      call plvasp(1.0_plflt)
+      call plwind(0._plflt, 10._plflt, 0._plflt, 10._plflt)      
+!      call plenv( 0._plflt, 10._plflt, 0._plflt, 10._plflt, 1, -2 )
       call plcol0(2)
 
 !      n.b. all theta quantities scaled by 2*pi/500 to be integers to avoid
