@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x05.java,v 1.15 2005/12/19 21:56:37 airwin Exp $
+// $Id: x05.java 6815 2006-07-19 07:13:56Z andrewross $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -39,7 +39,7 @@ class x05 {
 
     public static void main( String[] args ) 
     {
-        x05 x = new x05( args );
+        new x05( args );
     }
 
     public x05( String[] args )
