@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x07.java,v 1.16 2005/12/10 20:14:45 airwin Exp $
+// $Id: x07.java 6815 2006-07-19 07:13:56Z andrewross $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -31,7 +31,6 @@ package plplot.examples;
 
 import plplot.core.*;
 
-import java.lang.Math;
 import java.text.*;
 
 class x07 {
@@ -43,7 +42,7 @@ class x07 {
 
     public static void main( String[] args ) 
     {
-        x07 x = new x07( args );
+        new x07( args );
     }
 
     public x07( String[] args )
