@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x10.java,v 1.13 2005/07/03 12:43:39 andrewross Exp $
+// $Id: x10.java 6815 2006-07-19 07:13:56Z andrewross $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -31,13 +31,12 @@ package plplot.examples;
 
 import plplot.core.*;
 
-import java.lang.Math;
 
 class x10 {
 
     public static void main( String[] args ) 
     {
-        x10 x = new x10( args );
+        new x10( args );
     }
 
     public x10( String[] args )
