@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x16.java 6815 2006-07-19 07:13:56Z andrewross $
+// $Id: x16.java 10304 2009-08-20 09:05:43Z andrewross $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -92,6 +92,9 @@ class x16 {
 	// Parse and process command line arguments.
 	pls.parseopts( args, PLStream.PL_PARSE_FULL | PLStream.PL_PARSE_NOPROGRAM );
 
+	// Load colour palettes
+	pls.spal0("cmap0_black_on_white.pal");
+	pls.spal1("cmap1_gray.pal", true);
 	// Reduce colors in cmap 0 so that cmap 1 is useful on a 
 	//16-color display
 	pls.scmap0n(3);
@@ -166,6 +169,13 @@ class x16 {
 
 	// Plot using 1d coordinate transform
     
+	// Load colour palettes
+	pls.spal0("cmap0_black_on_white.pal");
+	pls.spal1("cmap1_blue_yellow.pal",true);
+	// Reduce colors in cmap 0 so that cmap 1 is useful on a 
+	//16-color display
+	pls.scmap0n(3);
+
 	pls.adv(0);
 	pls.vpor(0.1, 0.9, 0.1, 0.9);
 	pls.wind(-1.0, 1.0, -1.0, 1.0);
@@ -185,6 +195,13 @@ class x16 {
 
 	// Plot using 2d coordinate transform
 
+	// Load colour palettes
+	pls.spal0("cmap0_black_on_white.pal");
+	pls.spal1("cmap1_blue_red.pal",true);
+	// Reduce colors in cmap 0 so that cmap 1 is useful on a 
+	//16-color display
+	pls.scmap0n(3);
+
 	pls.adv(0);
 	pls.vpor(0.1, 0.9, 0.1, 0.9);
 	pls.wind(-1.0, 1.0, -1.0, 1.0);
@@ -205,6 +222,13 @@ class x16 {
 
 	// Plot using 2d coordinate transform
 
+	// Load colour palettes
+	pls.spal0("");
+	pls.spal1("",true);
+	// Reduce colors in cmap 0 so that cmap 1 is useful on a 
+	//16-color display
+	pls.scmap0n(3);
+
 	pls.adv(0);
 	pls.vpor(0.1, 0.9, 0.1, 0.9);
 	pls.wind(-1.0, 1.0, -1.0, 1.0);
@@ -228,6 +252,13 @@ class x16 {
 
 	//Example with polar coordinates.
 
+	// Load colour palettes
+	pls.spal0("cmap0_black_on_white.pal");
+	pls.spal1("cmap1_gray.pal",true);
+	// Reduce colors in cmap 0 so that cmap 1 is useful on a 
+	//16-color display
+	pls.scmap0n(3);
+
 	pls.adv(0);
 	pls.vpor( .1, .9, .1, .9 );
 	pls.wind( -1., 1., -1., 1. );
