@@ -1,5 +1,5 @@
 //---------------------------------------------------------------------------//
-// $Id: x18.java,v 1.15 2006/05/13 05:22:43 airwin Exp $
+// $Id: x18.java 6815 2006-07-19 07:13:56Z andrewross $
 //---------------------------------------------------------------------------//
 
 //---------------------------------------------------------------------------//
@@ -113,14 +113,14 @@ class x18 {
    // viewing options in each plot.
    public static void main( String[] args ) 
      {
-	x18 x = new x18( args );
+	new x18( args );
      }
    
    public x18( String[] args )
      {
 	NumberFormat nf = NumberFormat.getNumberInstance();
 	
-	int i, j, k;
+	int i, k;
 	double r;
 
         // Parse and process command line arguments.
