@@ -52,7 +52,12 @@ plParseOpts (\@ARGV, PL_PARSE_SKIP | PL_PARSE_NOPROGRAM);
 
 plinit ();
 
-plenv (0, 10, 0, 10, 1, -2);
+pladv(0);
+# Ensure window has aspect ratio of one so circle is
+# plotted as a circle. 
+plvasp(1.0);
+plwind(0., 10., 0., 10.);
+#plenv (0, 10, 0, 10, 1, -2);
 plcol0 (2);
 # n.b. all theta quantities scaled by 2*pi/500 to be integers to avoid
 # floating point logic problems.
