@@ -1,6 +1,28 @@
 #!/usr/bin/env python
 
-# Run 14th python plplot example
+# $Id: xw14.py 9273 2009-01-07 16:10:59Z andrewross $
+
+#  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Alan W. Irwin
+
+#  Demo of multiple stream/window capability.
+#
+#  This file is part of PLplot.
+#
+#  PLplot is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Library Public License as published
+#  by the Free Software Foundation; either version 2 of the License, or
+#  (at your option) any later version.
+#
+#  PLplot is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU Library General Public License for more details.
+#
+#  You should have received a copy of the GNU Library General Public License
+#  along with PLplot; if not, write to the Free Software
+#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+#
+
 
 # Append to effective python path so that can find plplot modules.
 from plplot_python_start import *
@@ -20,6 +42,8 @@ def main():
     geometry_master = "500x410+100+200"
     geometry_slave  = "500x410+650+200"
     driver = plgdev()
+    (fam, num, bmax) = plgfam()
+    
     print "Demo of multiple output streams via the %s driver." % driver
     print "Running with the second stream as slave to the first."
     print ""
@@ -38,6 +62,8 @@ def main():
     plsetopt("geometry", geometry_slave)
     plspause(0)
     plsdev(driver)
+    plsfam(fam, num, bmax)
+    plsetopt("fflen","2")
     plinit()
 		    
     # Set up the data & plot
