@@ -1,8 +1,8 @@
 #----------------------------------------------------------------------------
-# $Id: tcldemos.tcl 5628 2004-06-14 12:33:11Z andrewross $
+# $Id: tcldemos.tcl 9294 2009-01-11 12:06:27Z andrewross $
 #
 # PLplot TCL demos
-# 
+#
 # Maurice LeBrun
 # IFS, University of Texas at Austin
 # 23-Jun-1994
@@ -20,12 +20,10 @@
 # Tcl scripts compatible.
 #----------------------------------------------------------------------------
 
-for {set i 1} {$i <= 19} {incr i} {
+for {set i 1} {$i <= 31} {incr i} {
     set demo x[format "%02d" $i]
     source $demo.tcl
+    # restore defaults
+    plcol0 1
     proc $i {} "$demo"
 }
-set i 22
-set demo x[format "%02d" $i]
-source $demo.tcl
-proc $i {} "$demo"
