@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------------
-# $Id: x06.tcl 5922 2005-01-20 23:38:55Z airwin $
+# $Id: x06.tcl 8674 2008-08-19 10:54:16Z andrewross $
 #----------------------------------------------------------------------------
 
 proc x06 {{w loopback}} {
@@ -49,5 +49,5 @@ proc x06 {{w loopback}} {
     $w cmd plmtex "t" 1.5 0.5 0.5 "PLplot Example 6 - plpoin symbols"
 
     # Restore defaults
-    $w cmd plcol0 1
+    # $w cmd plcol0 1
 }
