@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------------
-# $Id: x07.tcl 5922 2005-01-20 23:38:55Z airwin $
+# $Id: x07.tcl 8674 2008-08-19 10:54:16Z andrewross $
 #----------------------------------------------------------------------------
 
 proc x07 {{w loopback}} {
@@ -53,5 +53,5 @@ proc x07 {{w loopback}} {
 	$w cmd plmtex "t" 1.5 0.5 0.5 "PLplot Example 7 - PLSYM symbols"
     }
 # Restore defaults
-    $w cmd plcol0 1
+    # $w cmd plcol0 1
 }
