@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------------
-# $Id: x16.tcl 9249 2009-01-03 11:05:01Z arjenmarkus $
+# $Id: x16.tcl 10304 2009-08-20 09:05:43Z andrewross $
 #----------------------------------------------------------------------------
 
 # plshades demo, using color fill.
@@ -22,6 +22,9 @@ proc x16 {{w loopback}} {
     matrix zz f $nx $ny
     matrix ww f $nx $ny
 
+    $w cmd plspal0 "cmap0_black_on_white.pal"
+    $w cmd plspal1 "cmap1_gray.pal" 1
+
 # Set up data array
 
     for {set i 0} {$i < $nx} {incr i} {
@@ -102,6 +105,9 @@ proc x16 {{w loopback}} {
 
 # Plot using 1d coordinate transform
 
+    $w cmd plspal0 "cmap0_black_on_white.pal"
+    $w cmd plspal1 "cmap1_blue_yellow.pal" 1
+
     $w cmd pladv 0
     $w cmd plvpor 0.1 0.9 0.1 0.9
     $w cmd plwind -1.0 1.0 -1.0 1.0
@@ -122,6 +128,9 @@ proc x16 {{w loopback}} {
 
 # Plot using 2d coordinate transform
 
+    $w cmd plspal0 "cmap0_black_on_white.pal"
+    $w cmd plspal1 "cmap1_blue_red.pal" 1
+
     $w cmd pladv 0
     $w cmd plvpor 0.1 0.9 0.1 0.9
     $w cmd plwind -1.0 1.0 -1.0 1.0
@@ -141,6 +150,9 @@ proc x16 {{w loopback}} {
 
 # Plot using 2d coordinate transform with both shades and contours.
 
+    $w cmd plspal0 ""
+    $w cmd plspal1 "" 1
+
     $w cmd pladv 0
     $w cmd plvpor 0.1 0.9 0.1 0.9
     $w cmd plwind -1.0 1.0 -1.0 1.0
@@ -159,6 +171,9 @@ proc x16 {{w loopback}} {
 
 # Polar plot example demonstrating wrapping support.
 
+    $w cmd plspal0 "cmap0_black_on_white.pal"
+    $w cmd plspal1 "cmap1_gray.pal" 1
+
 # Build the new coordinate matrices.
 
     set nylim [expr $ny - 1]; set wrap 2;
