@@ -1,5 +1,5 @@
 #----------------------------------------------------------------------------
-# $Id: tkdemos.tcl 9294 2009-01-11 12:06:27Z andrewross $
+# $Id: tkdemos.tcl 10226 2009-08-09 19:39:14Z airwin $
 #
 # PLplot TK demos
 # 
@@ -21,8 +21,10 @@ plstdwin .
 plxframe .plw
 pack append . .plw {left expand fill}
 
-for {set i 1} {$i <= 31} {incr i} {
+# Exclude 31 because it does not work well in this context and because
+# the required x31.tcl is normally not copied to the tk directory in any case.
+for {set i 1} {$i <= 30} {incr i} {
     set demo x[format "%02d" $i]
     source $demo.tcl
-    proc $i {} "$demo .plw.plwin"
+    proc $i {} "$demo .plw.plwin; .plw.plwin cmd plspal0 cmap0_default.pal; .plw.plwin cmd plspal1 cmap1_default.pal"
 }
