@@ -1,4 +1,4 @@
-/* $Id: xtndfont.c 2289 2000-12-18 21:01:50Z airwin $
+/* $Id: xtndfont.c 9367 2009-01-22 19:03:59Z airwin $
  * $Log$
  * Revision 1.10  2000/12/18 21:01:49  airwin
  * Change to new style plplot/*.h header file locations.
@@ -15,7 +15,7 @@
 	Utility to generate extended font set.
 */
 
-#include "plplot/plplotP.h"
+#include "plplotP.h"
 
 extern short int *hersh[];
 extern short int *findex[];
