@@ -1,4 +1,4 @@
-/* $Id: drivers.h 9184 2008-12-18 08:41:56Z smekal $
+/* $Id: drivers.h 9802 2009-04-15 20:29:27Z airwin $
 
 	Contains all prototypes for driver functions.
 
@@ -97,6 +97,16 @@ PLDLLIMPEXP_DRIVER void plD_dispatch_init_svgcairo  ( PLDispatchTable *pdt );
 PLDLLIMPEXP_DRIVER void plD_dispatch_init_pngcairo  ( PLDispatchTable *pdt );
 PLDLLIMPEXP_DRIVER void plD_dispatch_init_memcairo  ( PLDispatchTable *pdt );
 PLDLLIMPEXP_DRIVER void plD_dispatch_init_extcairo  ( PLDispatchTable *pdt );
+PLDLLIMPEXP_DRIVER void plD_dispatch_init_bmpqt  ( PLDispatchTable *pdt );
+PLDLLIMPEXP_DRIVER void plD_dispatch_init_jpgqt  ( PLDispatchTable *pdt );
+PLDLLIMPEXP_DRIVER void plD_dispatch_init_pngqt  ( PLDispatchTable *pdt );
+PLDLLIMPEXP_DRIVER void plD_dispatch_init_ppmqt  ( PLDispatchTable *pdt );
+PLDLLIMPEXP_DRIVER void plD_dispatch_init_tiffqt  ( PLDispatchTable *pdt );
+PLDLLIMPEXP_DRIVER void plD_dispatch_init_svgqt  ( PLDispatchTable *pdt );
+PLDLLIMPEXP_DRIVER void plD_dispatch_init_epsqt  ( PLDispatchTable *pdt );
+PLDLLIMPEXP_DRIVER void plD_dispatch_init_pdfqt  ( PLDispatchTable *pdt );
+PLDLLIMPEXP_DRIVER void plD_dispatch_init_qtwidget  ( PLDispatchTable *pdt );
+PLDLLIMPEXP_DRIVER void plD_dispatch_init_extqt  ( PLDispatchTable *pdt );
 
 /* Prototypes for plot buffer calls. */
 
