@@ -1,4 +1,4 @@
-/* $Id: pdf.h 8759 2008-09-09 09:55:50Z andrewross $
+/* $Id: pdf.h 9882 2009-05-02 20:57:59Z airwin $
 
     Copyright (C) 1992 by Maurice J. LeBrun
 
@@ -83,7 +83,7 @@ typedef struct {
 /* Use a wrapper for the prototypes for use from K&R C */
 
 void pdf_set		PLARGS((char *option, int value));
-PDFstrm *pdf_fopen	PLARGS((const char *fileName, const char *mode));
+PLDLLIMPEXP PDFstrm *pdf_fopen	PLARGS((const char *fileName, const char *mode));
 PLDLLIMPEXP PDFstrm *pdf_bopen	PLARGS((U_CHAR *buffer, long bufmax));
 PLDLLIMPEXP PDFstrm *pdf_finit	PLARGS((FILE *file));
 PDFstrm *plLibOpenPdfstrm PLARGS((const char *fn));
@@ -95,18 +95,18 @@ PLDLLIMPEXP int  pdf_ungetc		PLARGS((int c, PDFstrm *pdfs));
 int  pdf_rdx	        PLARGS((U_CHAR *x, long nitems, PDFstrm *pdfs));
 
 PLDLLIMPEXP int  pdf_rd_header	PLARGS((PDFstrm *pdfs, char *header));
-int  pdf_wr_header	PLARGS((PDFstrm *pdfs, char *header));
+PLDLLIMPEXP int  pdf_wr_header	PLARGS((PDFstrm *pdfs, char *header));
 int  pdf_wr_string	PLARGS((PDFstrm *pdfs, const char *string));
 int  pdf_rd_string	PLARGS((PDFstrm *pdfs, char *string, int nmax));
-int  pdf_wr_1byte	PLARGS((PDFstrm *pdfs, U_CHAR s));
+PLDLLIMPEXP int  pdf_wr_1byte	PLARGS((PDFstrm *pdfs, U_CHAR s));
 PLDLLIMPEXP int  pdf_rd_1byte	PLARGS((PDFstrm *pdfs, U_CHAR *ps));
-int  pdf_wr_2bytes	PLARGS((PDFstrm *pdfs, U_SHORT s));
+PLDLLIMPEXP int  pdf_wr_2bytes	PLARGS((PDFstrm *pdfs, U_SHORT s));
 PLDLLIMPEXP int  pdf_rd_2bytes 	PLARGS((PDFstrm *pdfs, U_SHORT *ps));
-int  pdf_wr_2nbytes	PLARGS((PDFstrm *pdfs, U_SHORT *s, PLINT n));
+PLDLLIMPEXP int  pdf_wr_2nbytes	PLARGS((PDFstrm *pdfs, U_SHORT *s, PLINT n));
 PLDLLIMPEXP int  pdf_rd_2nbytes 	PLARGS((PDFstrm *pdfs, U_SHORT *s, PLINT n));
-int  pdf_wr_4bytes	PLARGS((PDFstrm *pdfs, U_LONG s));
+PLDLLIMPEXP int  pdf_wr_4bytes	PLARGS((PDFstrm *pdfs, U_LONG s));
 PLDLLIMPEXP int  pdf_rd_4bytes 	PLARGS((PDFstrm *pdfs, U_LONG *ps));
-int  pdf_wr_ieeef	PLARGS((PDFstrm *pdfs, float f));
+PLDLLIMPEXP int  pdf_wr_ieeef	PLARGS((PDFstrm *pdfs, float f));
 PLDLLIMPEXP int  pdf_rd_ieeef	PLARGS((PDFstrm *pdfs, float *pf));
 
 #endif	/* __PDF_H__ */
