@@ -1,4 +1,4 @@
-/* $Id: plcore.h 9184 2008-12-18 08:41:56Z smekal $
+/* $Id: plcore.h 9802 2009-04-15 20:29:27Z airwin $
 
 	Contains declarations for core plplot data structures.  This file
 	should be included only by plcore.c.
@@ -296,7 +296,36 @@ static PLDispatchInit static_device_initializers[] = {
 #if defined(PLD_extcairo) && !defined(ENABLE_DYNDRIVERS)
     plD_dispatch_init_extcairo,
 #endif
-
+#if defined(PLD_bmpqt) && !defined(ENABLE_DYNDRIVERS)
+    plD_dispatch_init_bmpqt,
+#endif
+#if defined(PLD_jpgqt) && !defined(ENABLE_DYNDRIVERS)
+    plD_dispatch_init_jpgqt,
+#endif
+#if defined(PLD_pngqt) && !defined(ENABLE_DYNDRIVERS)
+    plD_dispatch_init_pngqt,
+#endif
+#if defined(PLD_ppmqt) && !defined(ENABLE_DYNDRIVERS)
+    plD_dispatch_init_ppmqt,
+#endif
+#if defined(PLD_tiffqt) && !defined(ENABLE_DYNDRIVERS)
+    plD_dispatch_init_tiffqt,
+#endif
+#if defined(PLD_svgqt) && !defined(ENABLE_DYNDRIVERS)
+    plD_dispatch_init_svgqt,
+#endif
+#if defined(PLD_epsqt) && !defined(ENABLE_DYNDRIVERS)
+    plD_dispatch_init_epsqt,
+#endif
+#if defined(PLD_pdfqt) && !defined(ENABLE_DYNDRIVERS)
+    plD_dispatch_init_pdfqt,
+#endif
+#if defined(PLD_qtwidget) && !defined(ENABLE_DYNDRIVERS)
+    plD_dispatch_init_qtwidget,
+#endif
+#if defined(PLD_extqt) && !defined(ENABLE_DYNDRIVERS)
+    plD_dispatch_init_extqt,
+#endif
     NULL
 };
 
