@@ -1,4 +1,4 @@
-/* $Id: plplot.h 9284 2009-01-08 20:47:39Z andrewross $
+/* $Id: plplot.h 10302 2009-08-20 00:09:10Z hezekiahcarty $
 
     Macros and prototypes for the PLplot package.  This header file must
     be included by all user codes.
@@ -154,18 +154,29 @@ typedef float PLFLT;
 #define PLFLT_MIN  FLT_MIN
 #endif
 
-#if (defined(HAVE_STDINT_H) && !defined(__cplusplus)) ||\
-(defined(__cplusplus) && defined(HAVE_CXX_STDINT_H))
+#if (defined(PL_HAVE_STDINT_H) && !defined(__cplusplus)) ||\
+(defined(__cplusplus) && defined(PL_HAVE_CXX_STDINT_H))
 #include <stdint.h>
 /* This is apparently portable if stdint.h exists. */
 typedef uint32_t PLUINT;
 typedef int32_t PLINT;
 typedef int64_t PLINT64;
+#define PLINT_MIN INT32_MIN
 #else
 /* A reasonable back-up in case stdint.h does not exist on the platform. */
 typedef unsigned int PLUINT;
 typedef int PLINT;
 typedef __int64 PLINT64;
+/* for Visual C++ 2003 and later INT_MIN must be used, otherwise
+    PLINT_MIN is unsigned and 2147483648 NOT -2147483648, see 
+    http://msdn.microsoft.com/en-us/library/4kh09110(VS.71).aspx for
+    details */
+#if defined(_MSC_VER) && _MSC_VER >= 1310
+  #include <Limits.h>
+  #define PLINT_MIN INT_MIN
+#else
+  #define PLINT_MIN -2147483648
+#endif
 /*
 typedef unsigned int PLUINT;
 typedef int PLINT;
@@ -217,6 +228,19 @@ typedef void* PLPointer;
 #define PLESC_DEV2PLCOL		24	/* convert device color to PLColor */
 #define PLESC_SETBGFG		25	/* set BG, FG colors */
 #define PLESC_DEVINIT		26	/* alternate device initialization */
+#define PLESC_GETBACKEND        27	/* get used backend of (wxWidgets) driver */
+#define PLESC_BEGIN_TEXT        28      /* get ready to draw a line of text */
+#define PLESC_TEXT_CHAR         29      /* render a character of text */
+#define PLESC_CONTROL_CHAR      30      /* handle a text control character (super/subscript, etc.) */
+#define PLESC_END_TEXT          31      /* finish a drawing a line of text */
+#define PLESC_START_RASTERIZE   32      /* start rasterized rendering */
+#define PLESC_END_RASTERIZE     33      /* end rasterized rendering */
+#define PLESC_ARC               34      /* render an arc */
+
+/* Alternative unicode text handling control characters */
+#define PLTEXT_FONTCHANGE       0       /* font change in the text stream */
+#define PLTEXT_SUPERSCRIPT      1       /* superscript in the text stream */
+#define PLTEXT_SUBSCRIPT        2       /* subscript in the text stream */
 
 /* image operations */
 #define ZEROW2B   1
@@ -229,6 +253,11 @@ typedef void* PLPointer;
 #define PLSWIN_DEVICE		1	/* device coordinates */
 #define PLSWIN_WORLD		2	/* world coordinates */
 
+/* Axis label tags */
+#define PL_X_AXIS               1       /* The x-axis */
+#define PL_Y_AXIS               2       /* The y-axis */
+#define PL_Z_AXIS               3       /* The z-axis */
+
 /* PLplot Option table & support constants */
 
 /* Option-specific settings */
@@ -427,6 +456,11 @@ typedef struct {
 #define PLESC_DOUBLEBUFFERING_DISABLE    2
 #define PLESC_DOUBLEBUFFERING_QUERY      3
 
+typedef struct {
+    PLFLT exp_label_disp;
+    PLFLT exp_label_pos;
+    PLFLT exp_label_just;
+} PLLabelDefaults;
 
 /*--------------------------------------------------------------------------*\
  *		BRAINDEAD-ness
@@ -488,17 +522,21 @@ typedef struct {
 #define    pl_setcontlabelformat c_pl_setcontlabelformat
 #define    pl_setcontlabelparam c_pl_setcontlabelparam
 #define    pladv	c_pladv
+#define    plarc	c_plarc
 #define    plaxes	c_plaxes
 #define    plbin	c_plbin
 #define    plbop	c_plbop
 #define    plbox	c_plbox
 #define    plbox3	c_plbox3
+#define    plbtime	c_plbtime
 #define    plcalc_world	c_plcalc_world
 #define    plclear	c_plclear
 #define    plcol0	c_plcol0
 #define    plcol1	c_plcol1
+#define    plconfigtime	c_plconfigtime
 #define    plcont	c_plcont
 #define    plcpstrm	c_plcpstrm
+#define    plctime	c_plctime
 #define    plend	c_plend
 #define    plend1	c_plend1
 #define    plenv	c_plenv
@@ -514,8 +552,8 @@ typedef struct {
 #define    plfontld	c_plfontld
 #define    plgchr	c_plgchr
 #define    plgcol0	c_plgcol0
-#define    plgcolbg	c_plgcolbg
 #define    plgcol0a	c_plgcol0a
+#define    plgcolbg	c_plgcolbg
 #define    plgcolbga	c_plgcolbga
 #define    plgcompression	c_plgcompression
 #define    plgdev	c_plgdev
@@ -605,11 +643,14 @@ typedef struct {
 #define    plshade	c_plshade
 #define    plshade1	c_plshade1
 #define    plshades	c_plshades
+#define    plslabelfunc c_plslabelfunc
 #define    plsmaj	c_plsmaj
 #define    plsmem	c_plsmem
 #define    plsmin	c_plsmin
 #define    plsori	c_plsori
 #define    plspage	c_plspage
+#define    plspal0      c_plspal0
+#define    plspal1      c_plspal1
 #define    plspause	c_plspause
 #define    plsstrm	c_plsstrm
 #define    plssub	c_plssub
@@ -688,15 +729,11 @@ c_pl_setcontlabelparam(PLFLT offset, PLFLT size, PLFLT spacing, PLINT active);
 PLDLLIMPEXP void
 c_pladv(PLINT page);
 
-/* simple arrow plotter. */
+/* Plot an arc */
 
 PLDLLIMPEXP void
-c_plvect(PLFLT **u, PLFLT **v, PLINT nx, PLINT ny, PLFLT scale,
-	void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
-       	PLPointer pltr_data);
-
-PLDLLIMPEXP void
-c_plsvect(PLFLT *arrowx, PLFLT *arrowy, PLINT npts, PLBOOL fill);
+c_plarc(PLFLT x, PLFLT y, PLFLT a, PLFLT b, PLFLT angle1, PLFLT angle2,
+        PLBOOL fill);
 
 /* This functions similarly to plbox() except that the origin of the axes */
 /* is placed at the user-specified point (x0, y0). */
@@ -716,6 +753,10 @@ c_plaxes(PLFLT x0, PLFLT y0, const char *xopt, PLFLT xtick, PLINT nxsub,
 PLDLLIMPEXP void
 c_plbin(PLINT nbin, PLFLT *x, PLFLT *y, PLINT opt);
 
+/* Calculate broken-down time from continuous time for current stream. */
+PLDLLIMPEXP void
+c_plbtime(PLINT *year, PLINT *month, PLINT *day, PLINT *hour, PLINT *min, PLFLT *sec, PLFLT ctime);
+  
 /* Start new page.  Should only be used with pleop(). */
 
 PLDLLIMPEXP void
@@ -754,6 +795,11 @@ c_plcol0(PLINT icol0);
 PLDLLIMPEXP void
 c_plcol1(PLFLT col1);
 
+/* Configure transformation between continuous and broken-down time (and
+   vice versa) for current stream. */
+PLDLLIMPEXP void
+c_plconfigtime(PLFLT scale, PLFLT offset1, PLFLT offset2, PLINT ccontrol, PLBOOL ifbtime_offset, PLINT year, PLINT month, PLINT day, PLINT hour, PLINT min, PLFLT sec);
+  
 /* Draws a contour plot from data in f(nx,ny).  Is just a front-end to
  * plfcont, with a particular choice for f2eval and f2eval_data.
  */
@@ -782,6 +828,10 @@ plfcont(PLFLT (*f2eval) (PLINT, PLINT, PLPointer),
 PLDLLIMPEXP void
 c_plcpstrm(PLINT iplsr, PLBOOL flags);
 
+/* Calculate continuous time from broken-down time for current stream. */
+PLDLLIMPEXP void
+c_plctime(PLINT year, PLINT month, PLINT day, PLINT hour, PLINT min, PLFLT sec, PLFLT *ctime);
+  
 /* Converts input values from relative device coordinates to relative plot */
 /* coordinates. */
 
@@ -1396,6 +1446,12 @@ plfshade(PLFLT (*f2eval) (PLINT, PLINT, PLPointer),
 	 void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
 	 PLPointer pltr_data);
 
+/* Setup a user-provided custom labeling function */
+
+PLDLLIMPEXP void
+c_plslabelfunc(void (*label_func)(PLINT, PLFLT, char *, PLINT, PLPointer),
+               PLPointer label_data);
+
 /* Set up lengths of major tick marks. */
 
 PLDLLIMPEXP void
@@ -1422,6 +1478,16 @@ PLDLLIMPEXP void
 c_plspage(PLFLT xp, PLFLT yp, PLINT xleng, PLINT yleng,
 	  PLINT xoff, PLINT yoff);
 
+/* Set the colors for color table 0 from a cmap0 file */
+
+PLDLLIMPEXP void
+c_plspal0(const char *filename);
+
+/* Set the colors for color table 1 from a cmap1 file */
+
+PLDLLIMPEXP void
+c_plspal1(const char *filename, PLBOOL interpolate);
+
 /* Set the pause (on end-of-page) status */
 
 PLDLLIMPEXP void
@@ -1509,6 +1575,9 @@ c_plsurf3dl(PLFLT *x, PLFLT *y, PLFLT **z, PLINT nx, PLINT ny,
 	   PLINT opt, PLFLT *clevel, PLINT nlevel,
 	   PLINT ixstart, PLINT ixn, PLINT *indexymin, PLINT*indexymax);
 
+PLDLLIMPEXP void
+c_plsvect(PLFLT *arrowx, PLFLT *arrowy, PLINT npts, PLBOOL fill);
+
 /* Sets the edges of the viewport to the specified absolute coordinates */
 
 PLDLLIMPEXP void
@@ -1544,7 +1613,7 @@ c_plszax(PLINT digmax, PLINT digits);
 PLDLLIMPEXP void
 c_pltext(void);
 
-/* Set the format for date / time labels */
+/* Set the format for date / time labels for current stream. */
 
 PLDLLIMPEXP void
 c_pltimefmt(const char *fmt);
@@ -1558,6 +1627,13 @@ c_plvasp(PLFLT aspect);
 /* Creates the largest viewport of the specified aspect ratio that fits */
 /* within the specified normalized subpage coordinates. */
 
+/* simple arrow plotter. */
+
+PLDLLIMPEXP void
+c_plvect(PLFLT **u, PLFLT **v, PLINT nx, PLINT ny, PLFLT scale,
+	void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
+       	PLPointer pltr_data);
+
 PLDLLIMPEXP void
 c_plvpas(PLFLT xmin, PLFLT xmax, PLFLT ymin, PLFLT ymax, PLFLT aspect);
 
