@@ -1,4 +1,4 @@
-/* $Id: plplotP.h 8942 2008-10-21 01:42:57Z airwin $
+/* $Id: plplotP.h 10370 2009-09-04 23:45:36Z airwin $
 
     Internal (private) macros and prototypes for the PLplot package.  This
     header file must be included before all others, including system header
@@ -112,7 +112,6 @@ typedef char * caddr_t;
 #include <string.h>
 #include <limits.h>
 #include <float.h>
-#include <time.h>
 #if defined(PLPLOT_WINTK)
 #elif defined(WIN32) &! defined (__GNUC__)
 /* Redefine tmpfile()! (AM)*/
@@ -121,39 +120,14 @@ typedef char * caddr_t;
 #include <unistd.h>
 #endif
 
+/*#include <locale.h> */
+
 /* (AM) Define M_PI if the platform does not include it
    (MSVC for instance) */
 #if !defined(M_PI)
 #define M_PI 3.14159265358979323846
 #endif
 
-#if HAVE_DIRENT_H
-/* The following conditional is a workaround for a bug in the MacOSX system.
-   When  the dirent.h file will be fixed upstream by Apple Inc, this should
-   go away. */
-# ifdef NEED_SYS_TYPE_H
-#  include <sys/types.h>
-# endif
-# include <dirent.h>
-# define NAMLEN(dirent) strlen((dirent)->d_name)
-#else
-# if defined(_MSC_VER)
-#  include "dirent_msvc.h"
-# else
-#  define dirent direct
-#  define NAMLEN(dirent) (dirent)->d_namlen
-#  if HAVE_SYS_NDIR_H
-#   include <sys/ndir.h>
-#  endif
-#  if HAVE_SYS_DIR_H
-#   include <sys/dir.h>
-#  endif
-#  if HAVE_NDIR_H
-#   include <ndir.h>
-#  endif
-# endif
-#endif
-
 /*
  * Macros for file positioning.  I tried switching to f[sg]etpos() because I
  * like the semantics better, but ran into the problem that fpos_t is not
@@ -268,6 +242,41 @@ extern PLDLLIMPEXP_DATA(PLStream *)plsc;
   #define snscanf plsnscanf
 #endif /* PL_HAVE_SNPRINTF */
 
+/*--------------------------------------------------------------------------*\
+ * Add in missing isnan / isinf functions on some platforms
+\*--------------------------------------------------------------------------*/
+
+#if defined(PL__HAVE_ISNAN)
+#  define isnan _isnan
+#  if defined(_MSC_VER)
+#    include <float.h>
+#  endif
+#endif
+#if defined(PL__HAVE_ISINF)
+#  define isinf _isinf
+#endif
+#if defined(PL__HAVE_FINITE)
+#  define finite _finite
+#endif
+
+/* Note these replacements follow the old BSD convention and not
+ * C99. In particular isinf does not distinguish +/- inf. */
+#if !defined(PL_HAVE_ISNAN)
+#  define isnan(x) ((x) != (x))
+#endif
+#if !defined(PL_HAVE_ISINF)
+#  define isinf(x) (!isnan(x) && isnan(x-x))
+#endif
+#if !defined(PL_HAVE_FINITE)
+#  define finite(x) (!isnan(x-x)) 
+#endif
+
+/* Check if C99 HUGE_VAL macro is available - if not then 
+ * define a replacement */
+#ifndef HUGE_VAL
+#define HUGE_VAL (1.0/0.0)
+#endif
+
 /*--------------------------------------------------------------------------*\
  *                       PLPLOT control macros
 \*--------------------------------------------------------------------------*/
@@ -391,6 +400,9 @@ extern PLDLLIMPEXP_DATA(PLStream *)plsc;
 #define PLPLOT_TCL_ENV          "PLPLOT_TCL"
 #define PLPLOT_HOME_ENV         "PLPLOT_HOME"
 
+/* Maximum size for path strings in the plplot code */
+#define PLPLOT_MAX_PATH 1024
+
 /*
  *   Some stuff that is included (and compiled into) plsym.h
  *   Other modules might want this, so we will "extern" it
@@ -414,6 +426,13 @@ extern Hershey_to_Unicode_table hershey_to_unicode_lookup_table[];
 /* Greek character translation array (defined in plcore.c) */
 extern const char plP_greek_mnemonic[];
 
+/* plinit calls setlocale to establish this pointer to a character string
+   that stores the LC_NUMERIC locale set by any library or application before
+   it calls plinit.  This character string is used to restore the LC_NUMERIC
+   locale to the original one after anything (such as colour palette file
+   reading) within PLplot that temporarily changes the locale. 
+   extern PLDLLIMPEXP_DATA(char *) plplot_default_lc_numeric_locale; */
+
 
 /*--------------------------------------------------------------------------*\
  *		Function Prototypes
@@ -470,7 +489,7 @@ plP_fci2hex(PLUNICODE fci, unsigned char *phexdigit, unsigned char hexpower);
 
 /* Pattern fills in software the polygon bounded by the input points. */
 
-void
+PLDLLIMPEXP void
 plfill_soft(short *x, short *y, PLINT npts);
 
 /* In case of an abort this routine is called.  It just prints out an */
@@ -543,6 +562,12 @@ PLDLLIMPEXP void
 difilt(PLINT *, PLINT *, PLINT,
        PLINT *, PLINT *, PLINT *, PLINT *);
 
+  /* Transforms the clipping region coordinates as necessary
+     based on the current plot orientation, etc. */
+
+PLDLLIMPEXP void
+difilt_clip(PLINT *, PLINT *);
+
   /* Driver draws text */
 
 void
@@ -562,6 +587,11 @@ typedef struct {
   PLINT refx; /* processed ref. point--after justification, displacement, etc, processing */
   PLINT refy;
   char font_face; /* font face OPTIONALLY used for rendering hershey codes */
+  /* The following 3 fields are used by the alternative text handling pathway.
+     See drivers/cairo.h for details about how this works. */
+  PLUNICODE n_fci; /* font storage for unicode font handling */
+  PLUNICODE n_char; /* character storage for unicode font handling */
+  PLINT n_ctrl_char; /* control character code storage for unicode font handling */
   PLUNICODE  unicode_char;   /* an int to hold either a Hershey, ASC-II, or Unicode value for plsym calls */
   PLUNICODE  *unicode_array;   /* a pointer to an array of ints holding either a Hershey, ASC-II, or Unicode value for cached plsym */
   unsigned short unicode_array_len;
@@ -752,7 +782,7 @@ plP_stindex(const char *str1, const char *str2);
 
 /* Searches string str for first occurence of character chr.  */
 
-PLINT
+PLDLLIMPEXP PLINT
 plP_strpos(const char *str, int chr);
 
 /* Searches string str for character chr (case insensitive). */
@@ -911,6 +941,17 @@ void
 plP_image(PLFLT *z, PLINT nx, PLINT ny, PLFLT xmin, PLFLT ymin, PLFLT dx, PLFLT dy,
         void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer), PLPointer pltr_data);
 
+/* Structure for holding arc data */
+typedef struct {
+    PLFLT x;
+    PLFLT y;
+    PLFLT a;
+    PLFLT b;
+    PLFLT angle1;
+    PLFLT angle2;
+    PLBOOL fill;
+} arc_struct;
+
 /* End of page */
 
 PLDLLIMPEXP void
