@@ -1,4 +1,4 @@
-/* $Id: plstrm.h 8899 2008-10-14 20:44:40Z smekal $
+/* $Id: plstrm.h 10215 2009-08-05 15:17:56Z hezekiahcarty $
  *
  *	Contains declarations for PLStream and PLDev structs.
  *	Also prototypes for stream & device utility functions.
@@ -30,6 +30,7 @@
 
 #include "disptab.h"
 #include "pldll.h"
+#include "qsastime.h"
 
 /*--------------------------------------------------------------------------*\
  * Define the PLDev data structure.
@@ -478,6 +479,15 @@ typedef struct {
  * for hexpower = 4-6 so there is room for expansion of this scheme into more
  * font attributes if required.  (hexpower = 7 is reserved for the 0x8 marker
  * of the FCI.)
+ *
+ ****************************************************************************
+ *
+ * Time related variable
+ *
+ * qsasconfig is a pointer to a struct that keeps track of the details
+ * of the transformation between broken-down and continuous time used
+ * in the qsastime library.
+ *
 \*--------------------------------------------------------------------------*/
 
 #define PL_MAX_CMAP1CP 256
@@ -521,7 +531,7 @@ typedef struct {
     PLINT color, colorset;
     PLINT family, member, finc, fflen, bytemax, famadv;
     PLINT dev_fill0, dev_fill1, dev_dash, dev_di, dev_flush, dev_swin;
-    PLINT dev_text, dev_xor, dev_clear, dev_fastimg;
+    PLINT dev_text, dev_xor, dev_clear, dev_fastimg, dev_arc;
 
     char DevName[80];
     FILE *OutFile;
@@ -646,6 +656,8 @@ typedef struct {
     PLINT xdigmax, ydigmax, zdigmax;
     PLINT xdigits, ydigits, zdigits;
     char *timefmt;
+    void (*label_func)(PLINT, PLFLT, char *, PLINT, PLPointer);
+    PLPointer label_data;
 
 /* Variables governing physical coordinate system */
 
@@ -696,6 +708,8 @@ typedef struct {
 
   PLINT dev_unicode;
 
+  PLINT alt_unicode; /* The alternative interface for unicode text rendering. */
+
   PLUNICODE fci;
 
   PLINT dev_hrshsym;
@@ -711,6 +725,11 @@ typedef struct {
    */
   void *psdoc;
 
+  /* pointer to a struct that keeps track of the details of the
+     transformation between broken-down and continuous time used in
+     the qsastime library. */
+
+     QSASConfig *qsasconfig;
 
 } PLStream;
 
