@@ -1,4 +1,4 @@
-/* $Id: plargs.c 8487 2008-06-25 08:36:42Z smekal $
+/* $Id: plargs.c 10352 2009-08-27 16:38:57Z airwin $
 
     Copyright 1993, 1994, 1995
     Maurice LeBrun			mjl@dino.ph.utexas.edu
@@ -150,6 +150,8 @@ static int opt_server_name	(const char *, const char *, void *);
 static int opt_tk_file          (const char *, const char *, void *);
 static int opt_dpi		(const char *, const char *, void *);
 static int opt_dev_compression	(const char *, const char *, void *);
+static int opt_cmap0	        (const char *, const char *, void *);
+static int opt_cmap1	        (const char *, const char *, void *);
 
 /* Global variables */
 
@@ -404,7 +406,7 @@ static PLOptionTable ploption_table[] = {
     NULL,
     PL_OPT_FUNC | PL_OPT_ARG,
     "-bg color",
-    "Background color (000000=black, FFFFFF=white)" },
+    "Background color (FF0000=opaque red, 0000FF_0.1=blue with alpha of 0.1)" },
 {
     "ncol0",			/* Allocated colors in cmap 0 */
     opt_ncol0,
@@ -557,6 +559,22 @@ static PLOptionTable ploption_table[] = {
     PL_OPT_FUNC | PL_OPT_ARG,
     "-compression num",
     "Sets compression level in supporting devices" },
+{
+    "cmap0",
+    opt_cmap0,
+    NULL,
+    NULL,
+    PL_OPT_ARG | PL_OPT_FUNC,
+    "-cmap0 file name",
+    "Initializes color table 0 from a cmap0.pal format file in one of standard PLplot paths."},
+{
+    "cmap1",
+    opt_cmap1,
+    NULL,
+    NULL,
+    PL_OPT_ARG | PL_OPT_FUNC,
+    "-cmap1 file name",
+    "Initializes color table 1 from a cmap1.pal format file in one of standard PLplot paths."},
 {
     "drvopt",			/* Driver specific options */
     opt_drvopt,
@@ -1576,30 +1594,46 @@ opt_width(const char *opt, const char *optarg, void *client_data)
  * opt_bg()
  *
  * Performs appropriate action for option "bg":
- * Sets background color
+ * Sets background color (rgb represented in hex on command line) and alpha
+ * (represented as floating point on the command line with underscore
+ * delimiter), e.g., 
+ * -bg ff0000 (set background to red with an alpha value of 1.0)
+ * -bg ff0000_0.1 (set background to red with an alpha value of 0.1
 \*--------------------------------------------------------------------------*/
 
 static int
 opt_bg(const char *opt, const char *optarg, void *client_data)
 {
     const char *rgb;
+    char *color_field, *alpha_field;
     long bgcolor, r, g, b;
+    PLFLT a;
 
-/* Always in hex!  Strip off leading "#" (TK-ism) if present. */
+/* Strip off leading "#" (TK-ism) if present. */
 
     if (*optarg == '#')
 	rgb = optarg + 1;
     else
 	rgb = optarg;
 
-/* Get number in hex */
+    strncpy(opttmp, optarg, OPTMAX-1);
+    opttmp[OPTMAX-1] = '\0';
 
-    bgcolor = strtol(rgb, NULL, 16);
+    if (strchr (opttmp, '_')) {
+      /* e.g., -bg ff0000_0.1 */
+      color_field = strtok (opttmp, "_");
+      alpha_field = strtok (NULL, "_");
+    } else {
+      color_field = opttmp;
+      alpha_field = NULL;
+    }
+      
+    bgcolor = strtol(color_field, NULL, 16);
 
 /* Must be either a 3 or 6 digit hex number */
 /* If 3 digits, each is "doubled" (i.e. ABC becomes AABBCC). */
 
-    switch (strlen(rgb)) {
+    switch (strlen(color_field)) {
     case 3:
 	r = (bgcolor & 0xF00) >> 8;
 	g = (bgcolor & 0x0F0) >> 4;
@@ -1617,11 +1651,16 @@ opt_bg(const char *opt, const char *optarg, void *client_data)
 	break;
 
     default:
-	fprintf(stderr, "Unrecognized background color value %s\n", rgb);
+	fprintf(stderr, "Unrecognized background color value %s\n", color_field);
 	return 1;
     }
 
-    plscolbg(r, g, b);
+    if(alpha_field)
+      a = atof(alpha_field);
+    else
+      a = 1.;
+
+    plscolbga(r, g, b, a);
 
     return 0;
 }
@@ -1668,6 +1707,7 @@ opt_wplt(const char *opt, const char *optarg, void *client_data)
     PLFLT xl, yl, xr, yr;
 
     strncpy(opttmp, optarg, OPTMAX-1);
+    opttmp[OPTMAX-1] = '\0';
 
     if ((field = strtok(opttmp, ",")) == NULL)
 	return 1;
@@ -1833,13 +1873,14 @@ opt_fsiz(const char *opt, const char *optarg, void *client_data)
     strncpy(spec, optarg, len);
     spec[len] = '\0';
 
-    bytemax = multiplier * atof(spec);
-    if (bytemax == 0) {
-	fprintf(stderr, "?invalid bytemax\n");
+    bytemax = (PLINT)(multiplier * atof(spec));
+    if (bytemax<=0) {
+	fprintf(stderr, "?invalid file size %d. 2.14G is the maximum.\n", bytemax);
 	return 1;
     }
     plsfam(1, -1, bytemax);
 
+    free(spec);
     return 0;
 }
 
@@ -2090,6 +2131,7 @@ opt_geo(const char *opt, const char *optarg, void *client_data)
 /* Set up plplot dimensions */
 
     strncpy(opttmp, optarg, OPTMAX-1);
+    opttmp[OPTMAX-1] = '\0';
     if (strchr (opttmp, 'x')) {
 
     /* -geometry WxH or -geometry WxH+Xoff+Yoff */
@@ -2162,6 +2204,7 @@ opt_dpi(const char *opt, const char *optarg, void *client_data)
     PLINT xwid = 0, ywid = 0, xoff = 0, yoff = 0;
 
     strncpy(opttmp, optarg, OPTMAX-1);
+    opttmp[OPTMAX-1] = '\0';
     if (strchr (opttmp, 'x')) {
 	field = strtok (opttmp, "x");
 	xdpi = atof (field);
@@ -2206,4 +2249,28 @@ opt_dev_compression(const char *opt, const char *optarg, void *client_data)
     return 0;
 }
 
+/*--------------------------------------------------------------------------*\
+ * opt_cmap0()
+ *
+ * Sets color table 0 based on a cmap0.pal file.
+\*--------------------------------------------------------------------------*/
 
+static int
+opt_cmap0(const char *opt, const char *optarg, void *client_data)
+{
+  plspal0(optarg);
+  return 0;
+}
+
+/*--------------------------------------------------------------------------*\
+ * opt_cmap1()
+ *
+ * Sets color table 1 based on a cmap1.pal file.
+\*--------------------------------------------------------------------------*/
+
+static int
+opt_cmap1(const char *opt, const char *optarg, void *client_data)
+{
+  plspal1(optarg, TRUE);
+  return 0;
+}
