@@ -1,4 +1,4 @@
-/* $Id: plbox.c 8992 2008-11-19 09:34:20Z andrewross $
+/* $Id: plbox.c 10215 2009-08-05 15:17:56Z hezekiahcarty $
 
 	Routines for drawing axes & box around the current viewport.
 
@@ -24,6 +24,10 @@
 
 #include "plplotP.h"
 
+#define STRING_LEN 40
+#define FORMAT_LEN 10
+#define TEMP_LEN 30
+
 static PLFLT xlog[8] =
 {
     0.301030, 0.477121, 0.602060, 0.698970,
@@ -33,7 +37,7 @@ static PLFLT xlog[8] =
 /* Static function prototypes */
 
 static void
-plxybx(const char *opt, const char *label, PLFLT wx1, PLFLT wy1,
+plxybx(const char *opt, const char *label, PLINT axis, PLFLT wx1, PLFLT wy1,
        PLFLT wx2, PLFLT wy2, PLFLT vmin, PLFLT vmax,
        PLFLT tick, PLINT nsub, PLINT nolast, PLINT *digits);
 
@@ -51,7 +55,7 @@ plztx(const char *opt, PLFLT dx, PLFLT dy, PLFLT wx, PLFLT wy1,
       PLFLT wy2, PLFLT disp, PLFLT pos, PLFLT just, const char *text);
 
 static void
-plform(PLFLT value, PLINT scale, PLINT prec, char *result, PLINT ll, PLINT lf);
+plform(PLINT axis, PLFLT value, PLINT scale, PLINT prec, char *result, PLINT len, PLBOOL ll, PLBOOL lf, PLBOOL lo);
 
 static void
 grid_box(const char *xopt, PLFLT xtick1, PLINT nxsub1,
@@ -98,6 +102,7 @@ c_plbox(const char *xopt, PLFLT xtick, PLINT nxsub,
  * l: Logarithmic axes, major ticks at decades, minor ticks at units
  * n: Write numeric label at conventional location
  * m: Write numeric label at unconventional location
+ * o: Label text is generated by a user-defined function
  * t: Draw major tick marks
  * s: Draw minor tick marks
  * v: (for Y only) Label vertically
@@ -385,8 +390,8 @@ c_plaxes(PLFLT x0, PLFLT y0,
 /* Draw the horizontal axis */
 
     if (lax) {
-	plP_movphy(vppxmi, yp0);
-	plP_draphy(vppxma, yp0);
+	plP_movphy(vppxmi, (PLINT)yp0);
+	plP_draphy(vppxma, (PLINT)yp0);
 	if (ltx) {
 	    tp = xtick1 * floor(vpwxmi / xtick1);
 	    for (;;) {
@@ -396,20 +401,20 @@ c_plaxes(PLFLT x0, PLFLT y0,
 			for (i = 0; i <= 7; i++) {
 			    temp = tp + xlog[i];
 			    if (BETW(temp, vpwxmi, vpwxma))
-				plxtik(plP_wcpcx(temp), yp0, xminor, xminor);
+				plxtik(plP_wcpcx(temp), (PLINT)yp0, xminor, xminor);
 			}
 		    }
 		    else {
 			for (i = 1; i <= nxsub1 - 1; i++) {
 			    temp = tp + i * xtick1 / nxsub1;
 			    if (BETW(temp, vpwxmi, vpwxma))
-				plxtik(plP_wcpcx(temp), yp0, xminor, xminor);
+				plxtik(plP_wcpcx(temp), (PLINT)yp0, xminor, xminor);
 			}
 		    }
 		}
 		if (!BETW(tn, vpwxmi, vpwxma))
 		    break;
-		plxtik(plP_wcpcx(tn), yp0, xmajor, xmajor);
+		plxtik(plP_wcpcx(tn), (PLINT)yp0, xmajor, xmajor);
 		tp = tn;
 	    }
 	}
@@ -418,8 +423,8 @@ c_plaxes(PLFLT x0, PLFLT y0,
 /* Draw the vertical axis */
 
     if (lay) {
-	plP_movphy(xp0, vppymi);
-	plP_draphy(xp0, vppyma);
+	plP_movphy((PLINT)xp0, vppymi);
+	plP_draphy((PLINT)xp0, vppyma);
 	if (lty) {
 	    tp = ytick1 * floor(vpwymi / ytick1);
 	    for (;;) {
@@ -429,20 +434,20 @@ c_plaxes(PLFLT x0, PLFLT y0,
 			for (i = 0; i <= 7; i++) {
 			    temp = tp + xlog[i];
 			    if (BETW(temp, vpwymi, vpwyma))
-				plytik(xp0, plP_wcpcy(temp), yminor, yminor);
+				plytik((PLINT)xp0, plP_wcpcy(temp), yminor, yminor);
 			}
 		    }
 		    else {
 			for (i = 1; i <= nysub1 - 1; i++) {
 			    temp = tp + i * ytick1 / nysub1;
 			    if (BETW(temp, vpwymi, vpwyma))
-				plytik(xp0, plP_wcpcy(temp), yminor, yminor);
+				plytik((PLINT)xp0, plP_wcpcy(temp), yminor, yminor);
 			}
 		    }
 		}
 		if (!BETW(tn, vpwymi, vpwyma))
 		    break;
-		plytik(xp0, plP_wcpcy(tn), ymajor, ymajor);
+		plytik((PLINT)xp0, plP_wcpcy(tn), ymajor, ymajor);
 		tp = tn;
 	    }
 	}
@@ -516,7 +521,7 @@ c_plbox3(const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
 	ty = plP_w3wcy(xmin, ymin, zmin);
 	ux = plP_w3wcx(xmax, ymin, zmin);
 	uy = plP_w3wcy(xmax, ymin, zmin);
-	plxybx(xopt, xlabel, tx, ty, ux, uy,
+	plxybx(xopt, xlabel, PL_X_AXIS, tx, ty, ux, uy,
 	       xmin, xmax, xtick, nsubx, 0, &xdigits);
 
 	dx = ux - tx;
@@ -528,7 +533,7 @@ c_plbox3(const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
 	ty = plP_w3wcy(xmin, ymax, zmin);
 	ux = plP_w3wcx(xmin, ymin, zmin);
 	uy = plP_w3wcy(xmin, ymin, zmin);
-	plxybx(yopt, ylabel, tx, ty, ux, uy,
+	plxybx(yopt, ylabel, PL_Y_AXIS, tx, ty, ux, uy,
 	       ymax, ymin, ytick, nsuby, ln, &ydigits);
 
 	dx = ux - tx;
@@ -544,7 +549,7 @@ c_plbox3(const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
 	ty = plP_w3wcy(xmin, ymax, zmin);
 	ux = plP_w3wcx(xmin, ymin, zmin);
 	uy = plP_w3wcy(xmin, ymin, zmin);
-	plxybx(yopt, ylabel, tx, ty, ux, uy,
+	plxybx(yopt, ylabel, PL_Y_AXIS, tx, ty, ux, uy,
 	       ymax, ymin, ytick, nsuby, 0, &ydigits);
 
 	dx = ux - tx;
@@ -556,7 +561,7 @@ c_plbox3(const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
 	ty = plP_w3wcy(xmax, ymax, zmin);
 	ux = plP_w3wcx(xmin, ymax, zmin);
 	uy = plP_w3wcy(xmin, ymax, zmin);
-	plxybx(xopt, xlabel, tx, ty, ux, uy,
+	plxybx(xopt, xlabel, PL_X_AXIS, tx, ty, ux, uy,
 	       xmax, xmin, xtick, nsubx, ln, &xdigits);
 
 	dx = ux - tx;
@@ -572,7 +577,7 @@ c_plbox3(const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
 	ty = plP_w3wcy(xmax, ymax, zmin);
 	ux = plP_w3wcx(xmin, ymax, zmin);
 	uy = plP_w3wcy(xmin, ymax, zmin);
-	plxybx(xopt, xlabel, tx, ty, ux, uy,
+	plxybx(xopt, xlabel, PL_X_AXIS, tx, ty, ux, uy,
 	       xmax, xmin, xtick, nsubx, 0, &xdigits);
 
 	dx = ux - tx;
@@ -584,7 +589,7 @@ c_plbox3(const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
 	ty = plP_w3wcy(xmax, ymin, zmin);
 	ux = plP_w3wcx(xmax, ymax, zmin);
 	uy = plP_w3wcy(xmax, ymax, zmin);
-	plxybx(yopt, ylabel, tx, ty, ux, uy,
+	plxybx(yopt, ylabel, PL_Y_AXIS, tx, ty, ux, uy,
 	       ymin, ymax, ytick, nsuby, ln, &ydigits);
 
 	dx = ux - tx;
@@ -600,7 +605,7 @@ c_plbox3(const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
 	ty = plP_w3wcy(xmax, ymin, zmin);
 	ux = plP_w3wcx(xmax, ymax, zmin);
 	uy = plP_w3wcy(xmax, ymax, zmin);
-	plxybx(yopt, ylabel, tx, ty, ux, uy,
+	plxybx(yopt, ylabel, PL_X_AXIS, tx, ty, ux, uy,
 	       ymin, ymax, ytick, nsuby, 0, &ydigits);
 
 	dx = ux - tx;
@@ -612,7 +617,7 @@ c_plbox3(const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
 	ty = plP_w3wcy(xmin, ymin, zmin);
 	ux = plP_w3wcx(xmax, ymin, zmin);
 	uy = plP_w3wcy(xmax, ymin, zmin);
-	plxybx(xopt, xlabel, tx, ty, ux, uy,
+	plxybx(xopt, xlabel, PL_X_AXIS, tx, ty, ux, uy,
 	       xmin, xmax, xtick, nsubx, ln, &xdigits);
 
 	dx = ux - tx;
@@ -645,18 +650,19 @@ c_plbox3(const char *xopt, const char *xlabel, PLFLT xtick, PLINT nsubx,
  * i: Inverts tick marks (i.e. drawn downwards)
  * l: Logarithmic axes, major ticks at decades, minor ticks at units
  * n: Write numeric label
+ * o: Use custom label function
  * t: Draw major tick marks
  * s: Draw minor tick marks
  * u: Write label on line
 \*--------------------------------------------------------------------------*/
 
 static void
-plxybx(const char *opt, const char *label, PLFLT wx1, PLFLT wy1,
+plxybx(const char *opt, const char *label, PLINT axis, PLFLT wx1, PLFLT wy1,
        PLFLT wx2, PLFLT wy2, PLFLT vmin_in, PLFLT vmax_in,
        PLFLT tick, PLINT nsub, PLINT nolast, PLINT *digits)
 {
-    static char string[40];
-    PLINT lb, ld, lf, li, ll, ln, ls, lt, lu;
+    static char string[STRING_LEN];
+    PLINT lb, ld, lf, li, ll, ln, ls, lt, lu, lo;
     PLINT major, minor, mode, prec, scale;
     PLINT i, i1, i2, i3, i4;
     PLINT nsub1;
@@ -688,6 +694,7 @@ plxybx(const char *opt, const char *label, PLFLT wx1, PLFLT wy1,
     ls = plP_stsearch(opt, 's');
     lt = plP_stsearch(opt, 't');
     lu = plP_stsearch(opt, 'u');
+    lo = plP_stsearch(opt, 'o');
 
     if (lu)
 	plxytx(wx1, wy1, wx2, wy2, 3.2, 0.5, 0.5, label);
@@ -772,7 +779,7 @@ plxybx(const char *opt, const char *label, PLFLT wx1, PLFLT wy1,
 	tp = tick1 * (1. + floor(vmin / tick1));
 	for (tn = tp; BETW(tn, vmin, vmax); tn += tick1) {
 	   if(BETW(tn, vmin+tcrit, vmax-tcrit)) {
-	    plform(tn, scale, prec, string, ll, lf);
+	    plform(axis, tn, scale, prec, string, STRING_LEN, ll, lf, lo);
 	    pos = (vmax_in > vmin_in)?
 	       (tn - vmin) / (vmax - vmin):
 	       (vmax - tn) / (vmax - vmin);
@@ -780,8 +787,8 @@ plxybx(const char *opt, const char *label, PLFLT wx1, PLFLT wy1,
 	   }
 	}
 	*digits = 2;
-	if (!ll && mode) {
-	    sprintf(string, "(x10#u%d#d)", (int) scale);
+	if (!ll && !lo && mode) {
+	    snprintf(string, STRING_LEN, "(x10#u%d#d)", (int) scale);
 	    plxytx(wx1, wy1, wx2, wy2, height, 1.0, 0.5, string);
 	}
     }
@@ -855,6 +862,7 @@ plxytx(PLFLT wx1, PLFLT wy1, PLFLT wx2, PLFLT wy2,
  * l: Logarithmic axes, major ticks at decades, minor ticks at units
  * m: Write numeric label on right axis
  * n: Write numeric label on left axis
+ * o: Use custom label function
  * s: Draw minor tick marks
  * t: Draw major tick marks
  * u: Writes left-hand label
@@ -866,8 +874,8 @@ plzbx(const char *opt, const char *label, PLINT right, PLFLT dx, PLFLT dy,
       PLFLT wx, PLFLT wy1, PLFLT wy2, PLFLT vmin_in, PLFLT vmax_in,
       PLFLT tick, PLINT nsub, PLINT *digits)
 {
-    static char string[40];
-    PLINT lb, lc, ld, lf, li, ll, lm, ln, ls, lt, lu, lv;
+    static char string[STRING_LEN];
+    PLINT lb, lc, ld, lf, li, ll, lm, ln, ls, lt, lu, lv, lo;
     PLINT i, mode, prec, scale;
     PLINT nsub1, lstring;
     PLFLT pos, tn, tp, temp, height, tick1;
@@ -899,6 +907,7 @@ plzbx(const char *opt, const char *label, PLINT right, PLFLT dx, PLFLT dy,
     lt = plP_stsearch(opt, 't');
     lu = plP_stsearch(opt, 'u');
     lv = plP_stsearch(opt, 'v');
+    lo = plP_stsearch(opt, 'o');
 
     if (lu && !right)
 	plztx("h", dx, dy, wx, wy1, wy2, 5.0, 0.5, 0.5, label);
@@ -988,7 +997,7 @@ plzbx(const char *opt, const char *label, PLINT right, PLFLT dx, PLFLT dy,
 	*digits = 0;
 	tp = tick1 * floor(vmin / tick1);
 	for (tn = tp + tick1; BETW(tn, vmin, vmax); tn += tick1) {
-	    plform(tn, scale, prec, string, ll, lf);
+	    plform(PL_Z_AXIS, tn, scale, prec, string, STRING_LEN, ll, lf, lo);
 	    pos = (vmax_in > vmin_in)?
 	        (tn - vmin) / (vmax - vmin):
 	        (vmax - tn) / (vmax - vmin);
@@ -1001,8 +1010,8 @@ plzbx(const char *opt, const char *label, PLINT right, PLFLT dx, PLFLT dy,
 	    lstring = strlen(string);
 	    *digits = MAX(*digits, lstring);
 	}
-	if (!ll && mode) {
-	    sprintf(string, "(x10#u%d#d)", (int) scale);
+	if (!ll && !lo && mode) {
+	    snprintf(string, STRING_LEN, "(x10#u%d#d)", (int) scale);
 	    pos = 1.15;
 	    height = 0.5;
 	    if (ln && !right) {
@@ -1191,16 +1200,14 @@ grid_box(const char *xopt, PLFLT xtick1, PLINT nxsub1,
 static void
 label_box(const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1)
 {
-    static char string[40];
-    PLBOOL ldx, lfx, lix, llx, lmx, lnx, ltx;
-    PLBOOL ldy, lfy, liy, lly, lmy, lny, lty, lvy;
+    static char string[STRING_LEN];
+    PLBOOL ldx, lfx, lix, llx, lmx, lnx, ltx, lox;
+    PLBOOL ldy, lfy, liy, lly, lmy, lny, lty, lvy, loy;
     PLFLT vpwxmi, vpwxma, vpwymi, vpwyma;
     PLFLT vpwxmin, vpwxmax, vpwymin, vpwymax;
-    PLFLT pos, tn, tp, offset, height;
+    PLFLT pos, tn, tp, offset, height, just;
     PLFLT factor, tstart;
     const char *timefmt;
-    struct tm *tm;
-    time_t t;
 
 /* Set plot options from input */
 
@@ -1211,6 +1218,7 @@ label_box(const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1)
     lmx = plP_stsearch(xopt, 'm');
     lnx = plP_stsearch(xopt, 'n');
     ltx = plP_stsearch(xopt, 't');
+    lox = plP_stsearch(xopt, 'o');
 
     ldy = plP_stsearch(yopt, 'd');
     lfy = plP_stsearch(yopt, 'f');
@@ -1220,6 +1228,7 @@ label_box(const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1)
     lny = plP_stsearch(yopt, 'n');
     lty = plP_stsearch(yopt, 't');
     lvy = plP_stsearch(yopt, 'v');
+    loy = plP_stsearch(yopt, 'o');
 
     plP_xgvpw(&vpwxmin, &vpwxmax, &vpwymin, &vpwymax);
 /* n.b. large change; vpwxmi always numerically less than vpwxma, and
@@ -1246,12 +1255,10 @@ label_box(const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1)
 	  tp = xtick1 * (1. + floor(vpwxmi / xtick1));
 	for (tn = tp; BETW(tn, vpwxmi, vpwxma); tn += xtick1) {
             if (ldx) {
-              t = (time_t) tn;
-              tm = gmtime(&t);
-              strftime(string, 40, timefmt, tm);
+              strfqsas(string, STRING_LEN, timefmt, (double) tn, plsc->qsasconfig);
             }
             else {
-	      plform(tn, xscale, xprec, string, llx, lfx);
+              plform(PL_X_AXIS, tn, xscale, xprec, string, STRING_LEN, llx, lfx, lox);
             }
 	    height = lix ? 1.75 : 1.5;
 	    pos = (vpwxmax > vpwxmin)?
@@ -1267,14 +1274,24 @@ label_box(const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1)
 
     /* Write separate exponential label if mode = 1. */
 
-	if (!llx && !ldx && xmode) {
-	    pos = 1.0;
-	    height = 3.2;
-	    sprintf(string, "(x10#u%d#d)", (int) xscale);
+	if (!llx && !ldx && !lox && xmode) {
+            /* Assume label data is for placement of exponents if no custom
+               label function is provided. */
+            if (plsc->label_data) {
+                height = ((PLLabelDefaults *)plsc->label_data)->exp_label_disp;
+                pos = ((PLLabelDefaults *)plsc->label_data)->exp_label_pos;
+                just = ((PLLabelDefaults *)plsc->label_data)->exp_label_just;
+            }
+            else {
+                height = 3.2;
+                pos = 1.0;
+                just = 0.5;
+            }
+	    snprintf(string, STRING_LEN, "(x10#u%d#d)", (int) xscale);
 	    if (lnx)
-		plmtex("b", height, pos, 0.5, string);
+		plmtex("b", height, pos, just, string);
 	    if (lmx)
-		plmtex("t", height, pos, 0.5, string);
+		plmtex("t", height, pos, just, string);
 	}
     }
 
@@ -1295,12 +1312,10 @@ label_box(const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1)
 	  tp = ytick1 * (1. + floor(vpwymi / ytick1));
 	for (tn = tp; BETW(tn, vpwymi, vpwyma); tn += ytick1) {
             if (ldy) {
-              t = (time_t) tn;
-              tm = gmtime(&t);
-              strftime(string, 40, timefmt, tm);
+              strfqsas(string, STRING_LEN, timefmt, (double) tn, plsc->qsasconfig);
             }
             else {
-	      plform(tn, yscale, yprec, string, lly, lfy);
+	      plform(PL_Y_AXIS, tn, yscale, yprec, string, STRING_LEN, lly, lfy, loy);
             }
 	    pos = (vpwymax > vpwymin)?
 	        (tn - vpwymi) / (vpwyma - vpwymi):
@@ -1332,18 +1347,26 @@ label_box(const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1)
 
     /* Write separate exponential label if mode = 1. */
 
-	if (!lly && !ldy && ymode) {
-	    sprintf(string, "(x10#u%d#d)", (int) yscale);
-	    offset = 0.02;
-	    height = 2.0;
-	    if (lny) {
-		pos = 0.0 - offset;
-		plmtex("t", height, pos, 1.0, string);
-	    }
-	    if (lmy) {
-		pos = 1.0 + offset;
-		plmtex("t", height, pos, 0.0, string);
-	    }
+	if (!lly && !ldy && !loy && ymode) {
+	    snprintf(string, STRING_LEN, "(x10#u%d#d)", (int) yscale);
+            if (plsc->label_data) {
+                height = ((PLLabelDefaults *)plsc->label_data)->exp_label_disp;
+                pos = ((PLLabelDefaults *)plsc->label_data)->exp_label_pos;
+                just = ((PLLabelDefaults *)plsc->label_data)->exp_label_just;
+            }
+            else {
+                offset = 0.02;
+                height = 2.0;
+                if (lny) {
+                    pos = 0.0 - offset;
+                    just = 1.0;
+                }
+                if (lmy) {
+                    pos = 1.0 + offset;
+                    just = 0.0;
+                }
+            }
+            plmtex("t", height, pos, just, string);
 	}
     }
 }
@@ -1368,61 +1391,105 @@ label_box(const char *xopt, PLFLT xtick1, const char *yopt, PLFLT ytick1)
  *    -	If scale == 1, use scientific notation with one place before the
  *	decimal point and "prec" places after.  In this case, the value
  *	must be divided by 10^scale.
+ *
+ * The axis argument is included to support PLplot's custom axis labeling.  It
+ * is passed on to the custom labeling function if it exists.  Otherwise, it
+ * is ignored.
 \*--------------------------------------------------------------------------*/
 
 static void
-plform(PLFLT value, PLINT scale, PLINT prec, char *string, PLINT ll, PLINT lf)
+plform(PLINT axis, PLFLT value, PLINT scale, PLINT prec, char *string, PLINT len, PLBOOL ll, PLBOOL lf, PLBOOL lo)
 {
-    if (ll) {
-
-    /* Logarithmic */
-
-	if (lf) {
-
-	/* Fixed point, i.e. .1, 1, 10, etc */
-
-	    int exponent = ROUND(value);
-
-	    value = pow(10.0, exponent);
-	    if (exponent < 0) {
-		char form[10];
-		sprintf(form, "%%.%df", ABS(exponent));
-		sprintf(string, form, value);
-	    }
-	    else {
-		sprintf(string, "%d", (int) value);
-	    }
-	}
-	else {
-
-	/* Exponential, i.e. 10^-1, 10^0, 10^1, etc */
-
-	    sprintf(string, "10#u%d", (int) ROUND(value));
-	}
+    /* Check to see if a custom labeling function is defined.  If not, */
+    if (lo && plsc->label_func) {
+        (*plsc->label_func)(axis, value, string, len, plsc->label_data);
     }
     else {
+        if (lo) {
+            plwarn("Custom axis labels requested without a labeling function \
+                    - using default.");
+        }
+        if (ll) {
 
-    /* Linear */
+        /* Logarithmic */
 
-	PLINT setpre, precis;
-	char form[10], temp[30];
-	double scale2;
+            if (lf) {
 
-	plP_gprec(&setpre, &precis);
+            /* Fixed point, i.e. .1, 1, 10, etc */
 
-	if (setpre)
-	    prec = precis;
+                int exponent = ROUND(value);
 
-	if (scale)
-	    value /= pow(10.,(double)scale);
+                value = pow(10.0, exponent);
+                if (exponent < 0) {
+                    char form[FORMAT_LEN];
+                    snprintf(form, FORMAT_LEN, "%%.%df", ABS(exponent));
+                    snprintf(string, len, form, value);
+                }
+                else {
+                    snprintf(string, len, "%d", (int) value);
+                }
+            }
+            else {
 
-    /* This is necessary to prevent labels like "-0.0" on some systems */
+            /* Exponential, i.e. 10^-1, 10^0, 10^1, etc */
 
-	scale2 = pow(10., prec);
-	value = floor((value * scale2) + .5) / scale2;
+                snprintf(string, len, "10#u%d", (int) ROUND(value));
+            }
+        }
+        else {
 
-	sprintf(form, "%%.%df", (int) prec);
-	sprintf(temp, form, value);
-	strcpy(string, temp);
+        /* Linear */
+
+            PLINT setpre, precis;
+            char form[FORMAT_LEN], temp[TEMP_LEN];
+            double scale2;
+
+            plP_gprec(&setpre, &precis);
+
+            if (setpre)
+                prec = precis;
+
+            if (scale)
+                value /= pow(10.,(double)scale);
+
+        /* This is necessary to prevent labels like "-0.0" on some systems */
+
+            scale2 = pow(10., prec);
+            value = floor((value * scale2) + .5) / scale2;
+
+            snprintf(form, FORMAT_LEN, "%%.%df", (int) prec);
+            snprintf(temp, TEMP_LEN, form, value);
+            strncpy(string, temp, len-1);
+            string[len-1] = '\0';
+        }
     }
 }
+
+/*--------------------------------------------------------------------------*\
+ * plslabelfunc
+ *
+ * Formats a PLFLT value in one of the following formats.
+ *
+ * label_func - A pointer to a function which will provide a string to use
+ *              as the label for the given floating point value.
+ *              Pass this as NULL to clear the custom function and reset it to
+ *              the default PLplot labeling function.
+ *
+ * label_data - Extra data to pass to the label function.
+ *
+ * The label_func function arguments are, in order:
+ *
+ * axis: PL_X_AXIS, PL_Y_AXIS or PL_Z_AXIS to indicate which axis is being
+ *       labeled
+ * value: The value at this position on the axis
+ * string: The resulting label string should be stored here
+ * data: A pointer to whatever extra information the custom plotting function
+ *       requires
+ *
+\*--------------------------------------------------------------------------*/
+void
+c_plslabelfunc(void (*label_func)(PLINT, PLFLT, char *, PLINT, PLPointer), PLPointer label_data)
+{
+    plsc->label_func = label_func;
+    plsc->label_data = label_data;
+}
