@@ -1,4 +1,4 @@
-/* $Id: plcont.c 8368 2008-04-15 08:49:18Z andrewross $
+/* $Id: plcont.c 9727 2009-03-12 08:18:31Z smekal $
 
 	Contour plotter.
 
@@ -36,7 +36,7 @@ static void
 plcntr(PLFLT (*plf2eval) (PLINT, PLINT, PLPointer),
        PLPointer plf2eval_data,
        PLINT nx, PLINT ny, PLINT kx, PLINT lx,
-       PLINT ky, PLINT ly, PLFLT flev, PLINT **ipts, 
+       PLINT ky, PLINT ly, PLFLT flev, PLINT **ipts,
        void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
        PLPointer pltr_data);
 
@@ -51,7 +51,7 @@ pldrawcn(PLFLT (*plf2eval) (PLINT, PLINT, PLPointer),
 	 PLPointer pltr_data);
 
 static void
-plfloatlabel(PLFLT value, char *string);
+plfloatlabel(PLFLT value, char *string, PLINT len);
 
 static PLFLT
 plP_pcwcx(PLINT x);
@@ -255,7 +255,8 @@ void c_pl_setcontlabelformat(PLINT lexp, PLINT sigdig)
 
 static void pl_drawcontlabel(PLFLT tpx, PLFLT tpy, char *flabel, PLFLT *distance, PLINT *lastindex)
 {
-    PLFLT currx_old, curry_old,	delta_x, delta_y;
+    PLFLT delta_x, delta_y;
+    PLINT currx_old, curry_old;
 
     delta_x = plP_pcdcx(plsc->currx)-plP_pcdcx(plP_wcpcx(tpx));
     delta_y = plP_pcdcy(plsc->curry)-plP_pcdcy(plP_wcpcy(tpy));
@@ -306,7 +307,7 @@ static void pl_drawcontlabel(PLFLT tpx, PLFLT tpy, char *flabel, PLFLT *distance
  * print the label
  */
 
-static void plfloatlabel(PLFLT value, char *string)
+static void plfloatlabel(PLFLT value, char *string, PLINT len)
 {
     PLINT  setpre, precis;
     /* form[10] gives enough space for all non-malicious formats.
@@ -316,7 +317,9 @@ static void plfloatlabel(PLFLT value, char *string)
      * Obviously there are security issues here that
      * should be addressed as well.
      */
-    char   form[10], tmpstring[15];
+#define FORM_LEN 10
+#define TMPSTRING_LEN 15
+    char   form[FORM_LEN], tmpstring[TMPSTRING_LEN];
     PLINT  exponent = 0;
     PLFLT  mant, tmp;
 
@@ -349,10 +352,10 @@ static void plfloatlabel(PLFLT value, char *string)
     if (mant != 0.0)
 	mant = (int )(mant*pow(10.0, prec-1) + 0.5*mant/fabs(mant))/pow(10.0, prec-1);
 
-    sprintf(form, "%%.%df", prec-1);
-    sprintf(string, form, mant);
-    sprintf(tmpstring, "#(229)10#u%d", exponent);
-    strcat(string, tmpstring);
+    snprintf(form, FORM_LEN, "%%.%df", prec-1);
+    snprintf(string, len, form, mant);
+    snprintf(tmpstring, TMPSTRING_LEN, "#(229)10#u%d", exponent);
+    strncat(string, tmpstring, len-strlen(string)-1);
 
     if (abs(exponent) < limexp || value == 0.0) {
 	value = pow(10.0, exponent) * mant;
@@ -365,8 +368,8 @@ static void plfloatlabel(PLFLT value, char *string)
 	if (prec < 0)
             prec = 0;
 
-	sprintf(form, "%%.%df", (int) prec);
-	sprintf(string, form, value);
+	snprintf(form, FORM_LEN, "%%.%df", (int) prec);
+	snprintf(string, len, form, value);
     }
 }
 
@@ -487,6 +490,7 @@ c_plcont(PLFLT **f, PLINT nx, PLINT ny, PLINT kx, PLINT lx,
     if (pltr == NULL) {
         /* If pltr is undefined, abort with an error. */
         plabort("plcont: The pltr callback must be defined");
+        return;
     }
 
     grid.f = f;
@@ -587,21 +591,21 @@ plcntr(PLFLT (*f2eval) (PLINT, PLINT, PLPointer),
     cont_new_store(flev);
 
     /* format contour label for plptex and define the font height of the labels */
-    plfloatlabel(flev, flabel);
+    plfloatlabel(flev, flabel, 30);
     plschr(0.0, contlabel_size);
 
     /* Clear array for traversed squares */
     for (kcol = kx; kcol < lx; kcol++) {
         for (krow = ky; krow < ly; krow++) {
 	    ipts[kcol][krow] = 0;
-	} 
+	}
     }
 
 
     for (krow = ky; krow < ly; krow++) {
         for (kcol = kx; kcol < lx; kcol++) {
 	    if (ipts[kcol][krow] == 0) {
-	      
+	
 	        /* Follow and draw a contour */
 	        pldrawcn(f2eval, f2eval_data,
 		         nx, ny, kx, lx, ky, ly, flev, flabel, kcol, krow,
@@ -628,7 +632,7 @@ pldrawcn(PLFLT (*f2eval) (PLINT, PLINT, PLPointer),
 	 PLPointer f2eval_data,
 	 PLINT nx, PLINT ny, PLINT kx, PLINT lx,
 	 PLINT ky, PLINT ly, PLFLT flev, char *flabel, PLINT kcol, PLINT krow,
-	 PLFLT lastx, PLFLT lasty, PLINT startedge, PLINT **ipts, 
+	 PLFLT lastx, PLFLT lasty, PLINT startedge, PLINT **ipts,
 	 PLFLT *distance, PLINT *lastindex,
 	 void (*pltr) (PLFLT, PLFLT, PLFLT *, PLFLT *, PLPointer),
 	 PLPointer pltr_data)
@@ -657,12 +661,12 @@ pldrawcn(PLFLT (*f2eval) (PLINT, PLINT, PLPointer),
     ipts[kcol][krow] = 1;
 
     /* Check if no contour has been crossed i.e. iedge[i] = -1 */
-    if ((iedge[0] == -1) && (iedge[1] == -1) && (iedge[2] == -1) 
+    if ((iedge[0] == -1) && (iedge[1] == -1) && (iedge[2] == -1)
          && (iedge[3] == -1)) return;
 
-    /* Check if this is a completely flat square - in which case 
+    /* Check if this is a completely flat square - in which case
        ignore it */
-    if ( (f[0] == 0.0) && (f[1] == 0.0) && (f[2] == 0.0) && 
+    if ( (f[0] == 0.0) && (f[1] == 0.0) && (f[2] == 0.0) &&
 	 (f[3] == 0.0) ) return;
 
     /* Calculate intersection points */
@@ -728,15 +732,15 @@ pldrawcn(PLFLT (*f2eval) (PLINT, PLINT, PLPointer),
 		      (krownext >= ky) && (krownext < ly) &&
 		      (ipts[kcolnext][krownext] == 0)) {
 		      pldrawcn(f2eval, f2eval_data,
-			       nx, ny, kx, lx, ky, ly, flev, flabel, 
+			       nx, ny, kx, lx, ky, ly, flev, flabel,
 			       kcolnext, krownext,
-			       locx[num], locy[num], inext, ipts, 
+			       locx[num], locy[num], inext, ipts,
 			       distance, lastindex,
 			       pltr, pltr_data);
 		  }
       	      }
 	      /* Hard case where contour passes through corner */
-	      /* This is still not perfect - it may lose the contour 
+	      /* This is still not perfect - it may lose the contour
 	       * which won't upset the contour itself (we can find it
 	       * again later) but might upset the labelling */
 	      else {
@@ -751,13 +755,13 @@ pldrawcn(PLFLT (*f2eval) (PLINT, PLINT, PLPointer),
 		      (krownext >= ky) && (krownext < ly) &&
 		      (ipts[kcolnext][krownext] == 0)) {
 		      pldrawcn(f2eval, f2eval_data,
-			       nx, ny, kx, lx, ky, ly, flev, flabel, 
+			       nx, ny, kx, lx, ky, ly, flev, flabel,
 			       kcolnext, krownext,
-			       locx[num], locy[num], inext, ipts, 
+			       locx[num], locy[num], inext, ipts,
 			       distance, lastindex,
 			       pltr, pltr_data);
 		  }
-		  
+		
 	      }
 	      if (first == 1) {
 	 	  /* Move back to first point */
