@@ -1,4 +1,4 @@
-/* $Id: plctrl.c 9110 2008-12-15 09:50:50Z andrewross $
+/* $Id: plctrl.c 10370 2009-09-04 23:45:36Z airwin $
 
 	Misc. control routines, like begin, end, exit, change graphics/text
 	mode, change color.  Includes some spillage from plcore.c.  If you
@@ -7,6 +7,7 @@
    Copyright (C) 2004  Joao Cardoso
    Copyright (C) 2004  Rafael Laboissiere
    Copyright (C) 2008  Hazen Babcock
+   Copyright (C) 2009  Alan W. Irwin
 
    This file is part of PLplot.
 
@@ -44,7 +45,7 @@
 #ifdef __unix
 #include <sys/types.h>
 #include <sys/stat.h>
-#ifdef HAVE_UNISTD_H
+#ifdef PL_HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 #include <errno.h>
@@ -53,6 +54,12 @@
 /* Random number generator (Mersenne Twister) */
 #include "mt19937ar.h"
 
+#define BUFFER_SIZE 256
+
+/* small epsilon for fuzzy range checks that is still large enough to
+   work even in the single precision floating point case.*/
+#define FUZZ_EPSILON 1.e-4
+
 /* Static functions */
 
 /* Used by any external init code to suggest a path */
@@ -67,7 +74,7 @@ strcat_delim(char *dirspec);
 static int
 (*exit_handler) (const char *errormsg);
 
-void
+static void
 (*abort_handler) (const char *errormsg);
 
 static void
@@ -79,6 +86,9 @@ plcmap1_def(void);
 static PLFLT
 value(double n1, double n2, double hue);
 
+static void
+cmap0_palette_read(const char *filename,
+                   int *number_colors, int **r, int **g, int **b, double **a);
 /* An additional hardwired location for lib files. */
 /* I have no plans to change these again, ever. */
 
@@ -120,8 +130,8 @@ c_plcol0(PLINT icol0)
 	return;
     }
     if (icol0 < 0 || icol0 >= plsc->ncol0) {
-	char buffer[256];
-	sprintf(buffer, "plcol0: Invalid color map entry: %d", (int) icol0);
+	char buffer[BUFFER_SIZE];
+	snprintf(buffer, BUFFER_SIZE, "plcol0: Invalid color map entry: %d", (int) icol0);
 	plabort(buffer);
 	return;
     }
@@ -152,13 +162,13 @@ c_plcol1(PLFLT col1)
 	return;
     }
     if (col1 < 0 || col1 > 1) {
-	char buffer[256];
-	sprintf(buffer, "plcol1: Invalid color map position: %f", (PLFLT) col1);
+	char buffer[BUFFER_SIZE];
+	snprintf(buffer, BUFFER_SIZE, "plcol1: Invalid color map position: %f", (PLFLT) col1);
 	plabort(buffer);
 	return;
     }
 
-    icol1 = col1 * plsc->ncol1;
+    icol1 = (PLINT)(col1 * plsc->ncol1);
     icol1 = MIN(icol1, plsc->ncol1-1);
 
     plsc->icol1 = icol1;
@@ -232,14 +242,14 @@ c_plscol0(PLINT icol0, PLINT r, PLINT g, PLINT b)
     if (plsc->cmap0 == NULL)
 	plscmap0n(0);
     if (icol0 < 0 || icol0 >= plsc->ncol0) {
-	char buffer[256];
-	sprintf(buffer, "plscol0: Illegal color table value: %d", (int) icol0);
+	char buffer[BUFFER_SIZE];
+	snprintf(buffer, BUFFER_SIZE, "plscol0: Illegal color table value: %d", (int) icol0);
 	plabort(buffer);
 	return;
     }
     if ((r < 0 || r > 255) || (g < 0 || g > 255) || (b < 0 || b > 255)) {
-	char buffer[256];
-	sprintf(buffer, "plscol0: Invalid RGB color: %d, %d, %d",
+	char buffer[BUFFER_SIZE];
+	snprintf(buffer, BUFFER_SIZE, "plscol0: Invalid RGB color: %d, %d, %d",
 		(int) r, (int) g, (int) b);
 	plabort(buffer);
 	return;
@@ -261,14 +271,14 @@ c_plscol0a(PLINT icol0, PLINT r, PLINT g, PLINT b, PLFLT a)
     if (plsc->cmap0 == NULL)
 	plscmap0n(0);
     if (icol0 < 0 || icol0 >= plsc->ncol0) {
-	char buffer[256];
-	sprintf(buffer, "plscol0a: Illegal color table value: %d", (int) icol0);
+	char buffer[BUFFER_SIZE];
+	snprintf(buffer, BUFFER_SIZE, "plscol0a: Illegal color table value: %d", (int) icol0);
 	plabort(buffer);
 	return;
     }
     if ((r < 0 || r > 255) || (g < 0 || g > 255) || (b < 0 || b > 255) || (a < 0 || a > 1.0)) {
-	char buffer[256];
-	sprintf(buffer, "plscol0a: Invalid RGB color: %d, %d, %d, %f",
+	char buffer[BUFFER_SIZE];
+	snprintf(buffer, BUFFER_SIZE, "plscol0a: Invalid RGB color: %d, %d, %d, %f",
 		(int) r, (int) g, (int) b, (double) a);
 	plabort(buffer);
 	return;
@@ -301,8 +311,8 @@ c_plgcol0(PLINT icol0, PLINT *r, PLINT *g, PLINT *b)
     *b = -1;
 
     if (icol0 < 0 || icol0 > plsc->ncol0) {
-	char buffer[256];
-	sprintf(buffer, "plgcol0: Invalid color index: %d", (int) icol0);
+	char buffer[BUFFER_SIZE];
+	snprintf(buffer, BUFFER_SIZE, "plgcol0: Invalid color index: %d", (int) icol0);
 	plabort(buffer);
 	return;
     }
@@ -333,8 +343,8 @@ c_plgcol0a(PLINT icol0, PLINT *r, PLINT *g, PLINT *b, PLFLT *a)
     *a = -1.0;
 
     if (icol0 < 0 || icol0 > plsc->ncol0) {
-	char buffer[256];
-	sprintf(buffer, "plgcol0: Invalid color index: %d", (int) icol0);
+	char buffer[BUFFER_SIZE];
+	snprintf(buffer, BUFFER_SIZE, "plgcol0: Invalid color index: %d", (int) icol0);
 	plabort(buffer);
 	return;
     }
@@ -366,8 +376,8 @@ c_plscmap0(PLINT *r, PLINT *g, PLINT *b, PLINT ncol0)
 	    (g[i] < 0 || g[i] > 255) ||
 	    (b[i] < 0 || b[i] > 255)) {
 
-	    char buffer[256];
-	    sprintf(buffer, "plscmap0: Invalid RGB color: %d, %d, %d",
+	    char buffer[BUFFER_SIZE];
+	    snprintf(buffer, BUFFER_SIZE, "plscmap0: Invalid RGB color: %d, %d, %d",
 		    (int) r[i], (int) g[i], (int) b[i]);
 	    plabort(buffer);
 	    return;
@@ -403,8 +413,8 @@ c_plscmap0a(PLINT *r, PLINT *g, PLINT *b, PLFLT *a, PLINT ncol0)
 	    (b[i] < 0 || b[i] > 255) ||
 	    (a[i] < 0.0 || a[i] > 1.0)) {
 
-	    char buffer[256];
-	    sprintf(buffer, "plscmap0a: Invalid RGB color: %d, %d, %d, %f",
+	    char buffer[BUFFER_SIZE];
+	    snprintf(buffer, BUFFER_SIZE, "plscmap0a: Invalid RGB color: %d, %d, %d, %f",
 		    (int) r[i], (int) g[i], (int) b[i], (double) a[i]);
 	    plabort(buffer);
 	    return;
@@ -439,8 +449,8 @@ c_plscmap1(PLINT *r, PLINT *g, PLINT *b, PLINT ncol1)
 	    (g[i] < 0 || g[i] > 255) ||
 	    (b[i] < 0 || b[i] > 255)) {
 
-	    char buffer[256];
-	    sprintf(buffer, "plscmap1: Invalid RGB color: %d, %d, %d",
+	    char buffer[BUFFER_SIZE];
+	    snprintf(buffer, BUFFER_SIZE, "plscmap1: Invalid RGB color: %d, %d, %d",
 		    (int) r[i], (int) g[i], (int) b[i]);
 	    plabort(buffer);
 	    return;
@@ -475,8 +485,8 @@ c_plscmap1a(PLINT *r, PLINT *g, PLINT *b, PLFLT *a, PLINT ncol1)
 	    (b[i] < 0 || b[i] > 255) ||
 	    (a[i] < 0.0 || a[i] > 1.0)) {
 
-	    char buffer[256];
-	    sprintf(buffer, "plscmap1a: Invalid RGB color: %d, %d, %d, %f",
+	    char buffer[BUFFER_SIZE];
+	    snprintf(buffer, BUFFER_SIZE, "plscmap1a: Invalid RGB color: %d, %d, %d, %f",
 		    (int) r[i], (int) g[i], (int) b[i], (double) a[i]);
 	    plabort(buffer);
 	    return;
@@ -781,7 +791,7 @@ c_plscmap0n(PLINT ncol0)
 /* Allocate the space */
 
     if (plsc->cmap0 == NULL) {
-	if ((plsc->cmap0 = (PLColor *) calloc(1, size))==NULL)
+      if ((plsc->cmap0 = (PLColor *) calloc(1, size))==NULL)
      {
        plexit("c_plscmap0n: Insufficient memory");
      }
@@ -804,6 +814,55 @@ c_plscmap0n(PLINT ncol0)
 	plP_state(PLSTATE_CMAP0);
 }
 
+/*--------------------------------------------------------------------------*\
+ * color_set()
+ *
+ * Initializes color table entry by RGB values.
+\*--------------------------------------------------------------------------*/
+
+void
+color_set(PLINT i, U_CHAR r, U_CHAR g, U_CHAR b, PLFLT a, char *name )
+{
+    plsc->cmap0[i].r = r;
+    plsc->cmap0[i].g = g;
+    plsc->cmap0[i].b = b;
+    plsc->cmap0[i].a = a;
+    plsc->cmap0[i].name = name;
+}
+
+#define color_def(i, r, g, b, a, n)			\
+  if (i >= imin && i <= imax) color_set(i, r, g, b, a, n);
+
+/*--------------------------------------------------------------------------*\
+ * plcmap0_def()
+ *
+ * Initializes specified color map 0 color entry to its default.
+\*--------------------------------------------------------------------------*/
+
+void
+plcmap0_def(int imin, int imax)
+{
+  int i, *r, *g, *b;
+  double *a;
+  int number_colors;
+  if(imin <= imax) {
+    cmap0_palette_read("", &number_colors, &r, &g, &b, &a);
+    free(r);
+    free(g);
+    free(b);
+    free(a);
+    
+  } else {
+    number_colors = 0;
+  }
+
+  /* Initialize all colours undefined by the default colour palette file
+     to opaque red as a warning. */
+  for (i = MAX(number_colors, imin); i <= imax; i++)
+    color_def(i, 255, 0, 0, 1.0,
+              "opaque red to mark not defined by palette file");
+}
+
 /*--------------------------------------------------------------------------*\
  * plscmap1n()
  *
@@ -861,81 +920,6 @@ c_plscmap1n(PLINT ncol1)
 	plcmap1_calc();
 }
 
-/*--------------------------------------------------------------------------*\
- * color_set()
- *
- * Initializes color table entry by RGB values.
-\*--------------------------------------------------------------------------*/
-
-static void
-color_set(PLINT i, U_CHAR r, U_CHAR g, U_CHAR b, PLFLT a, char *name )
-{
-    plsc->cmap0[i].r = r;
-    plsc->cmap0[i].g = g;
-    plsc->cmap0[i].b = b;
-    plsc->cmap0[i].a = a;
-    plsc->cmap0[i].name = name;
-}
-
-/*--------------------------------------------------------------------------*\
- * plcmap0_def()
- *
- * Initializes specified color map 0 color entry to its default.
- *
- * Initial RGB values for color map 0 taken from X11R6
- * (XFree86-3.3.6) X-windows
- * rgb.txt file, and may not accurately represent the described colors on
- * all systems.
-\*--------------------------------------------------------------------------*/
-
-#define color_def(i, r, g, b, a, n)			\
-  if (i >= imin && i <= imax) color_set(i, r, g, b, a, n);
-
-static void
-plcmap0_def(int imin, int imax)
-{
-    int i;
-
-    color_def(0,    0,   0,   0, 1.0, "black" );        /* black */
-    color_def(1,  255,   0,   0, 1.0, "red");           /* red */
-    color_def(2,  255, 255,   0, 1.0, "yellow" );       /* yellow */
-    color_def(3,    0, 255,   0, 1.0, "green" );	/* green */
-    color_def(4,  127, 255, 212, 1.0, "aquamarine" );	/* aquamarine */
-    color_def(5,  255, 192, 203, 1.0, "pink" );	        /* pink */
-    color_def(6,  245, 222, 179, 1.0, "wheat" );	/* wheat */
-    color_def(7,  190, 190, 190, 1.0, "grey" );	        /* grey */
-    color_def(8,  165,  42,  42, 1.0, "brown" );	/* brown */
-    color_def(9,    0,   0, 255, 1.0, "blue" );	        /* blue */
-    color_def(10, 138,  43, 226, 1.0, "BlueViolet" );	/* Blue Violet */
-    color_def(11,   0, 255, 255, 1.0, "cyan" );	        /* cyan */
-    color_def(12,  64, 224, 208, 1.0, "turquoise" );	/* turquoise */
-    color_def(13, 255,   0, 255, 1.0, "magenta" );	/* magenta */
-    color_def(14, 250, 128, 114, 1.0, "salmon" );	/* salmon */
-    color_def(15, 255, 255, 255, 1.0, "white" );	/* white */
-
-/*     color_def(0, 255, 255, 255, "white" );	/\* white *\/ */
-/*     color_def(1,    0,   0,   0, "black" );	/\* black *\/ */
-/*     color_def(2,    0,   0, 255, "blue" );	/\* blue *\/ */
-/*     color_def(3,  255,   0,   0, "red");	/\* red *\/ */
-/*     color_def(4,  165,  42,  42, "brown" );	/\* brown *\/ */
-/*     color_def(5, 250, 128, 114, "salmon" );	/\* salmon *\/ */
-/*     color_def(6,  255, 192, 203, "pink" );	/\* pink *\/ */
-/*     color_def(7,  127, 255, 212, "aquamarine" );	/\* aquamarine *\/ */
-/*     color_def(8,  245, 222, 179, "wheat" );	/\* wheat *\/ */
-/*     color_def(9,  64, 224, 208, "turquoise" );	/\* turquoise *\/ */
-/*     color_def(10,  190, 190, 190, "grey" );	/\* grey *\/ */
-/*     color_def(11,   0, 255, 255, "cyan" );	/\* cyan *\/ */
-/*     color_def(12,    0, 255,   0, "green" );	/\* green *\/ */
-/*     color_def(13,  255, 255,   0, "yellow" );	/\* yellow *\/ */
-/*     color_def(14, 255,   0, 255, "magenta" );	/\* magenta *\/ */
-/*     color_def(15, 138,  43, 226, "BlueViolet" );	/\* Blue Violet *\/ */
-
-/* Any others are just arbitrarily set */
-
-    for (i = 16; i <= imax; i++)
-      color_def(i, 255, 0, 0, 1.0, "red"); 	/* red */
-}
-
 /*--------------------------------------------------------------------------*\
  * plcmap1_def()
  *
@@ -949,7 +933,7 @@ plcmap0_def(int imin, int imax)
  * palette editor.  If you don't like these settings.. change them!
 \*--------------------------------------------------------------------------*/
 
-static void
+void
 plcmap1_def(void)
 {
     PLFLT i[6], h[6], l[6], s[6], midpt = 0., vertex = 0.;
@@ -964,7 +948,7 @@ plcmap1_def(void)
     i[5] = 1;		/* right boundary */
 
 /* For center control points, pick black or white, whichever is closer to bg */
-/* Be carefult to pick just short of top or bottom else hue info is lost */
+/* Be careful to pick just short of top or bottom else hue info is lost */
 
     if (plsc->cmap0 != NULL)
 	vertex = ((PLFLT) plsc->cmap0[0].r +
@@ -1100,7 +1084,7 @@ c_plhls(PLFLT h, PLFLT l, PLFLT s)
  * Auxiliary function used by c_plhlsrgb().
 \*--------------------------------------------------------------------------*/
 
-static PLFLT
+PLFLT
 value(double n1, double n2, double hue)
 {
     PLFLT val;
@@ -1207,6 +1191,368 @@ c_plrgbhls(PLFLT r, PLFLT g, PLFLT b, PLFLT *p_h, PLFLT *p_l, PLFLT *p_s)
     *p_s = s;
 }
 
+/*--------------------------------------------------------------------------*\
+ * cmap0_palette_read()
+ *
+ * Read and check r, g, b, a data from a cmap0*.pal format file.
+ * The caller must free the returned malloc'ed space for r, g, b, and a.
+\*--------------------------------------------------------------------------*/
+
+void
+cmap0_palette_read(const char *filename,
+                   int *number_colors, int **r, int **g, int **b, double **a)
+{
+  int i, err = 0;
+  char color_info[30];
+  char msgbuf[1024];
+  FILE *fp;
+
+  /*  if(!(setlocale(LC_NUMERIC, "C"))) {
+    plexit("cmap0_palette_read: LC_NUMERIC locale could not be set for \"C\"");
+    } */
+  if(strlen(filename) == 0) {
+    fp = plLibOpen(PL_DEFAULT_CMAP0_FILE);
+    if (fp == NULL) {
+      snprintf(msgbuf,1024,"Unable to open cmap0 file %s\n",PL_DEFAULT_CMAP0_FILE);
+      plwarn(msgbuf);
+      err = 1;
+    }
+  } else {
+    fp = plLibOpen(filename);
+    if (fp == NULL) {
+      snprintf(msgbuf,1024,"Unable to open cmap0 file %s\n",filename);
+      plwarn(msgbuf);
+      err = 1;
+    }
+  }
+  if (!err &&(fscanf(fp, "%d\n", number_colors) != 1 || *number_colors < 1)) {
+    fclose(fp);
+    snprintf(msgbuf,1024,"Unrecognized cmap0 header\n");
+    plwarn(msgbuf);
+    err = 1;
+  }
+
+  if(!err) {
+    /* Allocate arrays to hold r, g, b, and a data for calling routine.
+       The caller must free these after it is finished with them. */
+    if(((*r = (int *)malloc(*number_colors * sizeof(int))) == NULL) ||
+       ((*g = (int *)malloc(*number_colors * sizeof(int))) == NULL) ||
+       ((*b = (int *)malloc(*number_colors * sizeof(int))) == NULL) ||
+       ((*a = (double *)malloc(*number_colors * sizeof(double))) == NULL)) {
+      fclose(fp);
+      plexit("cmap0_palette_read: insufficient memory");
+    }
+          
+    for(i=0;i<*number_colors;i++){
+      fgets(color_info, 30, fp);
+      color_info[strlen(color_info)-1] = '\0'; /* remove return character */
+      if(strlen(color_info) == 7){
+        if (sscanf(color_info, "#%2x%2x%2x",
+                   (int *) (*r+i), (int *) (*g+i), (int *) (*b+i)) != 3) {
+          err = 1;
+          break;
+        }
+        *(*a+i) = 1.0;
+      } else if(strlen(color_info) > 9) {
+        if (sscanf(color_info, "#%2x%2x%2x %lf",
+                   (int *) (*r+i), (int *) (*g+i), (int *) (*b+i),
+                   (double *) (*a+i)) != 4) {
+          err = 1;
+          break;
+        }
+        /* fuzzy range check. */
+        if(*(*a+i) < -FUZZ_EPSILON || *(*a+i) > (1. + FUZZ_EPSILON)) {
+          err = 1;
+          break;
+        } else if(*(*a+i) < 0.) {
+          *(*a+i) = 0.;
+        } else if(*(*a+i) > 1.) {
+          *(*a+i) = 1.;
+        }
+      } else {
+        err = 1;
+        break;
+      }
+    }
+    fclose(fp);
+    if(err) {
+      snprintf(msgbuf,1024,"Unrecognized cmap0 format data line.  Line is %s\n",
+               color_info);
+      plwarn(msgbuf);
+      free(*r);
+      free(*g);
+      free(*b);
+      free(*a);
+    }
+  }
+  /* Fall back to opaque red on opaque white as visual warning of any
+     error above. */
+  if(err) {
+    *number_colors = 16;
+    if(((*r = (int *)malloc(*number_colors * sizeof(int))) == NULL) ||
+       ((*g = (int *)malloc(*number_colors * sizeof(int))) == NULL) ||
+       ((*b = (int *)malloc(*number_colors * sizeof(int))) == NULL) ||
+       ((*a = (double *)malloc(*number_colors * sizeof(double))) == NULL)) {
+      plexit("cmap0_palette_read: insufficient memory");
+    }
+    **r = 255;
+    **g = 255;
+    **b = 255;
+    **a = 1.;
+    for(i=1;i<*number_colors;i++){
+        *(*r+i) = 255;
+        *(*g+i) = 0;
+        *(*b+i) = 0;
+        *(*a+i) = 1.0;
+    }
+  }
+
+  /* Restore default LC_NUMERIC locale since we fiddled with it above.
+  if(!(setlocale(LC_NUMERIC, plplot_default_lc_numeric_locale))) {
+    snprintf(msgbuf,1024,"cmap0_palette_read: LC_NUMERIC could not be restored to the default \"%s\" locale.\n", *plplot_default_lc_numeric_locale);
+    plexit(msgbuf);
+    } */
+}
+
+/*--------------------------------------------------------------------------*\
+ * void c_plspal0(filename)
+ *
+ * Set the palette for color map 0 using a cmap0*.pal format file.
+ * filename: the name of the cmap0*.pal file to use.
+\*--------------------------------------------------------------------------*/
+
+void
+c_plspal0(const char *filename)
+{
+  int i, *r, *g, *b;
+  double *a;
+  int number_colors;
+  cmap0_palette_read(filename, &number_colors, &r, &g, &b, &a);
+  /* Allocate default number of cmap0 colours if cmap0 allocation not
+     done already. */
+  plscmap0n(0);
+  /* Allocate sufficient cmap0 colours to contain present data. */
+  if(number_colors > plsc->ncol0) {
+    plscmap0n(number_colors);
+  }
+  for(i=0;i<number_colors;i++){
+    c_plscol0a(i, r[i], g[i], b[i], a[i]);
+  }
+  free(r);
+  free(g);
+  free(b);
+  free(a);
+}
+
+/* This code fragment used a lot in plspal1 to deal with
+   floating-point range checking of a value and the adjustment of that
+   value when close to the range when there is floating-point errors.
+*/
+#define fuzzy_range_check(value, min, max, fuzz, err_number)            \
+  if(value < (min - fuzz) || value > (max + fuzz)) {                    \
+    snprintf(msgbuf,1024,"Unrecognized cmap1 format data line.  Error number is %d. Line is %s\n", err_number, color_info);                                   \
+    plwarn(msgbuf);                                                     \
+    err = 1;                                                            \
+    break;                                                              \
+  } else if (value < min) {                                             \
+    value = min;                                                        \
+  } else if (value > max) {                                             \
+    value = max;                                                        \
+  }
+/*--------------------------------------------------------------------------*\
+ * void c_plspal1(filename)
+ *
+ * Set the palette for color map 1 using a cmap1*.pal format file.
+ * filename: the name of the cmap1*.pal file to use.
+\*--------------------------------------------------------------------------*/
+
+void
+c_plspal1(const char *filename, PLBOOL interpolate)
+{
+  int i;
+  int number_colors;
+  int format_version, err;
+  PLBOOL rgb;
+  char color_info[160];
+  int r_i, g_i, b_i, pos_i, rev_i;
+  double r_d, g_d, b_d, a_d, pos_d;
+  PLFLT *r, *g, *b, *a, *pos;
+  PLINT *ri, *gi, *bi;
+  PLBOOL *rev;
+  FILE *fp;
+  char msgbuf[1024];
+
+  /*  if(!(setlocale(LC_NUMERIC, "C"))) {
+    plexit("plspal1: LC_NUMERIC locale could not be set for \"C\"");
+    }*/
+  rgb = TRUE;
+  err = 0;
+  format_version = 0;
+  if(strlen(filename) == 0) {
+    fp = plLibOpen(PL_DEFAULT_CMAP1_FILE);
+    if (fp == NULL) {
+      snprintf(msgbuf,1024,"Unable to open cmap1 .pal file %s\n",PL_DEFAULT_CMAP1_FILE);
+      plwarn(msgbuf);
+      return;
+    }
+  } else {
+    fp = plLibOpen(filename);
+    if (fp == NULL) {
+      snprintf(msgbuf,1024,"Unable to open cmap1 .pal file %s\n",filename);
+      plwarn(msgbuf);
+      return;
+    }
+  }
+  /* Check for new file format */
+  fgets(color_info, 160, fp);
+  if (strncmp(color_info,"v2 ",2) == 0) {
+    format_version = 1;
+    if (strncmp(&color_info[3],"hls",3) == 0)
+      rgb = FALSE;
+    else if (strncmp(&color_info[3],"rgb",3) == 0)
+      rgb = TRUE;
+    else {
+      snprintf(msgbuf,1024,"Invalid color space %s - assuming RGB\n",&color_info[3]);
+      plwarn(msgbuf);
+      rgb = TRUE;
+    }
+    fgets(color_info, 160, fp);
+  }
+
+  if (sscanf(color_info, "%d\n", &number_colors) != 1 || number_colors < 2) {
+    snprintf(msgbuf,1024,"Unrecognized cmap1 format (wrong number of colors) %s\n", color_info);
+    plwarn(msgbuf);
+    fclose(fp);
+    return;
+  }
+
+  r = (PLFLT *)malloc(number_colors * sizeof(PLFLT));
+  g = (PLFLT *)malloc(number_colors * sizeof(PLFLT));
+  b = (PLFLT *)malloc(number_colors * sizeof(PLFLT));
+  ri = (PLINT *)malloc(number_colors * sizeof(PLINT));
+  gi = (PLINT *)malloc(number_colors * sizeof(PLINT));
+  bi = (PLINT *)malloc(number_colors * sizeof(PLINT));
+  a = (PLFLT *)malloc(number_colors * sizeof(PLFLT));
+  pos = (PLFLT *)malloc(number_colors * sizeof(PLFLT));
+  rev = (PLBOOL *)malloc(number_colors * sizeof(PLBOOL));
+
+  if (format_version == 0) {
+    int return_sscanf, return_sscanf_old=0;
+    /* Old tk file format */
+    for(i=0;i<number_colors;i++){
+      fgets(color_info, 160, fp);
+      /* Ensure string is null terminated if > 160 characters */
+      color_info[159] = '\0';
+      return_sscanf = sscanf(color_info, "#%2x%2x%2x %d %d", &r_i, &g_i, &b_i, &pos_i, &rev_i);
+      if(return_sscanf < 4 || (return_sscanf_old != 0 && return_sscanf != return_sscanf_old)) {
+	snprintf(msgbuf,1024,"Unrecognized cmap1 format (wrong number of items for version 1 of format) %s\n", color_info);
+	plwarn(msgbuf);
+	err = 1;
+	break;
+      }
+      return_sscanf_old = return_sscanf;
+      /* For old format, input colours range from 0 to 255 and
+         need to be renormalized to the range from 0. to 1.. */
+      r[i] = (PLFLT)r_i/255.;
+      g[i] = (PLFLT)g_i/255.;
+      b[i] = (PLFLT)b_i/255.;
+      a[i] = 1.0;
+      pos[i] = 0.01*(PLFLT)pos_i;
+      fuzzy_range_check(r[i], 0., 1., FUZZ_EPSILON, 1);
+      fuzzy_range_check(g[i], 0., 1., FUZZ_EPSILON, 2);
+      fuzzy_range_check(b[i], 0., 1., FUZZ_EPSILON, 3);
+      fuzzy_range_check(pos[i], 0., 1., FUZZ_EPSILON, 4);
+      if(return_sscanf == 5) {
+        /* Next to oldest tk format with rev specified. */
+        rev[i] = (PLBOOL)rev_i;
+      }
+    }
+    if(return_sscanf == 4) {
+      /* Oldest tk format.  No rev specified. */
+      free(rev);
+      rev = NULL;
+    }
+  }
+  else {
+    /* New floating point file version with support for alpha and rev values */
+    for(i=0;i<number_colors;i++){
+      fgets(color_info, 160, fp);
+      if (sscanf(color_info, "%lf %lf %lf %lf %lf %d", &pos_d, &r_d, &g_d, &b_d, &a_d, &rev_i) != 6) {
+	snprintf(msgbuf,1024,"Unrecognized cmap1 format (wrong number of items for version 2 of format) %s\n", color_info);
+	plwarn(msgbuf);
+	err = 1;
+	break;
+      }
+             
+      r[i] = (PLFLT)r_d;
+      g[i] = (PLFLT)g_d;
+      b[i] = (PLFLT)b_d;
+      a[i] = (PLFLT)a_d;
+      pos[i] = (PLFLT)pos_d;
+      /* Check that all rgba and pos data within range from 0. to
+         1. except for the hls colour space case where the first
+         coordinate is checked within range from 0. to 360.*/
+      if(rgb) {
+        fuzzy_range_check(r[i], 0., 1., FUZZ_EPSILON, 5);
+      } else {
+        fuzzy_range_check(r[i], 0., 360., (360.*FUZZ_EPSILON), 6);
+      }
+      fuzzy_range_check(g[i], 0., 1., FUZZ_EPSILON, 7);
+      fuzzy_range_check(b[i], 0., 1., FUZZ_EPSILON, 8);
+      fuzzy_range_check(a[i], 0., 1., FUZZ_EPSILON, 9);
+      fuzzy_range_check(pos[i], 0., 1., FUZZ_EPSILON, 10);
+      
+      rev[i] = (PLBOOL)rev_i;
+    }
+  }
+  fclose(fp);
+
+  if (!err) {
+    if (interpolate) {
+        c_plscmap1la(rgb, number_colors, pos, r, g, b, a, rev);
+    }
+    else {
+        for (i = 0; i < number_colors; i++) {
+            ri[i] = r[i] * 255.0;
+            gi[i] = g[i] * 255.0;
+            bi[i] = b[i] * 255.0;
+        }
+        c_plscmap1a(ri, gi, bi, a, number_colors);
+    }
+  } else {
+    /* Fall back to red scale as visual warning if some problem occurred
+       above. */
+    free(r);
+    free(g);
+    free(b);
+    free(pos);
+    number_colors = 2;
+    r = (PLFLT *)malloc(number_colors * sizeof(PLFLT));
+    g = (PLFLT *)malloc(number_colors * sizeof(PLFLT));
+    b = (PLFLT *)malloc(number_colors * sizeof(PLFLT));
+    pos = (PLFLT *)malloc(number_colors * sizeof(PLFLT));
+    r[0] = 0.;
+    r[1] = 1.;
+    g[0] = 0.;
+    g[1] = 0.;
+    b[0] = 0.;
+    b[1] = 0.;
+    pos[0] = 0.;
+    pos[1] = 1.;
+    c_plscmap1l(TRUE, number_colors, pos, r, g, b, NULL);
+  }
+
+  free(r);
+  free(g);
+  free(b);
+  free(ri);
+  free(gi);
+  free(bi);
+  free(a);
+  free(pos);
+  free(rev);
+}
+
 /*--------------------------------------------------------------------------*\
  * A grab-bag of various control routines.
 \*--------------------------------------------------------------------------*/
@@ -1517,7 +1863,7 @@ plLibOpenPdfstrm(const char *fn)
 /****   search build tree               ****/
 
     if (plInBuildTree() == 1) {
-      plGetName(BUILD_DIR, "data", fn, &fs);
+      plGetName(SOURCE_DIR, "data", fn, &fs);
 
       if ((file = pdf_fopen(fs, "rb")) != NULL)
         goto done;
@@ -1531,15 +1877,17 @@ plLibOpenPdfstrm(const char *fn)
 
         if ((file = pdf_fopen(fs, "rb")) != NULL)
             goto done;
-
         fprintf(stderr, PLPLOT_LIB_ENV"=\"%s\"\n", dn); /* what IS set? */
     }
 #endif  /* PLPLOT_LIB_ENV */
 
 /****	search current directory	****/
 
-    if ((file = pdf_fopen(fn, "rb")) != NULL)
-        goto done;
+    if ((file = pdf_fopen(fn, "rb")) != NULL){
+      pldebug("plLibOpenPdfstr", "Found file %s in current directory.\n", fn);
+      free_mem(fs);
+      return (file);
+    }
 
 /****	search PLPLOT_HOME_ENV/lib = $(PLPLOT_HOME)/lib	****/
 
@@ -1581,11 +1929,11 @@ plLibOpenPdfstrm(const char *fn)
 	plGetName(plplotLibDir, "", fn, &fs);
 	if ((file = pdf_fopen(fs, "rb")) != NULL)
 	    goto done;
-
     }
 
 /**** 	not found, give up 	****/
     pldebug("plLibOpenPdfstr", "File %s not found.\n", fn);
+    free_mem(fs);
     return NULL;
 
  done:
@@ -1617,12 +1965,12 @@ int
 plFindName(char *p)
 {
     int n;
-    char buf[1024], *cp;
+    char buf[PLPLOT_MAX_PATH], *cp;
     extern int errno;
     struct stat sbuf;
 
     pldebug("plFindName", "Trying to find %s\n", p);
-    while ((n = readlink(p, buf, 1024)) > 0) {
+    while ((n = readlink(p, buf, PLPLOT_MAX_PATH)) > 0) {
 	pldebug("plFindName", "Readlink read %d chars at: %s\n", n, p);
 	if (buf[0] == '/') {
 	/* Link is an absolute path */
@@ -1686,7 +2034,6 @@ plGetName(const char *dir, const char *subdir, const char *filename, char **file
 /* Malloc space for filespec */
 
     free_mem(*filespec);
-    lfilespec = 10;
     lfilespec = strlen(dir) + strlen(subdir) + strlen(filename) + 10;
     if ((*filespec = (char *) malloc(lfilespec))==NULL)
       {
@@ -1703,6 +2050,8 @@ plGetName(const char *dir, const char *subdir, const char *filename, char **file
 	strcat_delim(*filespec);
 	strcat(*filespec, filename);
     }
+    pldebug("plGetName", "Length of full pathname of file to be found is %d\n", lfilespec);
+    pldebug("plGetName", "Full pathname of file to be found is %s\n", *filespec);
 }
 
 /*--------------------------------------------------------------------------*\
@@ -1712,11 +2061,11 @@ plGetName(const char *dir, const char *subdir, const char *filename, char **file
  * there already, or if dealing with a colon-terminated device name).
 \*--------------------------------------------------------------------------*/
 
-static void
+void
 strcat_delim(char *dirspec)
 {
     int ldirspec = strlen(dirspec);
-#if defined (MSDOS)
+#if defined (MSDOS) || defined(WIN32)
     if (dirspec[ldirspec-1] != '\\')
 	strcat(dirspec, "\\");
 #elif defined (macintosh)
@@ -1743,7 +2092,7 @@ plcol_interp(PLStream *pls, PLColor *newcolor, int i, int ncol)
     int il, ir;
 
     x = (double) (i * (pls->ncol1-1)) / (double) (ncol-1);
-    il = x;
+    il = (int)x;
     ir = il + 1;
     delta = x - il;
 
@@ -1757,9 +2106,9 @@ plcol_interp(PLStream *pls, PLColor *newcolor, int i, int ncol)
 	newcolor->a = pls->cmap1[il].a;
     }
     else {
-	newcolor->r = (1.-delta) * pls->cmap1[il].r + delta * pls->cmap1[ir].r;
-	newcolor->g = (1.-delta) * pls->cmap1[il].g + delta * pls->cmap1[ir].g;
-	newcolor->b = (1.-delta) * pls->cmap1[il].b + delta * pls->cmap1[ir].b;
+	newcolor->r = (unsigned char)((1.-delta) * pls->cmap1[il].r + delta * pls->cmap1[ir].r);
+	newcolor->g = (unsigned char)((1.-delta) * pls->cmap1[il].g + delta * pls->cmap1[ir].g);
+	newcolor->b = (unsigned char)((1.-delta) * pls->cmap1[il].b + delta * pls->cmap1[ir].b);
 	newcolor->a = (1.-delta) * pls->cmap1[il].a + delta * pls->cmap1[ir].a;
     }
 }
@@ -1778,7 +2127,7 @@ plOpenFile(PLStream *pls)
 {
     int i = 0, count = 0;
     size_t len;
-    char line[256];
+    char line[BUFFER_SIZE];
 
     while (pls->OutFile == NULL) {
 
@@ -1835,13 +2184,16 @@ plOpenFile(PLStream *pls)
 void
 plP_getmember(PLStream *pls)
 {
-    char tmp[256];
-    char prefix[256];
+    char tmp[BUFFER_SIZE];
+    char prefix[BUFFER_SIZE];
     char* suffix;
+    char num[BUFFER_SIZE];
+    int maxlen;
 
+    maxlen = strlen(pls->BaseName) + 10;
     if (pls->FileName == NULL)
       {
-        if ((pls->FileName = (char *) malloc(10 + strlen(pls->BaseName)))==NULL)
+        if ((pls->FileName = (char *) malloc(maxlen))==NULL)
           {
             plexit("plP_getmember: Insufficient memory");
           }
@@ -1849,15 +2201,17 @@ plP_getmember(PLStream *pls)
 
     suffix = strstr (pls->BaseName, "%n");
 
+    snprintf(tmp, BUFFER_SIZE, "%%0%1ii", (int) pls->fflen);
+    snprintf(num, BUFFER_SIZE, tmp, pls->member);
+
     if (suffix == NULL)
-      sprintf (tmp, "%s.%%0%1ii", pls->BaseName, (int) pls->fflen);
+      snprintf (pls->FileName, maxlen, "%s.%s", pls->BaseName, num);
     else {
-      strncpy (prefix, pls->BaseName, 256);
-      prefix [suffix - pls->BaseName] = 0;
-      sprintf (tmp, "%s%%0%1ii%s", prefix, (int) pls->fflen, suffix + 2);
+      strncpy (prefix, pls->BaseName, BUFFER_SIZE-1);
+      prefix [(suffix - pls->BaseName<BUFFER_SIZE)?(suffix-pls->BaseName):BUFFER_SIZE-1] = '\0';
+      snprintf (pls->FileName, maxlen, "%s%s%s", prefix, num, suffix + 2);
     }
 
-    sprintf(pls->FileName, tmp, pls->member);
 }
 
 /*--------------------------------------------------------------------------*\
@@ -1870,37 +2224,42 @@ plP_getmember(PLStream *pls)
 void
 plP_sfnam(PLStream *pls, const char *fnam)
 {
-    char prefix[256];
+    char prefix[BUFFER_SIZE];
     char* suffix;
+    int maxlen;
     pls->OutFile = NULL;
 
     if (pls->FileName != NULL)
 	free((void *) pls->FileName);
 
-    if ((pls->FileName = (char *) malloc(10 + strlen(fnam)))==NULL)
+    maxlen = 10 + strlen(fnam);
+    if ((pls->FileName = (char *) malloc(maxlen))==NULL)
       {
         plexit("plP_sfnam: Insufficient memory");
       }
 
     suffix = strstr (fnam, "%n");
 
-    if (suffix == NULL)
-      strcpy(pls->FileName, fnam);
+    if (suffix == NULL) {
+      strncpy(pls->FileName, fnam, maxlen-1);
+      pls->FileName[maxlen-1] = '\0';
+    }
     else {
-      strncpy (prefix, fnam, 256);
-      prefix [suffix - fnam] = 0;
-      sprintf (pls->FileName, "%s%s", prefix, suffix + 2);
+      strncpy (prefix, fnam, BUFFER_SIZE-1);
+      prefix [(suffix - fnam)<BUFFER_SIZE?(suffix-fnam):BUFFER_SIZE-1] = '\0';
+      snprintf (pls->FileName, maxlen, "%s%s", prefix, suffix + 2);
     }
 
     if (pls->BaseName != NULL)
 	free((void *) pls->BaseName);
 
-    if ((pls->BaseName = (char *) malloc(10 + strlen(fnam)))==NULL)
+    if ((pls->BaseName = (char *) malloc(maxlen))==NULL)
       {
         plexit("plP_sfnam: Insufficient memory");
       }
 
-    strcpy(pls->BaseName, fnam);
+    strncpy(pls->BaseName, fnam, maxlen-1);
+    pls->BaseName[maxlen-1] = '\0';
 }
 
 /*--------------------------------------------------------------------------*\
@@ -2050,7 +2409,7 @@ plGetInt(const char *s)
 {
     int m;
     int i = 0;
-    char line[256];
+    char line[BUFFER_SIZE];
 
     while (i++ < 10) {
 	fputs(s, stdout);
@@ -2081,7 +2440,7 @@ plGetFlt(const char *s)
     PLFLT m;
     double m1;
     int i = 0;
-    char line[256];
+    char line[BUFFER_SIZE];
 
     while (i++ < 10) {
 	fputs(s, stdout);
@@ -2139,6 +2498,10 @@ plsnprintf(char *buffer, int n, const char *format, ...)
   va_start(args, format);
 	ret=vsprintf(buffer, fmt, args);
   va_end( argptr );
+ 
+  /* Check if overrun occured */
+  if (ret > n-1) 
+    plabort("plsnprintf: buffer overrun");
   
   return ret;
 }
