@@ -1,4 +1,4 @@
-/* $Id: plcvt.c 8678 2008-08-19 14:31:13Z hbabcock $
+/* $Id: plcvt.c 9602 2009-02-24 13:08:40Z andrewross $
 
 	Coordinate transformation routines.
 
@@ -64,6 +64,7 @@ plP_mmpcy(PLFLT y)
 PLINT
 plP_wcpcx(PLFLT x)
 {
+    if (!finite(x)) return PLINT_MIN;
     return (ROUND(plsc->wpxoff + plsc->wpxscl * x));
 }
 
@@ -72,6 +73,7 @@ plP_wcpcx(PLFLT x)
 PLINT
 plP_wcpcy(PLFLT y)
 {
+    if (!finite(y)) return PLINT_MIN;
     return (ROUND(plsc->wpyoff + plsc->wpyscl * y));
 }
 
