@@ -1,4 +1,4 @@
-/* $Id: plfreetype.c 8981 2008-10-29 15:13:39Z andrewross $
+/* $Id: plfreetype.c 9477 2009-02-08 22:34:26Z andrewross $
  *
  * Copyright (C) 2002, 2004, 2005  Andrew Roach
  * Copyright (C) 2002  Maurice LeBrun
@@ -451,7 +451,11 @@ FT_PlotChar(PLStream *pls, FT_Data *FT, FT_GlyphSlot slot,
       clipymin = tmp;
     }
 
-    if ((slot->bitmap.pixel_mode==ft_pixel_mode_mono)||(pls->icol0==0)) {
+    /* Comment this out as it fails for cases where we want to plot text
+     * in the background font, i.e. example 24. 
+     */
+    /*if ((slot->bitmap.pixel_mode==ft_pixel_mode_mono)||(pls->icol0==0)) {*/
+    if (slot->bitmap.pixel_mode==ft_pixel_mode_mono) {
 	x+=slot->bitmap_left;
 	y-=slot->bitmap_top;
 
@@ -554,7 +558,7 @@ void plD_FreeType_init(PLStream *pls)
     FT_Data *FT;
     char *a;
 /* font paths and file names can be long so leave generous (1024) room */
-    char font_dir[1024];
+    char font_dir[PLPLOT_MAX_PATH];
     /* N.B. must be in exactly same order as TrueTypeLookup */
     const char *env_font_names[N_TrueTypeLookup] = {
          "PLPLOT_FREETYPE_SANS_FONT",
@@ -593,10 +597,11 @@ void plD_FreeType_init(PLStream *pls)
 #if defined(MSDOS) || defined(WIN32)
     static char *default_font_names[]={"arial.ttf","times.ttf","timesi.ttf","arial.ttf",
 				       "symbol.ttf"};
-    char WINDIR_PATH[255];
+    char WINDIR_PATH[PLPLOT_MAX_PATH];
     char *b;
     b=getenv("WINDIR");
-    strcpy(WINDIR_PATH,b);
+    strncpy(WINDIR_PATH,b,PLPLOT_MAX_PATH-1);
+    WINDIR_PATH[PLPLOT_MAX_PATH-1] = '\0';
 #else
     const char *default_unix_font_dir=PL_FREETYPE_FONT_DIR;
 #endif
@@ -643,7 +648,7 @@ void plD_FreeType_init(PLStream *pls)
     }
     else
     {
-      strcat(WINDIR_PATH,"\\fonts\\arial.ttf");
+      strncat(WINDIR_PATH,"\\fonts\\arial.ttf",PLPLOT_MAX_PATH-1-strlen(WINDIR_PATH));
       if (access(WINDIR_PATH, F_OK)==0)
         {
           b=strrchr(WINDIR_PATH,'\\');
@@ -668,10 +673,11 @@ void plD_FreeType_init(PLStream *pls)
  */
 
     if ((a = getenv("PLPLOT_FREETYPE_FONT_DIR")) != NULL)
-        strcpy(font_dir,a);
+        strncpy(font_dir,a,PLPLOT_MAX_PATH-1);
     else
-        strcpy(font_dir,default_unix_font_dir);
+        strncpy(font_dir,default_unix_font_dir,PLPLOT_MAX_PATH-1);
 
+    font_dir[PLPLOT_MAX_PATH-1] = '\0';
 #endif
 
 /*
@@ -697,23 +703,24 @@ void plD_FreeType_init(PLStream *pls)
 #else
 	    if ((a[0]=='/')||(a[0]=='~')) /* check for unix abs path */
 #endif
-		strcpy(FT->font_name[i],a);
+		strncpy(FT->font_name[i],a,PLPLOT_MAX_PATH-1);
 
 	    else {
-		strcpy(FT->font_name[i],font_dir);
-		strcat(FT->font_name[i],a);
+		strncpy(FT->font_name[i],font_dir,PLPLOT_MAX_PATH-1);
+		strncat(FT->font_name[i],a,PLPLOT_MAX_PATH-1-strlen(FT->font_name[i]));
 	    }
 
 	} else {
-	    strcpy(FT->font_name[i],font_dir);
-	    strcat(FT->font_name[i],(char *)TrueTypeLookup[i].pfont);
+	    strncpy(FT->font_name[i],font_dir,PLPLOT_MAX_PATH-1);
+	    strncat(FT->font_name[i],(char *)TrueTypeLookup[i].pfont,PLPLOT_MAX_PATH-1-strlen(FT->font_name[i]));
 	}
+        FT->font_name[i][PLPLOT_MAX_PATH-1] = '\0';
 
    {
    FILE *infile ;
 	if ( (infile=fopen(FT->font_name[i], "r"))==NULL) {
 	    char msgbuf[1024];
-	    sprintf(msgbuf,
+	    snprintf(msgbuf, 1024,
 		    "plD_FreeType_init: Could not find the freetype compatible font:\n %s",
 		    FT->font_name[i]);
 	    plwarn(msgbuf);
