@@ -1,6 +1,6 @@
 /*
    plgridd.c: Plot grids data from irregularly sampled data.
-   $Id: plgridd.c 7349 2007-02-04 05:45:38Z aroach $
+   $Id: plgridd.c 9586 2009-02-23 15:54:44Z andrewross $
 
    Copyright (C) 2004  Joao Cardoso
    Copyright (C) 2004  Alan W. Irwin
@@ -35,10 +35,6 @@
 #include <qhull/qhull_a.h>
 #endif
 
-#if !defined(HAVE_ISNAN)
-#define isnan(x) ((x) != (x))
-#endif
-
 /* forward declarations */
 static void
 grid_nnaidw (PLFLT *x, PLFLT *y, PLFLT *z, int npts,
@@ -148,7 +144,7 @@ c_plgriddata(PLFLT *x, PLFLT *y, PLFLT *z, PLINT npts,
 #ifdef WITH_CSA
     grid_csa(x, y, z, npts, xg, nptsx, yg, nptsy, zg);
 #else
-    plabort("plgriddata(): PLplot was configured to not use GRID_CSA.\n  Reverting to GRID_NNAIDW.");
+    plwarn("plgriddata(): PLplot was configured to not use GRID_CSA.\n  Reverting to GRID_NNAIDW.");
     grid_nnaidw(x, y, z, npts, xg, nptsx, yg, nptsy, zg);
 #endif
     break;
@@ -759,7 +755,7 @@ grid_adtli (PLFLT *x, PLFLT *y, PLFLT *z, int npts,
 
   /* Could pass extra args to qhull through the 'data' argument of
      plgriddata() */
-  sprintf(flags, "qhull d Qbb Qt");
+  strcpy(flags, "qhull d Qbb Qt", 250);
   
   if ((points = (coordT *) malloc(npts * (dim+1) * sizeof(coordT)))==NULL)
     {
