@@ -1,4 +1,4 @@
-/* $Id: plmap.c 8033 2007-11-23 15:28:09Z andrewross $
+/* $Id: plmap.c 9477 2009-02-08 22:34:26Z andrewross $
 
 	Continental Outline and Political Boundary Backgrounds
 
@@ -103,8 +103,9 @@ plmap( void (*mapform)(PLINT, PLFLT *, PLFLT *), const char *type,
     /*
      * read map outline
      */
-    strcpy(filename,type);
-    strcat(filename,MAP_FILE);
+    strncpy(filename,type,99);
+    filename[99] = '\0';
+    strncat(filename,MAP_FILE,99-strlen(filename));
 
     if ((in = plLibOpenPdfstrm(filename)) == NULL)
 	return;
