@@ -1,4 +1,4 @@
-/* $Id: plot3d.c 8082 2007-12-12 15:44:17Z andrewross $
+/* $Id: plot3d.c 8678 2008-08-19 14:31:13Z hbabcock $
 
 	3d plot routines.
 
@@ -2373,16 +2373,18 @@ pl3cut(PLINT sx1, PLINT sy1, PLINT sx2, PLINT sy2,
  * N.B. The plot transformation matrix is the product of the following
  * rotation and shear matrices:
  *
- * [c(t) -s(t)] [1 s(p)]
- * [s(t)  c(t)] [0 c(p)]
+ * [c(t) -s(t)] [stride s(p)]
+ * [s(t)  c(t)] [0      c(p)]
  * 
  * Where t is the rotation angle and phi is the shear angle.
 \*--------------------------------------------------------------------------*/
 
 void
-plRotationShear(PLFLT *xFormMatrix, PLFLT *rotation, PLFLT *shear)
+plRotationShear(PLFLT *xFormMatrix, PLFLT *rotation, PLFLT *shear, PLFLT *stride)
 {
-  *rotation = acos(xFormMatrix[0]);
+  *stride = sqrt(xFormMatrix[0] * xFormMatrix[0] + xFormMatrix[2] * xFormMatrix[2]);
+
+  *rotation = acos(xFormMatrix[0] / *stride);
   if(xFormMatrix[2] < 0.0){
     *rotation = -*rotation;
   }
@@ -2390,9 +2392,9 @@ plRotationShear(PLFLT *xFormMatrix, PLFLT *rotation, PLFLT *shear)
   *shear = -asin(xFormMatrix[0]*xFormMatrix[1] +
 		 xFormMatrix[2]*xFormMatrix[3]);
 
-  // Compute the cross product of the vectors [1,0] and [0,1] to 
-  // determine if we need to make a "quadrant 3,4" adjustment
-  // to the shear angle.
+  /* Compute the cross product of the vectors [1,0] and [0,1] to 
+   * determine if we need to make a "quadrant 3,4" adjustment
+   * to the shear angle. */
 
   if(xFormMatrix[0]*xFormMatrix[3] - xFormMatrix[1]*xFormMatrix[2] < 0.0){
     *shear = -(M_PI + *shear);
