@@ -1,4 +1,4 @@
-/* $Id: plstripc.c 9275 2009-01-07 22:56:20Z airwin $
+/* $Id: plstripc.c 10286 2009-08-18 16:35:32Z airwin $
  *
  * Plots a simple stripchart.
  *
@@ -168,18 +168,16 @@ static void plstrip_legend(PLStrip *stripc, int first)
  * during rescaling.
 \*--------------------------------------------------------------------------*/
 
-PLFLT oxm,oxM, oym,oyM;
 static void plstrip_gen( PLStrip *strip )
 {
     int i;
-    PLFLT x[]={0.,1.,1.,0.}, y[]={0.,0.,1.,1.};
 
 /* Set up window */
 
     plvpor(0,1,0,1);
     plwind(0,1,0,1);
     plcol(0);plpsty(0);
-    plfill(4, &x[0], &y[0]);
+    plclear();
     plvsta();
 
 /* Draw box and same window dimensions */
