@@ -1,4 +1,4 @@
-/* $Id: plsym.c 8678 2008-08-19 14:31:13Z hbabcock $
+/* $Id: plsym.c 9856 2009-04-26 20:01:32Z hbabcock $
 
 	Point, symbol, and string plotting routines.
 	Also font management code.  See the description of plLibOpen() for
@@ -176,8 +176,8 @@ c_plpoin3(PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, PLINT code)
 	     z[i] >= zmin && z[i] <= zmax) {
 	    u = plP_wcpcx(plP_w3wcx( x[i], y[i], z[i] ));
 	    v = plP_wcpcy(plP_w3wcy( x[i], y[i], z[i] ));
-	    plP_movphy(u,v);
-	    plP_draphy(u,v);
+	    plP_movphy((PLINT)u,(PLINT)v);
+	    plP_draphy((PLINT)u,(PLINT)v);
 	  }
 	}
     }
@@ -192,7 +192,7 @@ c_plpoin3(PLINT n, PLFLT *x, PLFLT *y, PLFLT *z, PLINT code)
 	     z[i] >= zmin && z[i] <= zmax) {
 	    u = plP_wcpcx(plP_w3wcx( x[i], y[i], z[i] ));
 	    v = plP_wcpcy(plP_w3wcy( x[i], y[i], z[i] ));
-	    plhrsh(sym, u, v);
+	    plhrsh(sym, (PLINT)u, (PLINT)v);
 	  }
 	}
     }
@@ -285,7 +285,15 @@ PLUNICODE unicode_char;
           plsc->chrht=plsc->symht;
           plsc->chrdef=plsc->symdef;
 
-          plP_esc(PLESC_HAS_TEXT, &args);
+	  if (plsc->alt_unicode){
+	    args.n_fci = fci;
+	    args.n_char = unicode_char;
+	    plP_esc(PLESC_BEGIN_TEXT, &args);
+	    plP_esc(PLESC_TEXT_CHAR, &args);
+	    plP_esc(PLESC_END_TEXT, &args);
+	  } else {
+	    plP_esc(PLESC_HAS_TEXT, &args);
+	  }
 
           plsc->chrht=plsc->original_chrht;
           plsc->chrdef=plsc->original_chrdef;
@@ -1174,9 +1182,12 @@ int plhershey2unicode ( int in )
 	 * jlo < jmid < jhi and jmid must be in valid range.
 	 */
 	jmid = (jlo+jhi)/2;
-	if (in > hershey_to_unicode_lookup_table[jmid].Hershey)
+  /* convert hershey_to_unicode_lookup_table[jmid].Hershey to signed 
+     integer since we don't loose information - the number range
+     is from 1 and 2932 at the moment */
+	if (in > (int)(hershey_to_unicode_lookup_table[jmid].Hershey))
 	  jlo = jmid;
-	else if (in < hershey_to_unicode_lookup_table[jmid].Hershey)
+	else if (in < (int)(hershey_to_unicode_lookup_table[jmid].Hershey))
 	  jhi = jmid;
 	else
 	  /* We have found it!
@@ -1370,8 +1381,8 @@ c_plmtex3(const char *side, PLFLT disp, PLFLT pos, PLFLT just, const char *text)
 		 *  The calculation is also dependent of the orientation
 		 *   (perpendicular or parallel) of the text. */
 
-		xpc = plP_dcmmx(plP_pcdcx(xpc));
-		ypc = plP_dcmmy(plP_pcdcy(ypc)) - dispy;
+		xpc = plP_dcmmx(plP_pcdcx((PLINT)xpc));  
+		ypc = plP_dcmmy(plP_pcdcy((PLINT)ypc)) - dispy;
 		
 		shift = plstrl(text) * just;
 		
@@ -1397,7 +1408,7 @@ c_plmtex3(const char *side, PLFLT disp, PLFLT pos, PLFLT just, const char *text)
     		xform[1] = -cos(theta);
     		xform[2] = 1.0;
     		xform[3] = -sin(theta);
-			plP_text(0, just, xform, xpc, ypc, xrefpc, yrefpc, text);
+			plP_text(0, just, xform, (PLINT)xpc, (PLINT)ypc, (PLINT)xrefpc, (PLINT)yrefpc, text);
     	}
 
     	/* parallel, rotate & shear by angle */
@@ -1407,7 +1418,7 @@ c_plmtex3(const char *side, PLFLT disp, PLFLT pos, PLFLT just, const char *text)
     		xform[2] = sin(theta);
     		xform[3] = 1.0;
 
-			plP_text(0, just, xform, xpc, ypc, xrefpc, yrefpc, text);
+			plP_text(0, just, xform, (PLINT)xpc, (PLINT)ypc, (PLINT)xrefpc, (PLINT)yrefpc, text);
 		}
 	}
 
@@ -1532,8 +1543,8 @@ c_plmtex3(const char *side, PLFLT disp, PLFLT pos, PLFLT just, const char *text)
 		
 		/* 4. Compute the reference point. */
 
-		xpc = plP_dcmmx(plP_pcdcx(xpc)) + dispx;
-		ypc = plP_dcmmy(plP_pcdcy(ypc)) + dispy;
+		xpc = plP_dcmmx(plP_pcdcx((PLINT)xpc)) + dispx;
+		ypc = plP_dcmmy(plP_pcdcy((PLINT)ypc)) + dispy;
 		
 		shift = plstrl(text) * just;
 
@@ -1558,7 +1569,7 @@ c_plmtex3(const char *side, PLFLT disp, PLFLT pos, PLFLT just, const char *text)
     		xform[2] = sin(theta);
     		xform[3] = 1.0;
 
-			plP_text(0, just, xform, xpc, ypc, xrefpc, yrefpc, text);
+			plP_text(0, just, xform, (PLINT)xpc, (PLINT)ypc, (PLINT)xrefpc, (PLINT)yrefpc, text);
     	}
 
     	else {
@@ -1567,7 +1578,7 @@ c_plmtex3(const char *side, PLFLT disp, PLFLT pos, PLFLT just, const char *text)
     		xform[2] = 1.0;
     		xform[3] = -sin(theta);
 
-			plP_text(0, just, xform, xpc, ypc, xrefpc, yrefpc, text);
+			plP_text(0, just, xform, (PLINT)xpc, (PLINT)ypc, (PLINT)xrefpc, (PLINT)yrefpc, text);
 		}
 
 	}
@@ -1655,8 +1666,8 @@ c_plptex3(PLFLT wx, PLFLT wy, PLFLT wz, PLFLT dx, PLFLT dy, PLFLT dz,
   stride = stride/sqrt(x_dx*x_dx + y_dy*y_dy + z_dz*z_dz);
 
   /* compute the reference point */	
-  xpc = plP_dcmmx(plP_pcdcx(xpc));
-  ypc = plP_dcmmy(plP_pcdcy(ypc));
+  xpc = plP_dcmmx(plP_pcdcx((PLINT)xpc));
+  ypc = plP_dcmmy(plP_pcdcy((PLINT)ypc));
   
   shift = plstrl(text) * just;
   xrefpc = xpc - cos(theta) * shift;
@@ -1673,7 +1684,7 @@ c_plptex3(PLFLT wx, PLFLT wy, PLFLT wz, PLFLT dx, PLFLT dy, PLFLT dz,
   xform[2] = sin(theta) * stride;
   xform[3] = sin(theta) * sin(phi) + cos(theta) * cos(phi);
 
-  plP_text(0, just, xform, xpc, ypc, xrefpc, yrefpc, text);	
+  plP_text(0, just, xform, (PLINT)xpc, (PLINT)ypc, (PLINT)xrefpc, (PLINT)yrefpc, text);	
 }
 
 /*------------------------------------------------------------------------*\
