@@ -1,4 +1,4 @@
-/* $Id: pltek.c 2428 2001-01-10 06:45:32Z mlebrun $
+/* $Id: pltek.c 9618 2009-02-25 22:03:25Z smekal $
  *
  *  Review a Tektronix vector file.
  *  from 'scan', by Clair Nielsen, LANL.
@@ -134,7 +134,10 @@ main(int argc, char *argv[])
 	istop = 0;
 	for (i = 0; i < 8196; i++) {	/* less than 8MB per page! */
 	    if (xtra) {
-		fwrite(&xtra, 1, 1, stdout);
+		if (fwrite(&xtra, 1, 1, stdout) != 1) {
+		    fprintf(stderr,"Error writing to stdout\n");
+                    exit(1);
+                }
 		xtra = '\0';
 	    }
 	    nb = fread(buf, 1, BUFSZ, fd);
@@ -143,7 +146,10 @@ main(int argc, char *argv[])
 	    ifirst = 0;
 	    for (j = 0; j < nb; j++) {
 		if (buf[j] == '\f') {
-		    fwrite(&buf[ifirst], 1, j - ifirst, stdout);
+		    if (fwrite(&buf[ifirst], 1, j - ifirst, stdout) != j-ifirst) {
+		        fprintf(stderr,"Error writing to stdout\n");
+                        exit(1);
+                    }
 		    fflush(stdout);
 		    istop = 1;
 		    break;
@@ -155,7 +161,10 @@ main(int argc, char *argv[])
 		xtra = ESC;
 		j--;
 	    }
-	    fwrite(&buf[ifirst], 1, j - ifirst, stdout);
+	    if (fwrite(&buf[ifirst], 1, j - ifirst, stdout) != j-ifirst ) {
+	        fprintf(stderr,"Error writing to stdout\n");
+                exit(1);
+            }
 	}
 	if ( termtype == xterm ) 
 	    tek_mode(ALPHA_MODE);
